\name{autointensity}
\title{Plot Autointensity Function of a Point Process}
\usage{
autointensity(times, window=NULL, maxlag=total/10,
	ylab="Conditional probability", xlab="Lag",
	main="Autointensity function", xlim=c(0,max(times)),
	ylim=c(0,if(plotse)max(se1)else max(z$density)),
	lty=1, plot=TRUE, plotse=TRUE, add=FALSE, ...)
}
\description{
\code{autointensity} plots the autointensity function of a point
process, including a solid horizontal line indicating the constant
intensity of a Poisson process.
}
\arguments{
\item{times}{Vector of times between events.}
\item{window}{Width of grouping interval.}
\item{maxlag}{Maximum lag to be calculated, by default the maximum
interevent time.}
\item{plot}{If FALSE, values are returned but the function is not
plotted.}
\item{plotse}{If TRUE, plots pointwise two-standard error bands around
the curve.}
\item{add}{If TRUE, add curve to an existing plot.}
\item{others}{Plotting control options.}
}
\value{
A list containing the coordinates of the plotted function and the
standard error bands.
}
\references{
Guttorp, P. (1995) Stochastic Modeling of Scientific Data. Chapman &
Hall, pp. 229, 238-240.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{cprocess}}.
}
\examples{
times <- rgamma(100,2,scale=4)
autointensity(times, window=3)
}
\keyword{hplot}

\eof
\name{bp}
\title{Create a Vector of Cumulative Numbers of Previous Events
for a Point Process (Birth Processes)}
\alias{bp}
\usage{
bp(y, id, censor=1)
}
\arguments{
\item{y}{Vector of times.}
\item{id}{Vector of corresponding individual identifiers for who had
which sequence of times.}
\item{censor}{Vector of censoring indicators.}
}
\value{
\code{bp} creates a vector of length \code{sum(y)} of cumulative
numbers of previous events for each individual for use in fitting
birth processes with \code{\link{ehr}}. Add one if the process starts
at an event.
}
\author{J.K. Lindsey}
\seealso{
\code{\link{ehr}}, \code{\link{ident}}, \code{\link{pp}}, \code{\link{tccov}},
\code{\link{tpast}}, \code{\link{ttime}}, \code{\link{tvcov}}.
}
\examples{
y <- c(5,3,2,4)
i <- c(1,1,2,2)
birth <- bp(y, i)
birth
}
\keyword{manip}

\eof
\name{coxre}
\title{Cox Proportional Hazards Model with Random Effect}
\alias{coxre}
\usage{
coxre(response, censor, nest=NULL, cov=NULL, stratified=FALSE,
	cumul=FALSE,estimate=1, iter=10, print.level=0, ndigit=10,
	gradtol=0.00001, steptol=0.00001, iterlim=100, fscale=1,
	typsiz=abs(estimate), stepmax=estimate)
}
\description{
\code{coxre} fits a Cox proportional hazards model to event history
data using a gamma distribution random effect. The parameter, gamma,
is the variance of this mixing distribution.

If a matrix of response times is supplied, the model can be stratified
by columns, i.e. a different intensity function is fitted for each
column. To fit identical intensity functions to all response types,
give the times as a vector.
}
\arguments{
\item{response}{Vector or matrix of times to events, with one column
per type of response (or subunit).}
\item{censor}{Corresponding vector or matrix of censoring indicators.
If NULL all values are set to one.}
\item{nest}{Vector indicating to which unit each observation belongs.}
\item{cov}{One covariate}
\item{stratified}{If TRUE, a model stratified on type of response
(the columns of response) is fitted instead of proportional intensities.}
\item{cumul}{Set to TRUE if response times are from a common origin
instead of times to (or between) events.}
\item{estimate}{Initial estimate of the frailty parameter.}
\item{iter}{Maximum number of iterations allowed for the inner EM loop.}
\item{others}{Plotting control options.}
}
\author{D.G. Clayton and J.K. Lindsey}
\references{
Clayton, D. (1987) The analysis of event history data: a review of
progress and outstanding problems.  Statistics in Medicine 7: 819-841
}
\seealso{
\code{\link[event]{kalsurv}}.
}
\examples{
# 11 individuals, each with 5 responses
y <- matrix(c(51,36,50,35,42,
	27,20,26,17,27,
	37,22,41,37,30,
	42,36,32,34,27,
	27,18,33,14,29,
	43,32,43,35,40,
	41,22,36,25,38,
	38,21,31,20,16,
	36,23,27,25,28,
	26,31,31,32,36,
	29,20,25,26,25),ncol=5,byrow=TRUE)
# Different intensity functions
coxre(response=y, censor=matrix(rep(1,55),ncol=5), nest=1:11,
	est=0.7, stratified=TRUE)
# Proportional intensity functions for the five responses
coxre(response=y, censor=matrix(rep(1,55),ncol=5), nest=1:11,
	est=0.7, stratified=FALSE)
# Identical intensity functions
coxre(response=as.vector(t(y)), censor=rep(1,55),
	nest=rep(1:11,rep(5,11)), est=0.7)
}
\keyword{models}

\eof
\name{cprocess}
\title{Plot Counting Process Data}
\alias{cprocess}
\usage{
cprocess(times=NULL, events=NULL, number=FALSE, lty=NULL, xlim=NULL,
	ylim=NULL, xlab="Time", ylab="Counts", ...)
}
\description{
\code{cprocess} plots the cumulative number of events (the counting
process) over time for each vector in the list. One or both of
\code{times} and \code{events} can be supplied.
}
\arguments{
\item{times}{Vector of times between events, a list of such
vectors, or a \code{repeated} object.}
\item{events}{Vector of counts of events, a list of such vectors, or a
\code{repeated} object.}
\item{number}{If TRUE, the counting processes are numbered
consecutively on the graph.}
\item{others}{Plotting control options.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{rmna}}.
}
\examples{
times <- rgamma(20,2,scale=4)
cprocess(times)
}
\keyword{hplot}

\eof
\name{ehr}
\title{Regression Models for Event History Intensity Functions}
\alias{ehr}
\usage{
ehr(point, lambda=NULL, linear=NULL, plambda=NULL, delta=1,
	envir=parent.frame(), print.level=0, typsiz=rep(1,length(plambda)),
	ndigit=10, gradtol=0.00001, iterlim=100, fscale=1,
	stepmax=max(10*sqrt(plambda%*%plambda),10), steptol=0.0004)
}
\description{
\code{ehr} fits an intensity function to event histories, where point is
produced by \code{point <- pp(y)} and \code{lambda} is the user-defined
log intensity function.

Nonlinear regression models for \code{lambda} can be supplied as
formulae where parameters are unknowns. Factor variables cannot be
used and parameters must be scalars. (See \code{\link[rmutil]{finterp}}.)
}
\arguments{
\item{point}{A point process vector produced by \code{\link[event]{pp}}.}
\item{lambda}{User-specified function of \code{p}, and possibly
\code{linear}, giving the regression equation for the intensity or a
formula beginning with ~, specifying either a linear regression
function in the Wilkinson and Rogers notation or a general function
with named unknown parameters. The function may contain a
linear part that must simply be given the name, \code{linear}, in the
function. If no function is supplied, the intensity is taken to be
constant (a homogeneous Poisson process).}
\item{linear}{A formula beginning with ~ specifying the linear part of
the regression function.}
\item{plambda}{Vector of initial parameter estimates. If \code{lambda}
is a formula with unknown parameters, their estimates must be supplied
either in their order of appearance in the expression or in a named list.}
\item{delta}{If any time intervals are different from unity, a vector
of time intervals.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, repeated, tccov, or tvcov.
If \code{point} has class \code{repeated}, it is used as the
environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\references{
Lindsey, J.K. (1995) Fitting parametric counting processes by
using log linear models. Journal of the Royal Statistical
Society C44, 201-212.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{bp}}, \code{\link[rmutil]{finterp}},
\code{\link[event]{ident}}, \code{\link[event]{pp}},
\code{\link[event]{tccov}}, \code{\link[event]{tpast}},
\code{\link[event]{ttime}}, \code{\link[event]{tvcov}}.
}
\examples{
y <- c(5,3,2,4)
# event indicator
py <- pp(y)
# time since previous event
ptime <- tpast(y)
# individual ID
i <- c(1,1,2,2)
id <- ident(y, i)
# times and corresponding covariate values
tx <- c(2,3,1,2,2,2,2)
x <- c(1,2,2,1,2,2,1)
zcov <- tvcov(y, x, tx)
# Poisson process
ehr(py, plambda=1)
# Weibull process
lambda1 <- function(p) p[1]+p[2]*log(ptime)
ehr(py, lambda=lambda1, plambda=c(1,1))
# or
ehr(py, lambda=~log(ptime), plambda=c(1,1))
# or
ehr(py, lambda=~b0+b1*log(ptime), plambda=list(b0=1,b1=1))
# Poisson process with time-varying covariate
lambda2 <- function(p) p[1]+p[2]*zcov
ehr(py, lambda=lambda2, plambda=c(1,1))
# or
ehr(py, lambda=~zcov, plambda=c(1,1))
# or
ehr(py, lambda=~c0+c1*zcov, plambda=list(c0=1,c1=1))
# Weibull process with time-varying covariate
lambda3 <- function(p) p[1]+p[2]*log(ptime)+p[3]*zcov
ehr(py, lambda=lambda3, plambda=c(1,1,1))
# or
ehr(py, lambda=~log(ptime)+zcov, plambda=c(1,1,1))
# or
ehr(py, lambda=~c0+b1*log(ptime)+c1*zcov, plambda=list(c0=1,c1=1,b1=1))
# gamma process with time-varying covariate
lambda4 <- function(p) hgamma(ptime, p[1], exp(p[2]+p[3]*zcov))
ehr(py, lambda=lambda4, plambda=c(1,1,1))
# or
ehr(py, lambda=~hgamma(ptime, b1, exp(c0+c1*zcov)),
	plambda=list(c0=1,c1=1,b1=1))
# or
lambda5 <- function(p, linear) hgamma(ptime, p[1], exp(linear))
ehr(py, lambda=lambda5, linear=~zcov, plambda=c(1,1,1))
}
\keyword{models}

\eof
\name{event}
\title{Event History Analysis Library}
\alias{event}
\description{
\code{\link[event]{autointensity}}	Plot Autointensity Function of a Point Process

\code{\link[event]{bp}}			Create a Vector of Cumulative Numbers of Previous Events for a Point Process

\code{\link[event]{coxre}}		Cox Proportional Hazards Model with Random Effect

\code{\link[event]{cprocess}}	Counting Process Plot

\code{\link[event]{ehr}}		Fit an Intensity Function to Event Histories

\code{\link[event]{hboxcox}}		Log Hazard Function for a Box-Cox Process

\code{\link[event]{hburr}}		Log Hazard Function for a Burr Process

\code{\link[event]{hcauchy}}		Log Hazard Function for a Cauchy Process

\code{\link[event]{hexp}}		Log Hazard Function for an Exponential (Poisson) Process

\code{\link[event]{hgamma}}		Log Hazard Function for a Gamma Process

\code{\link[event]{hgextval}}	Log Hazard Function for an Extreme Value  Process

\code{\link[event]{hggamma}}		Log Hazard Function for a Generalized Gamma Process

\code{\link[event]{hglogis}}		Log Hazard Function for a Generalized Logistic Process

\code{\link[event]{hgweibull}}	Log Hazard Function for a Generalized Weibull Process

\code{\link[event]{hhjorth}}		Log Hazard Function for a Hjorth Process

\code{\link[event]{hinvgauss}}	Log Hazard Function for a Inverse Gauss Process

\code{\link[event]{hlaplace}}	Log Hazard Function for a Laplace Process

\code{\link[event]{hlnorm}}		Log Hazard Function for a Log Normal Process

\code{\link[event]{hlogis}}		Log Hazard Function for a Logistic Process

\code{\link[event]{hnorm}}		Log Hazard Function for a Normal Process

\code{\link[event]{hpareto}}		Log Hazard Function for a Pareto Process

\code{\link[event]{hskewlaplace}}	Log Hazard Function for a Skew Laplace Process

\code{\link[event]{hstudent}}	Log Hazard Function for a Student Process

\code{\link[event]{hweibull}}	Log Hazard Function for a Weibull Process

\code{\link[event]{ident}}		Create an Individual Identification Vector for a Point Process

\code{\link[event]{kalsurv}}		Generalized Repeated Measurements Models for Event Histories

\code{\link[event]{km}}			Kaplan-Meier Survival Curves

\code{\link[event]{pbirth}}		Fit Overdispersed Count Data as a Birth Process

\code{\link[event]{pp}}			Create a Point Process Vector from Times between Events

\code{\link[event]{read.list}}	Read a List of Matrices of Unbalanced Repeated Measurements from a File

\code{\link[event]{read.surv}}	Read a List of Vectors of Event Histories from a File

\code{\link[event]{survkit}}		Weibull and Cox Models with Random Effects

\code{\link[event]{tccov}}		Create a Vector of Time-constant Covariates for a Point Process

\code{\link[event]{tpast}}		Create a Vector of Times Past since Previous Events for a Point Process

\code{\link[event]{ttime}}		Create a Vector of Total Time Elapsed for each Individual for a Point Process

\code{\link[event]{tvcov}}		Create a Vector of Time-varying Covariates for a Point Process
}
\keyword{documentation}

\eof
\name{hcauchy}
\title{Hazard Function for a Cauchy Process}
\alias{hcauchy}
\usage{
hcauchy(y, m, s)
}
\arguments{
\item{y}{Vector of times.}
\item{m}{Location parameter.}
\item{s}{Dispersion parameter.}
}
\value{
\code{hcauchy} returns the log hazard function for a Cauchy process with
the given parameter values.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{hboxcox}}, \code{\link[rmutil]{hburr}},
\code{\link[event]{hexp}}, \code{\link[rmutil]{hgextval}},
\code{\link[event]{hgamma}}, \code{\link[rmutil]{hggamma}},
\code{\link[rmutil]{hhjorth}}, \code{\link[rmutil]{hinvgauss}},
\code{\link[rmutil]{hlaplace}}, \code{\link[event]{hlnorm}},
\code{\link[event]{hlogis}}, \code{\link[rmutil]{hglogis}},
\code{\link[event]{hnorm}}, \code{\link[event]{hstudent}},
\code{\link[event]{hweibull}}, \code{\link[rmutil]{hgweibull}}.
}
\examples{
hcauchy(1:10, 3, 2)
}
\keyword{distribution}

\eof
\name{hexp}
\title{Hazard Function for a Poisson Process}
\alias{hexp}
\usage{
hexp(y, rate)
}
\arguments{
\item{y}{Vector of times.}
\item{rate}{Vector of rates.}
}
\value{
\code{hexp} returns the log hazard function for a Poisson process with
the given parameter value.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{hboxcox}}, \code{\link[rmutil]{hburr}},
\code{\link[event]{hexp}}, \code{\link[rmutil]{hgextval}},
\code{\link[event]{hgamma}}, \code{\link[rmutil]{hggamma}},
\code{\link[rmutil]{hhjorth}}, \code{\link[rmutil]{hinvgauss}},
\code{\link[rmutil]{hlaplace}}, \code{\link[event]{hlnorm}},
\code{\link[event]{hlogis}}, \code{\link[rmutil]{hglogis}},
\code{\link[event]{hnorm}}, \code{\link[event]{hstudent}},
\code{\link[event]{hweibull}}, \code{\link[rmutil]{hgweibull}}.
}
\examples{
hexp(1:10, 3)
}
\keyword{distribution}

\eof
\name{hgamma}
\title{Hazard Function for a Gamma Process}
\alias{hgamma}
\usage{
hgamma(y, shape, rate=1, scale=1/rate)
}
\arguments{
\item{y}{Vector of times.}
\item{shape}{Shape parameter.}
\item{rate}{Rate parameter.}
\item{scale}{Scale parameter.}
}
\value{
\code{hgamma} returns the log hazard function for a gamma process with
the given parameter values.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{hboxcox}}, \code{\link[rmutil]{hburr}},
\code{\link[event]{hexp}}, \code{\link[rmutil]{hgextval}},
\code{\link[event]{hcauchy}}, \code{\link[rmutil]{hggamma}},
\code{\link[rmutil]{hhjorth}}, \code{\link[rmutil]{hinvgauss}},
\code{\link[rmutil]{hlaplace}}, \code{\link[event]{hlnorm}},
\code{\link[event]{hlogis}}, \code{\link[rmutil]{hglogis}},
\code{\link[event]{hnorm}}, \code{\link[event]{hstudent}},
\code{\link[event]{hweibull}}, \code{\link[rmutil]{hgweibull}}.
}
\examples{
hgamma(1:10, 3, 2)
}
\keyword{distribution}

\eof
\name{hlnorm}
\title{Hazard Function for a Log Normal Process}
\alias{hlnorm}
\usage{
hlnorm(y, m, s)
}
\arguments{
\item{y}{Vector of times.}
\item{m}{Mean parameter.}
\item{s}{Variance parameter.}
}
\value{
\code{hlnorm} returns the log hazard function for a log normal
process with the given parameter values.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{hboxcox}}, \code{\link[rmutil]{hburr}},
\code{\link[event]{hexp}}, \code{\link[rmutil]{hgextval}},
\code{\link[event]{hcauchy}}, \code{\link[event]{hgamma}},
\code{\link[rmutil]{hggamma}}, \code{\link[rmutil]{hhjorth}},
\code{\link[rmutil]{hinvgauss}}, \code{\link[rmutil]{hlaplace}},
\code{\link[event]{hlogis}}, \code{\link[rmutil]{hglogis}},
\code{\link[event]{hnorm}}, \code{\link[event]{hstudent}},
\code{\link[event]{hweibull}}, \code{\link[rmutil]{hgweibull}}.
}
\examples{
hlnorm(1:10, 3, 2)
}
\keyword{distribution}

\eof
\name{hlogis}
\title{Hazard Function for a Logistic Process}
\alias{hlogis}
\usage{
hlogis(y, m, s)
}
\arguments{
\item{y}{Vector of times.}
\item{m}{Location parameter.}
\item{s}{Scale parameter.}
}
\value{
\code{hlogis} returns the log hazard function for a logistic
process with the given parameter values.
}
\author{J.K. Lindsey}
\seealso{
\code{\link{hboxcox}}, \code{\link{hburr}}, \code{\link{hexp}},
\code{\link{hgextval}}, \code{\link{hcauchy}}, \code{\link{hgamma}},
\code{\link{hggamma}}, \code{\link{hhjorth}}, \code{\link{hinvgauss}},
\code{\link{hlaplace}}, \code{\link{hlnorm}}, \code{\link{hglogis}},
\code{\link{hnorm}}, \code{\link{hstudent}}, \code{\link{hweibull}},
\code{\link{hgweibull}}.
}
\examples{
hlogis(1:10, 3, 2)
}
\keyword{distribution}

\eof
\name{hnorm}
\title{Hazard Function for a Normal Process}
\alias{hnorm}
\usage{
hnorm(y, m, s)
}
\arguments{
\item{y}{Vector of times.}
\item{m}{Mean parameter.}
\item{s}{Variance parameter.}
}
\value{
\code{hnorm} returns the log hazard function for a normal
process with the given parameter values.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{hboxcox}}, \code{\link[rmutil]{hburr}},
\code{\link[event]{hexp}}, \code{\link[rmutil]{hgextval}},
\code{\link[event]{hcauchy}}, \code{\link[event]{hgamma}},
\code{\link[rmutil]{hggamma}}, \code{\link[rmutil]{hhjorth}},
\code{\link[rmutil]{hinvgauss}}, \code{\link[rmutil]{hlaplace}},
\code{\link[event]{hlogis}}, \code{\link[rmutil]{hglogis}},
\code{\link[event]{hlnorm}}, \code{\link[event]{hstudent}},
\code{\link[event]{hweibull}}, \code{\link[rmutil]{hgweibull}}.
}
\examples{
hnorm(1:10, 3, 2)
}
\keyword{distribution}

\eof
\name{hstudent}
\title{Hazard Function for a Student t Process}
\alias{hstudent}
\usage{
hstudent(y, m, s, f)
}
\arguments{
\item{y}{Vector of times.}
\item{m}{Location parameter.}
\item{s}{Scale  parameter.}
\item{f}{Degrees of freedom.}
}
\value{
\code{hstudent} returns the log hazard function for a Student t
process with the given parameter values.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{hboxcox}}, \code{\link[rmutil]{hburr}},
\code{\link[event]{hexp}}, \code{\link[rmutil]{hgextval}},
\code{\link[event]{hcauchy}}, \code{\link[event]{hgamma}},
\code{\link[rmutil]{hggamma}}, \code{\link[rmutil]{hhjorth}},
\code{\link[rmutil]{hinvgauss}}, \code{\link[rmutil]{hlaplace}},
\code{\link[event]{hlogis}}, \code{\link[rmutil]{hglogis}},
\code{\link[event]{hnorm}}, \code{\link[event]{hnorm}},
\code{\link[event]{hweibull}}, \code{\link[rmutil]{hgweibull}}.
}
\examples{
hstudent(1:10, 3, 2, 5)
}
\keyword{distribution}

\eof
\name{hweibull}
\title{Hazard Function for a Weibull Process}
\alias{hweibull}
\usage{
hweibull(y, s, m)
}
\arguments{
\item{y}{Vector of times.}
\item{s}{Shape parameter.}
\item{m}{Scale parameter.}
}
\value{
\code{hweibull} returns the log hazard function for a Weibull
process with the given parameter values.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{hboxcox}}, \code{\link[rmutil]{hburr}},
\code{\link[event]{hexp}}, \code{\link[rmutil]{hgextval}},
\code{\link[event]{hcauchy}}, \code{\link[event]{hgamma}},
\code{\link[rmutil]{hggamma}}, \code{\link[rmutil]{hhjorth}},
\code{\link[rmutil]{hinvgauss}}, \code{\link[rmutil]{hlaplace}},
\code{\link[event]{hlogis}}, \code{\link[rmutil]{hglogis}},
\code{\link[event]{hlnorm}}, \code{\link[event]{hnorm}},
\code{\link[event]{hstudent}}, \code{\link[rmutil]{hgweibull}}.
}
\examples{
hweibull(1:10, 1.5, 2)
}
\keyword{distribution}

\eof
\name{ident}
\title{Create an Individual Identification Vector for a Point Process}
\alias{ident}
\usage{
ident(y, id)
}
\arguments{
\item{y}{Vector of times.}
\item{id}{Vector of corresponding individual identifiers for who had
which sequence of times.}
}
\value{
\code{ident} creates a vector of length \code{sum(y)} by repeating the
values of individual identifiers for the times for use with
\code{\link[event]{ehr}}.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{bp}}, \code{\link[event]{ehr}},
\code{\link[event]{pp}}, \code{\link[event]{tccov}},
\code{\link[event]{tpast}}, \code{\link[event]{ttime}},
\code{\link[event]{tvcov}}.
}
\examples{
y <- c(5,3,2,4)
i <- c(1,1,2,2)
id <- ident(y, i)
id
}
\keyword{manip}

\eof
\name{kalsurv}
\title{Repeated Events Models with Frailty or Serial Dependence}
\alias{kalsurv}
\usage{
kalsurv(response, intensity="exponential", distribution="Pareto",
	depend="independence", update="Markov", mu=NULL, shape=NULL,
	renewal=TRUE, density=FALSE, censor=NULL, delta=NULL, ccov=NULL,
	tvcov=NULL, preg=1, ptvc=NULL, pbirth=NULL,
	pintercept=NULL, pshape=NULL, pinitial=1, pdepend=NULL,
	pfamily=NULL, envir=parent.frame(), print.level=0,
	ndigit=10, gradtol=0.00001, steptol=0.00001, iterlim=100,
	fscale=1, typsiz=abs(p), stepmax=10*sqrt(p\%*\%p))
}
\description{
\code{kalsurv} is designed to handle event history models with
time-varying covariates. The distributions have two extra parameters
as compared to the functions specified by \code{intensity} and are
generally longer tailed than those distributions. Dependence of
inter-event times can be through gamma frailties (a type of random
effect), with or without autoregression, or several kinds of serial
dependence by updating, as in Kalman filtering.

By default, a gamma mixture of the distribution specified in
\code{intensity} is used, as the conditional distribution in the
\code{serial} dependence models, and as a symmetric multivariate
(random effect) model for \code{frailty} dependence. For example, with
a Weibull \code{intensity} and \code{frailty} dependence, this yields
a multivariate Burr distribution and with \code{Markov} or
\code{serial} dependence, univariate Burr conditional distributions.

If a value for \code{pfamily} is used, the gamma mixture is replaced
by a power variance family mixture.

Nonlinear regression models can be supplied as formulae where
parameters are unknowns in which case factor variables cannot be used and
parameters must be scalars. (See \code{\link[rmutil]{finterp}}.)

Marginal and individual profiles can be plotted using
\code{\link[rmutil]{mprofile}} and \code{\link[rmutil]{iprofile}} and
residuals with \code{\link[rmutil]{plot.residuals}}.
}
\arguments{
\item{response}{A list of vectors with times between events for
each individual, one matrix or dataframe of such times if all
individuals have the same number of events, or an object of class,
\code{response} (created by \code{\link[rmutil]{restovec}}) or \code{repeated}
(created by \code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{intensity}{The form of intensity function to be put in the
distribution given by dist. Choices are exponential, Weibull, gamma,
log normal, log logistic, log Cauchy, log Student, and gen(eralized)
logistic.}
\item{distribution}{The outer distribution. Choices are Pareto, gamma,
and Weibull.}
\item{depend}{Type of dependence. Choices are \code{independence},
\code{frailty}, and \code{serial}.}
\item{update}{Type of update for serial dependence. Choices are
\code{Markov}, \code{elapsed Markov}, \code{serial}, \code{event},
\code{cumulated}, \code{count}, and \code{kalman}. With \code{frailty}
dependence, weighting by length of observation time may be specified
by setting update to \code{time}.}
\item{mu}{A regression function for the location parameter or a
formula beginning with ~, specifying either a linear regression
function in the Wilkinson and Rogers notation or a general function
with named unknown parameters. Give the initial estimates in
\code{preg} if there are no time-varying covariates and in \code{ptvc}
if there are.}
\item{shape}{A regression function for the shape parameter or a
formula beginning with ~, specifying either a linear regression
function in the Wilkinson and Rogers notation or a general function
with named unknown parameters. It must yield one value per observation.}
\item{renewal}{IF TRUE, a renewal process is modelled, with time
reinitialized after each event. Otherwise, time is cumulated from the
origin of observations.}
\item{density}{If TRUE, the density of the function specified in
\code{intensity} is used instead of the intensity.}
\item{censor}{A vector of the same length as the number of individuals
containing a binary indicator, with a one indicating that the last
time period in the series terminated with an event and zero that it
was censored. For independence and frailty models, where response is
matrix, censor may also be a matrix of the same size. Ignored if
response has class, \code{response} or \code{repeated}.}
\item{delta}{Scalar or vector giving the unit of measurement for each
response value, set to unity by default. For example, if a response is
measured to two decimals, delta=0.01. If the response has been
pretransformed, this must be multiplied by the Jacobian. This
transformation cannot contain unknown parameters. For example, with a
log transformation, \code{delta=1/y}. (The delta values for the
censored response are ignored.) Ignored if response has class,
\code{response} or \code{repeated}.}
\item{ccov}{A vector or matrix containing time-constant baseline
covariates with one entry per individual, a model formula using
vectors of the same size, or an object of class, \code{tccov} (created
by \code{\link[rmutil]{tcctomat}}). If response has class, \code{repeated},
the covariates must be supplied as a Wilkinson and Rogers formula
unless none are to be used or \code{mu} is given.}
\item{tvcov}{A list of matrices with time-varying covariate values,
observed at the event times in \code{response}, for each individual
(one column per variable), one matrix or dataframe of such covariate
values, or an object of class, \code{tvcov} (created by
\code{\link[rmutil]{tvctomat}}). If response has class, \code{repeated}, the
covariates must be supplied as a Wilkinson and Rogers formula unless
none are to be used or \code{mu} is given.}
\item{preg}{Initial parameter estimates for the regression model:
intercept plus one for each covariate in \code{ccov}. If \code{mu} is
a formula or function, the parameter estimates must be given here only
if there are no time-varying covariates. If \code{mu} is
a formula with unknown parameters, their estimates must be supplied
either in their order of appearance in the expression or in a named
list.}
\item{ptvc}{Initial parameter estimates for the coefficients of the
time-varying covariates, as many as in \code{tvcov}. If \code{mu} is a
formula or function, the parameter estimates must be given here if
there are time-varying covariates present.}
\item{pbirth}{If supplied, this is the initial estimate for the
coefficient of the birth model.}
\item{pintercept}{The initial estimate of the intercept for the
generalized logistic intensity.}
\item{pshape}{An initial estimate for the shape parameter of the
intensity (except exponential intensity). If \code{shape} is
a function or formula, the corresponding initial estimates. If
\code{shape} is a formula with unknown parameters, their estimates
must be supplied either in their order of appearance in the expression
or in a named list.}
\item{pinitial}{An initial estimate for the initial parameter. In
\code{frailty} dependence, this is the frailty parameter.}
\item{pdepend}{An initial estimate for the serial dependence
parameter. For \code{frailty} dependence, if a value is given here, an
autoregression is fitted as well as the frailty.}
\item{pfamily}{An optional initial estimate for the second parameter
of a two-parameter power variance family mixture instead of the
default gamma mixture. This yields a gamma mixture as \code{family ->
0}, an inverse Gauss mixture for \code{family = 0.5}, and a compound
distribution of a Poisson-distributed number of gamma distributions
for \code{-1 < family < 0}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}.
If \code{response} has class \code{repeated}, it is used as the
environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of classes \code{kalsurv} and \code{recursive} is returned.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{coxre}}, \code{\link[rmutil]{finterp}},
\code{\link[rmutil]{gettvc}}, \code{\link[repeated]{gnlmm}},
\code{\link[gnlm]{gnlr}}, \code{\link[rmutil]{iprofile}},
\code{\link[repeated]{kalcount}}, \code{\link[repeated]{kalseries}},
\code{\link[rmutil]{mprofile}}, \code{\link[repeated]{nbkal}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}.
}
\examples{
treat <- c(0,0,1,1)
tr <- tcctomat(treat)
cens <- matrix(rbinom(20,1,0.9),ncol=5)
times <- # matrix(rweibull(20,2,1+3*rep(treat,5)),ncol=5)
	matrix(c(1.36,0.18,0.84,0.65,1.44,1.79,1.04,0.43,1.35,1.63,2.15,1.15,
		1.21,5.46,1.58,3.44,4.40,2.75,4.78,2.44),ncol=5,byrow=TRUE)
times <- restovec(times, censor=cens)
reps <- rmna(times, ccov=tr)
# exponential intensity model with independence
kalsurv(times, pinitial=0.5, preg=1, dep="independence",
	intensity="exponential")
# Weibull intensity model with independence
kalsurv(times, pinitial=0.5, preg=1, pshape=1, dep="independence",
	intensity="Weibull")
# same model with serial update
kalsurv(times, pinitial=0.5, pdep=0.1, preg=1, pshape=1, dep="serial",
	intensity="Weibull")
# try power variance family instead of gamma distribution for mixture
kalsurv(times, pinitial=0.5, pdep=0.1, preg=1, pshape=1, dep="serial",
	intensity="Weibull", pfamily=0.1)
# treatment effect with log link
kalsurv(times, pinitial=0.5, preg=c(1,0), pshape=1, intensity="Weibull",
	ccov=treat)
# or equivalently
kalsurv(times, mu=~exp(a+b*treat), pinitial=0.1, preg=c(1,0), pshape=1,
	intensity="Weibull", envir=reps)
# with identity link instead
kalsurv(times, mu=~treat, pinitial=0.5, preg=c(1,0), pshape=1,
	intensity="Weibull")
# or equivalently
kalsurv(times, mu=~a+b*treat, pinitial=0.5, preg=c(1,0), pshape=1,
	intensity="Weibull", envir=reps)
# add the birth model
kalsurv(times, pinitial=0.5, preg=c(1,0), pshape=1,
	intensity="Weibull", ccov=treat, pbirth=0)
# try frailty dependence
kalsurv(times, pinitial=0.5, preg=c(1,0), pshape=1, dep="frailty",
	intensity="Weibull", ccov=treat)
# add autoregression
kalsurv(times, pinitial=0.5, preg=c(1,0), pshape=1, dep="frailty",
	pdep=0.1, intensity="Weibull", ccov=treat)
# switch to gamma intensity model
kalsurv(times, pinitial=0.5, preg=c(1,0), pshape=1, intensity="gamma",
	ccov=treat)
}
\keyword{models}

\eof
\name{km}
\title{Kaplan-Meier Survivor Curves}
\usage{
km(times, censor, group=1, freq=1, cdf=FALSE)
plot.km(z, add=FALSE, xlim, ylim=c(0,1), main=NULL, xlab="Time",
	ylab=NULL, lty=NULL, ...)
plot.intensity.km(z, add=FALSE, xlab="Time", ylab="Intensity", type="l",
	lty=NULL, ...)
plot.dist.km(z)
}
\alias{km}
\alias{plot.km}
\alias{plot.intensity.km}
\alias{plot.dist}
\alias{plot.dist.km}
\description{
\code{km} calculates the Kaplan-Meier estimates for survival.

To plot the survivor curve, use \code{plot()}; for the empirical
intensity curve, use \code{plot.intensity()}; for diagnostic curves to
choose a distribution to which the data might belong, use \code{plot.dist()}.
}
\arguments{
\item{times}{Vector of times to events or a list of vectors of such
times for different individuals.}
\item{censor}{Vector of censoring indicators corresponding to the
vector of times or to the last time in each vector of a list.}
\item{group}{Vector indicating to which group each individual belongs.}
\item{freq}{Vector of frequencies for grouped data.}
\item{cdf}{If TRUE, calculate the cdf instead of the survivor curve.}
\item{z}{An object produced by \code{km}.}
}
\value{
A matrix with class, \code{km}, containing the Kaplan-Meier estimates
is returned.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{plot.intensity}}, \code{\link[event]{plot.survivor}}
}
\examples{
surv <- rgamma(40,2,scale=5)
cens <- rbinom(40,1,0.9)
treat <- gl(2,20)
plot(km(surv, cens, group=treat), main="",xlab="Months",
	ylab="Probability of deterioration")
plot.dist(km(surv, cens, group=treat))
plot.intensity(km(surv, cens, group=treat),ylab="Risk of deterioration")
}
\keyword{hplot}

\eof
\name{pbirth}
\title{Fit Overdispersed Count Data as a Birth Process}
\alias{pbirth}
\usage{
pbirth(frequencies, p, intensity="negative binomial",
	type="spectral decomposition", print.level=0, ndigit=10,
	gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100,
	typsiz=abs(p), stepmax=10*sqrt(p%*%p))
}
\description{
\code{pbirth} fits binomial, binomial exponential, binomial logistic,
binomial total, Poisson, Poisson exponential, negative binomial,
gen(eralized) negative binomial, and generalized negative binomial
processes as a birth process.
}
\arguments{
\item{frequencies}{Vector of frequencies or a matrix with each row a
different series of frequencies.}
\item{p}{Vector of initial estimates.}
\item{intensity}{The intensity function of the process: binomial,
binomial exdponential, binomial logistic, binomial total,
Poisson, Poisson exponential, negative binomial, or gen(eralized)
negative binomial.}
\item{type}{Algorithm used for matrix exponentiation: spectral
decomposition or series approximation.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\references{
Faddy, M.J. and Fenlon, J.S. (1999) Stochastic modelling of the
invasion process of nematodes in fly larvae. Applied Statistics 48:
31-37.
}
\author{J.K. Lindsey}
\examples{
y <- rnbinom(100,2,0.6)
fr <- tabulate(y)
pbirth(fr, p=log(-log(0.7)), intensity="Poisson", type="series")
pbirth(fr, p=c(log(-log(0.7)),log(5)),
	intensity="negative binomial", type="series")
pbirth(fr, p=c(log(-log(0.7)),log(5),-1),
	intensity="gen negative binomial", type="series")
}
\keyword{models}

\eof
\name{plot.intensity}
\title{Plot Intensity Functions}
\alias{plot.intensity}
\usage{
plot.intensity(z, ...)
plot.intensity.default(times, censor=1, group=1, colour=TRUE, mix=1,
	ylim=c(0,1), ylab="p", xlab="Time",
	main="Empirical Intensity Function(s)")
}
\description{
Plot the empirical intensity curve for given times between events.
}
\arguments{
\item{times}{Vector of times to events or a list of vectors of such
times for different individuals.}
\item{censor}{Vector of censoring indicators corresponding to the
vector of times or to the last time in each vector of a list.}
\item{group}{Vector indicating to which group each individual
belongs.}
\item{colour}{Use a different colour for each curve.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{km}}, \code{\link[event]{plot.survivor}}
}
\examples{
surv <- rgamma(40,2,scale=5)
cens <- rbinom(40,1,0.9)
treat <- gl(2,20)
plot(km(surv, cens, group=treat), main="",xlab="Months",
	ylab="Probability of deterioration")
plot.dist(km(surv, cens, group=treat))
plot.intensity(km(surv, cens, group=treat),ylab="Risk of deterioration")
}
\keyword{hplot}

\eof
\name{pp}
\title{Create a Point Process Vector from Times between Events}
\alias{pp}
\usage{
pp(y, censor=1)
}
\arguments{
\item{y}{Vector of times.}
\item{cens}{Vector of censoring indicators.}
}
\value{
\code{pp} creates a vector of length \code{sum(y)} of zeroes with a one
at the end of each uncensored time interval for use with
\code{\link[event]{ehr}}.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{bp}}, \code{\link[event]{ehr}},
\code{\link[event]{ident}}, \code{\link[event]{tccov}},
\code{\link[event]{tpast}}, \code{\link[event]{ttime}},
\code{\link[event]{tvcov}}.
}
\examples{
y <- c(5,3,2,4)
py <- pp(y)
py
}
\keyword{manip}

\eof
\name{survkit}
\title{Weibull and Cox Models with Random Effects}
\alias{survkit}
\usage{
survkit(times, censor=NULL, ccov=NULL, tvcov=NULL,
	strata=NULL, id=NULL, model="Weibull", baseline=FALSE,
	residuals=FALSE, survival=NULL, svalues=NULL, valrho=NULL,
	constraints=NULL, impose=NULL, dist=NULL, random=NULL,
	estimate=NULL, moments=FALSE, rule=NULL, pedigree=NULL,
	integrate=NULL, jointmode=FALSE, within=NULL, converge=1.e-8,
	iterlim=100)
}
\description{
\code{survfit} was written in Fortran by Dr. V. Ducrocq (INRA, France:
vincent.ducrocq@dga.jouy.inra.fr) and Dr. J. Soelkner (Vienna:
soelkner@mail.boku.ac.at) to fit Weibull and Cox proportional hazards
models with random effects for very large data sets. This is a
cut-down version adapted to R. The full Survival Kit, including the
manual, can be obtained from http://www.boku.ac.at/nuwi/popgen.
}
\arguments{
\item{times}{Vector of times (events, right-censoring, change in
time-varying covariate, left-truncation).}
\item{censor}{Corresponding vector of censoring indicators. 1: event;
0: censored; -1: change of time-varying covariate; -2: left-truncation
time.}
\item{ccov}{Model formula for time-constant covariates. These may have
one value per individual or one per time. Because of the way factor
variables are handled, interactions must be coded as new variables.}
\item{tvcov}{Model formula for time-varying covariates with one value
per time. There can only be one change-point per individual. Again,
interactions must be coded as new variables.}
\item{strata}{A factor variable specifying stratification. With the
Weibull model, different intercepts and power parameters are
calculated for each stratum. For the Cox model, a different baseline
curve is fitted.}
\item{id}{A variable giving individual identification numbers
(starting at one). If not supplied, all times are assumed to refer to
different individuals.}
\item{model}{Weibull or Cox model, or Kaplan-Meier estimates.}
\item{baseline}{If TRUE, the baseline values are calculated for the
Cox model.}
\item{residuals}{If TRUE, calculate residuals (only for Cox model).}
\item{survival}{Calculate values of the survival function at
\code{quantiles},or at \code{equal}ly-spaced, \code{specific}, or
\code{all} observed times.}
\item{svalues}{A vector of quantile values (between 0 and 100),
spacing and maximum for equally-spaced, or specific times for
\code{survival}.}
\item{valrho}{A fixed value of the Weibull power parameter if it is
not to be estimated.}
\item{constraints}{By default, the category of each factor variable
with the \code{largest} number of events is taken as baseline. Other
options are \code{none} which gives values around the mean and
\code{find}. See also, \code{impose}.}
\item{impose}{A list of a vector of variable names and a corresponding
vector of their baseline category numbers. Any factor variables not
given will have their first category as baseline.}
\item{dist}{The distribution of the random effect: loggamma, normal,
or multivariate (normal).}
\item{random}{A factor variable specifying the random effect.}
\item{estimate}{One fixed value for the mode of the variance of the
random effect or three values if the mode is to be estimated: lower
and upper bounds, and precision.}
\item{moments}{Estimate the first three moments of the random effect
as well as the mode.}
\item{rule}{For the multivariate normal random effect, the genetic
relationships: \code{usual}, \code{mgs} (sire or father model), or
\code{sire.dam} (father and mother).}
\item{pedigree}{A matrix with four columns required for the
multivariate normal random effect, containing the individual
id, the sex, the father's category, and the mother's category.}
\item{integrate}{A factor variable to integrate out as the log-gamma
random effect in a Weibull model. (Not available for the Cox model.)}
\item{jointmode}{If TRUE, the log-gamma variance parameter is
estimated simultaneously with the other parameters using the
information in \code{estimate}. Otherwise, a fixed value, given in
\code{estimate} is assumed.}
\item{within}{A second factor variable (within the \code{integrate}
variable) to integrate out.}
\item{converge}{The convergence criterion, by default 1.e-8.}
\item{iterlim}{Maximum number of iterations.}
}
\author{V. Ducrocq, J. Soelkner, and J.K. Lindsey}
\seealso{
\code{\link[event]{coxre}}, \code{\link[event]{kalsurv}}.
}
\examples{
# y <- trunc(rweibull(20,2,20))
y <- c(6,22,43,16,7,6,15,35,10,9,18,34,7,13,10,17,14,19,11,13)
# cens <- rbinom(20,1,0.9)
cens <- c(1,1,1,1,0,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1)
id <- gl(2,10)
# x <- rnorm(20)
x <- c(1.82881379,1.06606868,0.70877744,-0.09932880,-0.60626148,-0.75371046,
  0.23884069,0.51199483,-0.73060095,-0.93222151,2.27947539,-0.73855454,
 -0.36412735,-0.89122114,-0.05025962,-0.10001587,1.11460865,-1.87315971,
 -0.11280052,-1.6880509)
# Kaplan-Meier estimates
survkit(y, censor=cens, model="Kaplan")
# null Weibull model
survkit(y, censor=cens)
# one time-constant covariate
survkit(y, censor=cens, ccov=~x)
# stratify
survkit(y, censor=cens, ccov=~x, strata=id)
# estimate a normal random effect
survkit(y, censor=cens, ccov=~x, random=id, dist="normal",
	estimate=c(0.1,10,0.01), moments=TRUE)
# try a fixed value for the normal random effect
survkit(y, censor=cens, ccov=~x, random=id, dist="normal",
	estimate=1.3)
# estimate a log-gamma random effect
survkit(y, censor=cens, ccov=~x, random=id, dist="loggamma",
	estimate=c(0.1,10,0.01))
# estimate a log-gamma random effect by integrating it out
survkit(y, censor=cens, ccov=~x, dist="loggamma", estimate=1.4,
	integ=id, jointmode=TRUE)
# try a fixed value of the log-gamma random effect, integrating it out
survkit(y, censor=cens, ccov=~x, dist="loggamma", estimate=1,
	integ=id)
#
# Cox model with one time-constant covariate
print(z <- survkit(y, censor=cens, ccov=~x, model="Cox", residuals=TRUE,
	baseline=TRUE))
residuals(z)
baseline(z)
# obtain the quantiles
print(z <- survkit(y, censor=cens, ccov=~x, model="Cox",
	survival="quantiles", svalues=seq(10,90,by=10)))
survival(z)
# estimate a log-gamma random effect
survkit(y, censor=cens, ccov=~x, model="Cox", random=id,
	dist="loggamma", estimate=c(0.1,10,0.01))
}
\keyword{models}

\eof
\name{tccov}
\title{Create a Vector of Time-constant Covariates for a Point Process}
\alias{tccov}
\usage{
tccov(y, x, id)
}
\arguments{
\item{y}{Vector of times.}
\item{x}{Vector covariate.}
\item{id}{Vector of corresponding individual identifiers for who had
which sequence of times.}
}
\value{
\code{tccov} creates a vector of length \code{sum(y)} of time-constant
covariates for use with \code{\link[event]{ehr}}. \code{id} must be numbered
consecutively. \code{x} must have one value for each distinct \code{id},
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{bp}}, \code{\link[event]{ehr}},
\code{\link[event]{ident}}, \code{\link[event]{pp}},
\code{\link[event]{tpast}}, \code{\link[event]{ttime}},
\code{\link[event]{tvcov}}.
}
\examples{
y <- c(5,3,2,4)
id <- c(1,1,2,2)
x <- c(5.2,3.1)
xcov <- tccov(y, x, id)
xcov
}
\keyword{manip}

\eof
\name{tpast}
\title{Create a Vector of Times Past since Previous Events for a Point Process}
\alias{tpast}
\usage{
tpast(y)
}
\arguments{
\item{y}{Vector of times.}
}
\value{
\code{tpast} creates a vector of length \code{sum(y)} of times since the
immediately preceding event occurred for use with \code{\link[event]{ehr}}.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{bp}}, \code{\link[event]{ehr}},
\code{\link[event]{ident}}, \code{\link[event]{pp}},
\code{\link[event]{tccov}}, \code{\link[event]{ttime}},
\code{\link[event]{tvcov}}.
}
\examples{
y <- c(5,3,2,4)
ptime <- tpast(y)
ptime
}
\keyword{manip}

\eof
\name{ttime}
\title{Create a Vector of Total Time Elapsed for each Individual for a
Point Process}
\alias{ttime}
\usage{
ttime(y, id)
}
\arguments{
\item{y}{Vector of times.}
\item{id}{Vector of corresponding individual identifiers for who had
which sequence of times.}
}
\value{
\code{ttime} creates a vector of length \code{sum(y)} of times since
each individual began for use with \code{\link[event]{ehr}}.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{bp}}, \code{\link[event]{ehr}},
\code{\link[event]{ident}}, \code{\link[event]{pp}},
\code{\link[event]{tccov}}, \code{\link[event]{tpast}},
\code{\link[event]{tvcov}}.
}
\examples{
y <- c(5,3,2,4)
id <- c(1,1,2,2)
itime <- ttime(y, id)
itime
}
\keyword{manip}

\eof
\name{tvcov}
\title{Create a Vector of Time-varying Covariates for a Point Process}
\alias{tvcov}
\usage{
tvcov(y, x, tx)
}
\arguments{
\item{y}{Vector of times.}
\item{x}{Vector covariate.}
\item{tx}{Vector of times at which x changes.}
}
\value{
\code{tvcov} creates a vector of length \code{sum(y)} of time-varying
covariates for use with \code{\link[event]{ehr}}. It may also be used to create
weight vectors.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[event]{bp}}, \code{\link[event]{ehr}},
\code{\link[event]{ident}}, \code{\link[event]{pp}},
\code{\link[event]{tccov}}, \code{\link[event]{tpast}},
\code{\link[event]{ttime}}.
}
\examples{
y <- c(5,3,2,4)
x <- c(1,2,2,1,2,2,1)
tx <- c(2,3,1,2,2,2,2)
zcov <- tvcov(y, x, tx)
zcov
}
\keyword{manip}

\eof
