\name{binnest}
\title{Binary Random Effects Models with Two Levels of Nesting}
\alias{binnest}
\usage{
binnest(response, totals=NULL, nest=NULL, ccov=NULL, tvcov=NULL,
	mu=~1, re1=~1, re2=~1, preg=NULL, pre1=NULL, pre2=NULL,
	binom.mix=c(10,10), binom.prob=c(0.5,0.5), fcalls=900,
	eps=0.01, print.level=0)
}
\description{
\code{binnest} is designed to handle binary and binomial data with two
levels of nesting. The first level is the individual and the second
will consist of clusters within individuals.

The variance components at the two levels can only depend on the
covariates if \code{response} has class, \code{repeated}.
}
\arguments{
\item{response}{A list of three column matrices with counts,
corresponding totals (not necessary if the response is binary), and
(second-level) nesting indicator for each individual, one matrix or
dataframe of such counts, or an object of class, response (created by
\code{\link[rmutil]{restovec}}) or repeated (created by
\code{\link[rmutil]{rmna}}).}
\item{totals}{If \code{response} is a matrix or dataframe, a
corresponding matrix or dataframe of totals (not necessary if the
response is binary). Ignored otherwise.}
\item{nest}{If \code{response} is a matrix or dataframe, a
corresponding matrix or dataframe of nesting indicators. Ignored
otherwise.}
\item{ccov}{If \code{response} is a matrix, dataframe, list, or object
of class, \code{response}, a matrix of time-constant covariates or an
object of class, \code{tccov} (created by \code{\link[rmutil]{tcctomat}}). All
of these covariates are used in the fixed effects part of the model.
Ignored if response has class, \code{repeated}.}
\item{tvcov}{If \code{response} is a matrix, dataframe, list, or object
of class, \code{response}, an object of class, \code{tvcov} (created
by \code{\link[rmutil]{tvctomat}}). All of these covariates are used in the
fixed effects part of the model. Ignored if response has class,
\code{repeated}.}
\item{mu}{If \code{response} has class, \code{repeated}, a formula
beginning with ~, specifying a linear regression function for the
fixed effects, in the Wilkinson and Rogers notation, containing
selected covariates in the response object. (A logit link is
assumed.)}
\item{re1}{If \code{response} has class, \code{repeated}, a formula
beginning with ~, specifying a linear regression function for the
variance of the first level of nesting, in the Wilkinson and Rogers
notation, containing selected covariates in the response object. If
NULL, a random effect is not fitted at this level. (A log link is
assumed.)}
\item{re2}{If \code{response} has class, \code{repeated}, a formula
beginning with ~, specifying a linear regression function for the
variance of the second level of nesting, in the Wilkinson and Rogers
notation, containing selected covariates in the response object. If
NULL, a random effect is not fitted at this level. (A log link is
assumed.)}
\item{preg}{Initial parameter estimates for the fixed effect
regression model: either the model specified by \code{mu} or else the
intercept plus one for each covariate in \code{ccov} and
\code{tvcov}.}
\item{pre1}{Initial parameter estimates for the first level of nesting
variance model: either the model specified by \code{re1} or just the
intercept. If NULL, a random effect is not fitted at this level.}
\item{pre2}{Initial parameter estimates for the second level of nesting
variance model: either the model specified by \code{re1} or just the
intercept. If NULL, a random effect is not fitted at this level.}
\item{binom.mix}{A vector of two values giving the totals for the
binomial distributions used as the mixing distributions at the two
levels of nesting.}
\item{binom.prob}{A vector of two values giving the probabilities in
the binomial distributions used as the mixing distributions at the two
levels of nesting. If they are 0.5, the mixing distributions
approximate normal mixing distributions; otherwise, they are skewed.}
\item{fcalls}{Number of function calls allowed.}
\item{eps}{Convergence criterion.}
\item{print.level}{If 1, the iterations are printed out.}
}
\references{
Ten Have, T.R., Kunselman, A.R., and Tran, L. (1999) Statistics in
Medicine 18, 947-960.
}
\value{
A list of classes \code{binnest} is returned.
}
\author{T.R. Ten Have and J.K. Lindsey}
\seealso{
\code{\link[repeated]{gar}}, \code{\link[rmutil]{read.list}},
\code{\link[rmutil]{restovec}}, \code{\link[rmutil]{rmna}},
\code{\link[rmutil]{tcctomat}}, \code{\link[rmutil]{tvctomat}}.
}
\examples{
#y <- rbind(matrix(rbinom(20,1,0.6), ncol=4),
#	matrix(rbinom(20,1,0.4), ncol=4))
y <- matrix(c(1,1,0,1,1,1,1,0,1,1,1,1,1,1,1,1,0,1,1,0,0,1,0,1,1,0,1,0,
	1,1,1,1,1,1,1,1,0,1,1,0),nrow=10,ncol=4,byrow=TRUE)
resp <- restovec(y, nest=1:4, times=FALSE)
ccov <- tcctomat(c(rep(0,5),rep(1,5)), name="treatment")
reps <- rmna(resp, ccov=ccov)
# two random effects
binnest(reps, mu=~treatment, preg=c(1,0), pre1=1, pre2=1)
# first level random effect only
binnest(reps, mu=~treatment, preg=c(1,-1), pre1=1)
# second level random effect only
binnest(reps, mu=~treatment, preg=c(1,-1), pre2=1)
}
\keyword{models}

\eof
\name{biv.betab}
\title{Bivariate Beta-binomial Regression Models}
\alias{biv.betab}
\usage{
biv.betab(freq, x=NULL, p, depend=TRUE, print.level=0,
	typsiz=abs(p), ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p),
	steptol=0.00001, iterlim=100, fscale=1)
}
\description{
\code{biv.betab} fits dependent (logit) linear regression models to a
bivariate beta-binomial distribution.
}
\arguments{
\item{freq}{A matrix containing four columns corresponding to 00, 01,
10, and 11 responses.}
\item{x}{A matrix of explanatory variables, containing pairs of
columns, one for each response, and the same number of rows as freq.}
\item{p}{Initial parameter estimates: intercept, dependence (if depend
is TRUE, and one for each pair of columns of x.}
\item{depend}{If FALSE, the independence (logistic) model is fitted.}
\item{other}{Arguments for nlm.}
}
\value{
A list of class \code{bivbetab} is returned.
}
\author{J.K. Lindsey}
\examples{
y <- matrix(  c( 2, 1, 1,13,
		 4, 1, 3, 5,
		 3, 3, 1, 4,
		15, 8, 1, 6),ncol=4,byrow=TRUE)
first <- c(0,0,1,1)
second <- c(0,1,0,1)
self <- cbind(first,second)
other <- cbind(second,first)
biv.betab(y,cbind(self,other),p=c(-1,2,1,1))
# independence
biv.betab(y,cbind(self,other),p=c(-1,1,1),dep=FALSE)
}
\keyword{models}

\eof
\name{biv.binom}
\title{Marginal Bivariate Binomial Regression Models}
\alias{biv.binom}
\usage{
biv.binom(freq, marg1=~1, marg2=~1, interaction=~1, pmarg1=1,
	pmarg2=1,pinteraction=1, print.level=0, typsiz=abs(p),
	ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p),
	steptol=0.00001, iterlim=100, fscale=1)
}
\description{
\code{biv.binom} fits (logit) linear regression models to a marginal
bivariate binomial distribution. The covariates must be of length K,
that is the number of 2x2 tables.
}
\arguments{
\item{freq}{A four-column matrix containing K 2x2 frequency tables.}
\item{marg1}{The model formula for the first margin.}
\item{marg2}{The model formula for the second margin.}
\item{interaction}{The model formula for the interaction.}
\item{pmarg1}{Initial parameter estimates for the first margin regression.}
\item{pmarg2}{Initial parameter estimates for the second margin regression.}
\item{pinteraction}{Initial parameter estimates for the interaction
regression.}
\item{other}{Arguments for nlm.}
}
\value{
A list of class \code{bivbinom} is returned.
}
\author{J.K. Lindsey}}
\examples{
# 5 2x2 tables
Freq <- matrix(rpois(20,10),ncol=4)
x <- c(6,8,10,12,14)
print(z <- biv.binom(Freq,marg1=~x,marg2=~x,inter=~x,pmarg1=c(-2,0.08),
	pmarg2=c(-2,0.1),pinter=c(3,0)))
}
\keyword{models}

\eof
\name{capture}
\title{Capture-recapture Models}
\alias{capture}
\usage{
capture(z, n)
}
\description{
\code{capture} fits the Cormack capture-recapture model to \code{n} sample
periods. Set \code{n} to the appropriate value and type \code{eval(setup)}.

\code{n <- periods} # number of periods

\code{eval(setup)}

This produces the following variables -

\code{p[i]}: logit capture probabilities,

\code{pbd}: constant capture probability,

\code{d[i]}: death parameters,

\code{b[i]}: birth parameters,

\code{pw}: prior weights.

Then set up a Poisson model for log linear models:

\code{z <- glm(y~model, family=poisson, weights=pw)}

and call the function, \code{capture}.

If there is constant effort, then all estimates are correct.
Otherwise, \code{n[1]}, \code{p[1]}, \code{b[1]}, are correct only if
there is no birth in period 1.  \code{n[s]}, \code{p[s]}, are correct
only if there is no death in the last period.  \code{phi[s-1]} is
correct only if effort is constant in \code{(s-1, s)}.  \code{b[s-1]}
is correct only if \code{n[s]} and \code{phi[s-1]} both are.
}
\arguments{
\item{z}{A Poisson generalized linear model object.}
\item{n}{The number of repeated observations.}
}
\value{
\code{capture} returns a matrix containing the estimates.
}
\author{J.K. Lindsey}
\examples{
y <- c(0,1,0,0,0,1,0,1,0,0,0,1,0,0,0,14,1,1,0,2,1,2,1,16,0,2,0,11,
	2,13,10,0)
n <- 5
eval(setup)
# closed population
print(z0 <- glm(y~p1+p2+p3+p4+p5, family=poisson, weights=pw))
# deaths and emigration only
print(z1 <- update(z0, .~.+d1+d2+d3))
# immigration only
print(z2 <- update(z1, .~.-d1-d2-d3+b2+b3+b4))
# deaths, emigration, and immigration
print(z3 <- update(z2, .~.+d1+d2+d3))
# add trap dependence
print(z4 <- update(z3, .~.+i2+i3))
# constant capture probability over the three middle periods
print(z5 <- glm(y~p1+pbd+p5+d1+d2+d3+b2+b3+b4, family=poisson, weights=pw))
# print out estimates
capture(z5, n)
}
\keyword{models}

\eof
\name{catmiss}
\title{Marginal Probabilities for Categorical Repeated Measurements with
Missing Data}
\alias{catmiss}
\usage{
catmiss(response, frequency, ccov=NULL)
}
\description{
\code{catmiss} calculates the marginal probabilities of
repeated responses. If there are missing values, it gives both the
complete data estimates and the estimates using all data. It is
useful, for example, when a log linear model is fitted; the resulting
fitted values can be supplied to \code{catmiss} to obtain the
estimates of the marginal probabilities for the model. (Note however
that the standard errors do not take into account the fitting of the
model.)
}
\arguments{
\item{response}{A matrix with one column for each of the repeated
measures and one row for each possible combination of responses,
including the missing values, indicated by NAs.}
\item{frequency}{A vector containing the frequencies. Its length must
be a multiple of the number of rows of \code{response}. Responses are
arranged in blocks corresponding to the various possible combinations
of values of the explanatory variables.}
\item{ccov}{An optional matrix containing the explanatory variables
(time-constant covariates) as columns, with one line per block of
responses in \code{frequency}. Thus, the number of rows of response
times the number of rows of \code{ccov} equals the length of
\code{frequency}.}
}
\value{
A matrix with the probabilities and their standard errors is returned.
}
\author{J.K. Lindsey}
\seealso{
\code{\link{glm}}, \code{\link[gnlm]{nordr}}
}
\examples{
y <- rpois(27,15)
r1 <- gl(3,1,27)
r2 <- gl(3,3,27)
r3 <- gl(3,9)
# r1, r2, and r3 are factor variables with 3 indicating missing
# independence model with three binary repeated measures
# with missing values
print(z <- glm(y~r1+r2+r3, family=poisson))
# obtain marginal estimates (no observations with 3 missing values)
resp <- cbind(codes(r1), codes(r2), codes(r3))[1:26,]
resp <- ifelse(resp==3, NA, resp)
catmiss(resp, y[1:26])
}
\keyword{models}

\eof
\name{chidden}
\title{Continuous-time Hidden Markov Chain Models}
\alias{chidden}
\usage{
chidden(response=NULL, totals=NULL, times=NULL, distribution="Bernoulli",
	mu=NULL, cmu=NULL, tvmu=NULL, pgamma, pmu=NULL, pcmu=NULL, ptvmu=NULL,
	pshape=NULL, pfamily=NULL, par=NULL, pintercept=NULL, delta=NULL,
	envir=parent.frame(), print.level=0, ndigit=10,
	gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100, typsiz=abs(p),
	stepmax=10*sqrt(p%*%p))
}
\description{
\code{chidden} fits a two or more state hidden Markov chain model with
a variety of distributions in continuous time. All series on different
individuals are assumed to start at the same time point. If the time
points are equal, discrete steps, use \code{\link[repeated]{hidden}}.

The time-discretized Poisson process is a continuous-time hidden
Markov model for Poisson processes where time is then discretized and
only presence or absence of one or more events is recorded in each,
perhaps unequally-spaced, discrete interval.

For quantitative responses, specifying \code{par} allows an `observed'
autoregression to be fitted as well as the hidden Markov chain.

All functions and formulae for the location parameter are on the
(generalized) logit scale for the Bernoulli, binomial, and multinomial
distributions. Those for intensities of the discretized Poisson
process are on the log scale.

If \code{cmu} and \code{tvmu} are used, these two mean functions are
additive so that interactions between time-constant and time-varying
variables are not possible.

The algorithm will run more quickly if the most frequently occurring
time step is scaled to be equal to unity.

The object returned can be plotted to give the probabilities of being
in each hidden state at each time point. See \code{\link[repeated]{hidden}}
for details. For distributions other than the multinomial, proportional
odds, and continuation ratio, the (recursive) predicted values can be
plotted using \code{\link[rmutil]{mprofile}} and
\code{\link[rmutil]{iprofile}}.
}
\arguments{
\item{response}{A list of two or three column matrices with counts or
category indicators, times, and possibly totals (if the distribution
is binomial), for each individual, one matrix or dataframe of counts,
or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here. If there is only one series, a vector of
responses may be supplied instead.

Multinomial and ordinal categories must be integers numbered from 0.}
\item{totals}{If response is a matrix, a corresponding matrix of
totals if the distribution is binomial. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{times}{If \code{response} is a matrix, a vector of corresponding
times, when they are the same for all individuals. Ignored if response
has class, \code{response} or \code{repeated}.}
\item{distribution}{Bernoulli, Poisson, multinomial, proportional odds,
continuation ratio, binomial, exponential, beta binomial, negative
binomial, normal, inverse Gauss, logistic, gamma, Weibull, Cauchy,
Laplace, Levy, Pareto, gen(eralized) gamma, gen(eralized) logistic,
Hjorth, Burr, gen(eralized) Weibull, gen(eralized) extreme value,
gen(eralized) inverse Gauss, power exponential, skew Laplace,
Student t, or (time-)discretized Poisson process. (For definitions of
distributions, see the corresponding [dpqr]distribution help.)}
\item{mu}{A general location function with two possibilities: (1) a
list of formulae (with parameters having different names) or functions
(with one parameter vector numbering for all of them) each returning
one value per observation; or (2) a single formula or function which
will be used for all states (and all categories if multinomial) but
with different parameter values in each so that pmu must be a vector
of length the number of unknowns in the function or formula times the
number of states (times the number of categories minus one if
multinomial).}
\item{cmu}{A time-constant location function with three possibilities:
(1) a list of formulae (with parameters having different names) or
functions (with one parameter vector numbering for all of them) each
returning one value per individual; (2) a single formula or function
which will be used for all states (and all categories if multinomial)
but with different parameter values in each so that pcmu must be a
vector of length the number of unknowns in the function or formula
times the number of states (times the number of categories minus one
if multinomial); or (3) a function returning an array with one row for
each individual, one column for each state of the hidden Markov chain,
and, if multinomial, one layer for each category but the last. If
used, this function or formula should contain the intercept. Ignored
if \code{mu} is supplied.}
\item{tvmu}{A time-varying location function with three possibilities:
(1) a list of formulae (with parameters having different names) or
functions (with one parameter vector numbering for all of them) each
returning one value per time point; (2) a single formula or function
which will be used for all states (and all categories if multinomial)
but with different parameter values in each so that ptvmu must be a
vector of length the number of unknowns in the function or formula
times the number of states (times the number of categories minus one
if multinomial); or (3) a function returning an array with one row for
each time point, one column for each state of the hidden Markov chain,
and, if multinomial, one layer for each category but the last. This
function or formula is usually a function of time; it is the same for
all individuals. It only contains the intercept if \code{cmu} does
not. Ignored if \code{mu} is supplied.}
\item{pgamma}{A square \code{mxm} matrix of initial estimates of the
continuous-time hidden Markov transition matrix, where \code{m} is the number
of hidden states. Rows can either sum to zero or the diagonal elements
can be zero, in which case they will be replaced by minus the sum of the
other values on the rows. If the matrix contains zeroes off diagonal,
these are fixed and not estimated.}
\item{pmu}{Initial estimates of the unknown parameters in \code{mu}.}
\item{pcmu}{Initial estimates of the unknown parameters in \code{cmu}.}
\item{ptvmu}{Initial estimates of the unknown parameters in \code{tvmu}.}
\item{pshape}{Initial estimate(s) of the dispersion parameter, for
those distributions having one. This can be one value or a vector with
a different value for each state.}
\item{pfamily}{Initial estimate of the family parameter, for
those distributions having one.}
\item{par}{Initial estimate of the autoregression parameter.}
\item{pintercept}{For multinomial, proportional odds, and continuation
ratio models, \code{p-2} initial estimates for intercept contrasts
from the first intercept, where \code{p} is the number of categories.}
\item{delta}{Scalar or vector giving the unit of measurement (always
one for discrete data) for each response value, set to unity by
default. For example, if a response is measured to two decimals,
delta=0.01. If the response is transformed, this must be multiplied by
the Jacobian. For example, with a log transformation,
\code{delta=1/response}. Ignored if response has class, \code{response} or
\code{repeated}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}.
If \code{response} has class \code{repeated}, it is used as the
environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of classes \code{hidden} and \code{recursive} (unless
multinomial, proportional odds, or continuation ratio) is returned
that contains all of the relevant information calculated, including
error codes.
}
\author{J.K. Lindsey}
\references{
MacDonald, I.L. and Zucchini, W. (1997) Hidden Markov and other Models
for Discrete-valued Time Series. Chapman & Hall.

For time-discretized Poisson processes, see

Davison, A.C. and Ramesh, N.I. (1996) Some models for discretized
series of events. JASA 91: 601-609.
}
\seealso{
\code{\link[repeated]{gar}}, \code{\link[repeated]{gnlmm}},
\code{\link[repeated]{hidden}}, \code{\link[rmutil]{iprofile}},
\code{\link[repeated]{kalcount}}, \code{\link[rmutil]{mexp}},
\code{\link[rmutil]{mprofile}}, \code{\link[repeated]{nbkal}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}.
}
\examples{
# model for one randomly-generated binary series
y <- c(rbinom(10,1,0.1), rbinom(10,1,0.9))
mu <- function(p) array(p, c(1,2))
print(z <- chidden(y, times=1:20, dist="Bernoulli",
	pgamma=matrix(c(-0.1,0.2,0.1,-0.2),ncol=2),
	cmu=mu, pcmu=c(-2,2)))
# or equivalently
print(z <- chidden(y, times=1:20, dist="Bernoulli",
	pgamma=matrix(c(-0.1,0.2,0.1,-0.2),ncol=2),
	cmu=~1, pcmu=c(-2,2)))
# or
print(z <- chidden(y, times=1:20, dist="Bernoulli",
	pgamma=matrix(c(-0.1,0.2,0.1,-0.2),ncol=2),
	mu=~rep(a,20), pmu=c(-2,2)))
mexp(z$gamma)
par(mfcol=c(2,2))
plot(z)
plot(iprofile(z), lty=2)
plot(mprofile(z), add=TRUE)
print(z <- chidden(y, times=(1:20)*2, dist="Bernoulli",
	pgamma=matrix(c(-0.05,0.1,0.05,-0.1),ncol=2),
	cmu=~1, pcmu=c(-2,2)))
mexp(z$gamma) \%*\% mexp(z$gamma)
plot(z)
plot(iprofile(z), lty=2)
plot(mprofile(z), add=TRUE)
}
\keyword{models}

\eof
\name{cmcre}
\title{Continuous-time Two-state Markov Processes with Random Effect}
\alias{cmcre}
\usage{
cmcre(response, covariate=NULL, parameters, pcov=NULL, gradient=FALSE,
	hessian=FALSE, print.level=0, ndigit=10, gradtol=0.00001,
	steptol=0.00001, iterlim=100, fscale=1, typsiz=abs(parameters),
	stepmax=parameters)
}
\description{
\code{cmcre} fits a two-state Markov process in continuous time,
possibly with one or two random effects and/or one covariate.
}
\arguments{
\item{response}{A six-column matrix. Column 1: subject identification
(subjects can occupy several rows); column 2: time gap between
events; columns 3-6: transition matrix frequencies.}
\item{covariate}{An optional vector of length equal to the number of
rows of \code{response} upon which the equilibrium probability may
depend.}
\item{parameters}{Initial parameter estimates. The number of them
determines the model fitted (minimum 2, yielding an ordinary Markov
process). 1: beta1=log(-log(equilibrium probability)); 2: beta2=log(sum of
transition intensities); 3: log(tau1)=log(random effect variance for
equilibrium probability); 4: log(tau2)=log(random effect variance for sum
of transition intensities).}
\item{pcov}{Initial parameter estimate for the covariate influencing
the equilibrium probability: exp(-exp(beta1+beta*covariate)).}
\item{gradient}{If TRUE, analytic gradient is used (with
accompanying loss of speed).}
\item{hessian}{If TRUE, analytic hessian is used (with
accompanying loss of speed).}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\references{
Cook, R.J. (1999) A mixed model for two-state Markov processes under
panel observations. Biometrics 55, 915-920.
}
\value{
A list of class \code{cmcre} is returned.
}
\author{R.J. Cook and J.K. Lindsey}
\seealso{
\code{\link[repeated]{chidden}}, \code{\link[repeated]{hidden}}.
}
\examples{
# 12 subjects observed at intervals of 7 days
y <- matrix(c(1,7,1,2,3,5,
	2,7,10,2,2,0,
	3,7,7,0,1,1,
	4,7,2,1,0,7,
	5,7,1,1,1,11,
	6,7,5,4,4,1,
	7,7,1,1,1,8,
	8,7,2,3,4,2,
	9,7,9,0,0,0,
	10,7,0,1,2,8,
	11,7,8,2,2,1,
	12,7,9,2,2,1),ncol=6, byrow=TRUE)
# ordinary Markov process
cmcre(y, par=c(-0.2,-1))
# random effect for the equilibrium probability
cmcre(y, par=c(-0.1,-2,-0.8))
# random effects for the equilibrium probability and sum of transition
#   intensities
cmcre(y, par=c(-0.1,-1.4,-0.5,-1))
}
\keyword{models}

\eof
\name{cphidden}
\title{Changepoint Location using a Continuous-time Two-state Hidden Markov Chain}
\alias{cphidden}
\usage{
cphidden(response=NULL, totals=NULL, times=NULL, distribution="Bernoulli",
	mu=NULL, cmu=NULL, tvmu=NULL, pgamma, pmu=NULL, pcmu=NULL, ptvmu=NULL,
	pshape=NULL, pfamily=NULL, par=NULL, pintercept=NULL, delta=NULL,
	envir=parent.frame(), print.level=0, ndigit=10,
	gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100, typsiz=abs(p),
	stepmax=10*sqrt(p%*%p))
}
\description{
\code{cphidden} fits a two-state hidden Markov chain model with
a variety of distributions in continuous time in order to locate a
changepoint in the chosen distribution. All series on different
individuals are assumed to start at the same time point.

For quantitative responses, specifying \code{par} allows an `observed'
autoregression to be fitted as well as the hidden Markov chain.

All functions and formulae for the location parameter are on the
(generalized) logit scale for the Bernoulli, binomial, and multinomial
distributions.

If \code{cmu} and \code{tvmu} are used, these two mean functions are
additive so that interactions between time-constant and time-varying
variables are not possible.

The algorithm will run more quickly if the most frequently occurring
time step is scaled to be equal to unity.

The object returned can be plotted to give the probabilities of being
in each hidden state at each time point. See \code{\link[repeated]{hidden}}
for details. For distributions other than the multinomial, proportional
odds, and continuation ratio, the (recursive) predicted values can be
plotted using \code{\link[rmutil]{mprofile}} and
\code{\link[rmutil]{iprofile}}.
}
\arguments{
\item{response}{A list of two or three column matrices with counts or
category indicators, times, and possibly totals (if the distribution
is binomial), for each individual, one matrix or dataframe of counts,
or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here. If there is only one series, a vector of
responses may be supplied instead.

Multinomial and ordinal categories must be integers numbered from 0.}
\item{totals}{If response is a matrix, a corresponding matrix of
totals if the distribution is binomial. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{times}{If \code{response} is a matrix, a vector of corresponding
times, when they are the same for all individuals. Ignored if response
has class, \code{response} or \code{repeated}.}
\item{distribution}{Bernoulli, Poisson, multinomial, proportional odds,
continuation ratio, binomial, exponential, beta binomial, negative
binomial, normal, inverse Gauss, logistic, gamma, Weibull, Cauchy,
Laplace, Levy, Pareto, gen(eralized) gamma, gen(eralized) logistic,
Hjorth, Burr, gen(eralized) Weibull, gen(eralized) extreme value,
gen(eralized) inverse Gauss, power exponential, skew Laplace, or
Student t. (For definitions of
distributions, see the corresponding [dpqr]distribution help.)}
\item{mu}{A general location function with two possibilities: (1) a
list of formulae (with parameters having different names) or functions
(with one parameter vector numbering for all of them) each returning
one value per observation; or (2) a single formula or function which
will be used for all states (and all categories if multinomial) but
with different parameter values in each so that pmu must be a vector
of length the number of unknowns in the function or formula times the
number of states (times the number of categories minus one if
multinomial).}
\item{cmu}{A time-constant location function with three possibilities:
(1) a list of formulae (with parameters having different names) or
functions (with one parameter vector numbering for all of them) each
returning one value per individual; (2) a single formula or function
which will be used for all states (and all categories if multinomial)
but with different parameter values in each so that pcmu must be a
vector of length the number of unknowns in the function or formula
times the number of states (times the number of categories minus one
if multinomial); or (3) a function returning an array with one row for
each individual, one column for each state of the hidden Markov chain,
and, if multinomial, one layer for each category but the last. If
used, this function or formula should contain the intercept. Ignored
if \code{mu} is supplied.}
\item{tvmu}{A time-varying location function with three possibilities:
(1) a list of formulae (with parameters having different names) or
functions (with one parameter vector numbering for all of them) each
returning one value per time point; (2) a single formula or function
which will be used for all states (and all categories if multinomial)
but with different parameter values in each so that ptvmu must be a
vector of length the number of unknowns in the function or formula
times the number of states (times the number of categories minus one
if multinomial); or (3) a function returning an array with one row for
each time point, one column for each state of the hidden Markov chain,
and, if multinomial, one layer for each category but the last. This
function or formula is usually a function of time; it is the same for
all individuals. It only contains the intercept if \code{cmu} does
not. Ignored if \code{mu} is supplied.}
\item{pgamma}{An initial estimate of the transition intensity between
the two states in the continuous-time hidden Markov chain.}
\item{pmu}{Initial estimates of the unknown parameters in \code{mu}.}
\item{pcmu}{Initial estimates of the unknown parameters in \code{cmu}.}
\item{ptvmu}{Initial estimates of the unknown parameters in \code{tvmu}.}
\item{pshape}{Initial estimate(s) of the dispersion parameter, for
those distributions having one. This can be one value or a vector with
a different value for each state.}
\item{pfamily}{Initial estimate of the family parameter, for
those distributions having one.}
\item{par}{Initial estimate of the autoregression parameter.}
\item{pintercept}{For multinomial, proportional odds, and continuation
ratio models, \code{p-2} initial estimates for intercept contrasts
from the first intercept, where \code{p} is the number of categories.}
\item{delta}{Scalar or vector giving the unit of measurement (always
one for discrete data) for each response value, set to unity by
default. For example, if a response is measured to two decimals,
delta=0.01. If the response is transformed, this must be multiplied by
the Jacobian. For example, with a log transformation,
\code{delta=1/response}. Ignored if response has class, \code{response} or
\code{repeated}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}.
If \code{response} has class \code{repeated}, it is used as the
environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of classes \code{hidden} and \code{recursive} (unless
multinomial, proportional odds, or continuation ratio) is returned
that contains all of the relevant information calculated, including
error codes.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[repeated]{chidden}}, \code{\link[repeated]{gar}},
\code{\link[repeated]{gnlmm}},
\code{\link[repeated]{hidden}}, \code{\link[rmutil]{iprofile}},
\code{\link[repeated]{kalcount}}, \code{\link[rmutil]{mexp}},
\code{\link[rmutil]{mprofile}}, \code{\link[repeated]{nbkal}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}.
}
\examples{
# model for one randomly-generated binary series
y <- c(rbinom(10,1,0.1), rbinom(10,1,0.9))
mu <- function(p) array(p, c(1,2))
print(z <- cphidden(y, times=1:20, dist="Bernoulli",
	pgamma=0.1,cmu=mu, pcmu=c(-2,2)))
# or equivalently
print(z <- cphidden(y, times=1:20, dist="Bernoulli",
	pgamma=0.2,cmu=~1, pcmu=c(-2,2)))
# or
print(z <- cphidden(y, times=1:20, dist="Bernoulli",
	pgamma=0.2,mu=~rep(a,20), pmu=c(-2,2)))
mexp(z$gamma)
par(mfcol=c(2,2))
plot(z)
plot(iprofile(z), lty=2)
print(z <- cphidden(y, times=(1:20)*2, dist="Bernoulli",
	pgamma=0.1,cmu=~1, pcmu=c(-2,2)))
mexp(z$gamma) \%*\% mexp(z$gamma)
plot(z)
plot(iprofile(z), lty=2)
}
\keyword{models}

\eof
\name{gar}
\title{Generalized Autoregression Models}
\usage{
gar(response=NULL, distribution="normal", times=NULL, totals=NULL,
	censor=NULL, delta=NULL, mu=NULL, shape=NULL, depend=NULL,
	shfn=FALSE, common=FALSE, preg=NULL, pshape=NULL, pdepend=NULL,
	parch=NULL, arch="additive", transform="identity",
	link="identity", autocorr="exponential", order=1,
	envir=parent.frame(), print.level=0, ndigit=10,
	gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100,
	typsiz=abs(p), stepmax=10*sqrt(p%*%p))
volatility(z, nind=NULL)
}
\alias{gar}
\alias{volatility.gar}
\description{
\code{gar} fits a first- or second-order generalized autoregression,
possibly with Kalman update over time (first-order only).

Nonlinear regression models can be supplied as formulae where
parameters are unknowns in which case factor variables cannot be used and
parameters must be scalars. (See \code{\link[rmutil]{finterp}}.)

Marginal and individual profiles can be plotted using
\code{\link[rmutil]{mprofile}} and \code{\link[rmutil]{iprofile}} and
residuals with \code{\link[rmutil]{plot.residuals}}.

When the dispersion parameter is not constant over time,
\code{volatility} extracts the square root of the dispersion parameter
for a fitted model.
}
\arguments{
\item{response}{A list of two or three column matrices with responses,
corresponding times, and possibly a censor indicator, for each
individual, one matrix or dataframe of responses, or an object of
class, \code{response} (created by \code{\link[rmutil]{restovec}}) or
\code{repeated} (created by \code{\link[rmutil]{rmna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{distribution}{The distribution to be fitted: binomial, Poisson,
exponential, negative binomial, mult Poisson, double Poisson, Consul
generalized Poisson, beta binomial, mult binomial, double binomial,
normal, inverse Gauss, logistic, gamma, Weibull, Cauchy, Laplace,
Levy, Pareto, beta, simplex, two-sided power, gen(eralized) gamma,
gen(eralized) logistic, Hjorth, Burr, gen(eralized) Weibull,
gen(eralized) extreme value, gen(eralized) inverse Gauss, power
exponential, power variance function Poisson, skew Laplace, or Student
t. (For definitions of distributions, see the
corresponding [dpqr]distribution help.)}
\item{times}{When response is a matrix, a vector of possibly unequally
spaced times when they are the same for all individuals or a matrix of
times. Not necessary if equally spaced. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{totals}{An appropriate scalar, vector, or matrix of binomial
totals (only applicable for binomial, beta binomial, mult binomial,
double binomial). Ignored if response has class, \code{response} or
\code{repeated}.}
\item{censor}{If response is a matrix, a matrix of the same size
containing the censor indicator: 1=uncensored, 0=right-censored,
-1=left-censored. Ignored if response has class, \code{response} or
\code{repeated}.}
\item{delta}{Scalar or vector giving the unit of measurement for each
response value, set to unity by default. For example, if a response is
measured to two decimals, \code{delta=0.01}. If the response has been
pretransformed, this must be multiplied by the Jacobian. This
transformation cannot contain unknown parameters. For example, with a
log transformation, \code{delta=1/y}. (The delta values for the
censored response are ignored.) The jacobian is calculated
automatically for the transform option. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{mu}{A user-specified function of \code{pmu} giving the
regression equation for the location. It may also be a formula
beginning with ~, specifying either a linear regression function for
the location parameter in the Wilkinson and Rogers notation or a
general function with named unknown parameters. It must yield a  value
for each observation on each individual.}
\item{shape}{An optional user-specified shape regression function;
this may depend on the location (function) through its second
argument, in which case, \code{shfn} must be set to TRUE. It may also
be a formula beginning with ~, specifying either a linear regression
function for the shape parameter in the Wilkinson and Rogers notation
or a general function with named unknown parameters. If it contains
unknown parameters, the keyword \code{mu} may be used to specify a
function of the location parameter.}
\item{depend}{An optional user-specified regression function for the
log dependence parameter. It may also be a formula beginning with ~,
specifying either a linear regression function for the dependence
parameter in the Wilkinson and Rogers notation or a general function
with named unknown parameters. If used, \code{order} must be one.}
\item{shfn}{If TRUE, the supplied shape function depends on the
location function. The name of this location function must be the
last argument of the shape function.}
\item{common}{If TRUE, \code{mu} and \code{shape} must both be either
functions with, as argument, a vector of parameters having some or all
elements in common between them so that indexing is in common
between them or formulae with unknowns. All parameter estimates must
be supplied in \code{preg}. If FALSE, parameters are distinct between
the two functions and indexing starts at one in each function.}
\item{preg}{The initial parameter estimates for the location
regression function. If \code{mu} is a formula with unknown
parameters, their estimates must be supplied either in their order of
appearance in the expression or in a named list.}
\item{pdepend}{One or two estimates of the dependence parameters for
the Kalman update. With one, it is Markovian and, with two, it is
nonstationary. For the latter, the \code{order} must be one. If
\code{depend} is a function or formula, the corresponding number of
estimates must be supplied. Either pdepend or parch or both must be
supplied.}
\item{parch}{Estimate for an ARCH model where the shape parameter
depends on the square of the previous residual. Either pdepend or
parch or both must be supplied.}
\item{arch}{If \code{square}, then \code{shape+parch^diff*residual^2};
if \code{absolute value}, then \code{shape+parch^diff*|residual|};
if \code{exponential}, then \code{shape*exp(parch*residual^2*diff)},
where \code{diff} is the length of time since the previous observation
and \code{residual} is the previous residual or innovation.}
\item{pshape}{Zero to two estimates for the shape parameters,
depending on the distribution, if \code{shape} is not a function;
otherwise, estimates for the parameters in this function, with one
extra at the end for three-parameter distributions. If \code{shape} is
a formula with unknown parameters, their estimates must be supplied
either in their order of appearance in the expression or in a named
list (only for two-parameter distributions).}
\item{transform}{Transformation of the response variable: \code{identity},
\code{exp}, \code{square}, \code{sqrt}, or \code{log}.}
\item{link}{Link function for the mean: \code{identity}, \code{exp},
\code{square}, \code{sqrt}, \code{log}, \code{logit}, \code{cloglog} or
\code{loglog} (last three only for binary/binomial-type data).}
\item{autocorr}{The form of the (second if two) dependence function:
\code{exponential} is the usual \eqn{\rho^{|t_i-t_j|}}{rho^|t_i-t_j|};
\code{gaussian} is \eqn{\rho^{(t_i-t_j)^2}}{rho^((t_i-t_j)^2)};
\code{cauchy} is \eqn{1/(1+\rho(t_i-t_j)^2)}{1/(1+rho(t_i-t_j)^2)};
\code{spherical} is
\eqn{((|t_i-t_j|\rho)^3-3|t_i-t_j|\rho+2)/2}{((|t_i-t_j|rho)^3-3|t_i-t_j|rho+2)/2}
for \eqn{|t_i-t_j|\leq1/\rho}{|t_i-t_j|<=1/rho} and zero otherwise;
\code{IOU} is the integrated
Ornstein-Uhlenbeck process, \eqn{(2\rho \min(t_i,t_j)+\exp(-\rho t_i)
+\exp(-\rho t_j)-1 -\exp(\rho|ti-t_j|))/2\rho^3}{(2rho min(t_i,t_j)+exp(-rho t_i)
+exp(-rho t_j)-1 -exp(rho|ti-t_j|))/2rho^3}.}
\item{order}{First- or second-order stationary autoregression.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}.
If \code{response} has class \code{repeated}, it is used as the
environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\references{
Lindsey, J.K. (1997) Applying Generalized Linear Models. Springer,
pp.\ 93--101

Lambert, P. (1996) Statistics in Medicine 15, 1695-1708
}
\value{
A list of classes \code{gar} and \code{recursive} is returned
that contains all of the relevant information calculated, including
error codes.

The volatility vector for models with a shape regression function and
ARCH models contains the square root of the dispersion parameter at
each time point.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}},
\code{\link[rmutil]{finterp}}, \code{\link[repeated]{gnlmm}},
\code{\link[gnlm]{gnlr}}, \code{\link[rmutil]{iprofile}},
\code{\link[repeated]{kalcount}}, \code{\link[repeated]{kalseries}},
\code{\link[event]{kalsurv}}, \code{\link[rmutil]{mprofile}},
\code{\link[rmutil]{plot.residuals}}, \code{\link[rmutil]{read.list}},
\code{\link[rmutil]{restovec}}, \code{\link[rmutil]{rmna}},
\code{\link[rmutil]{tcctomat}}, \code{\link[rmutil]{tvctomat}}.
}
\examples{
# first-order one-compartment model
# data objects for formulae
dose <- c(2,5)
dd <- tcctomat(dose)
times <- matrix(rep(1:20,2), nrow=2, byrow=TRUE)
tt <- tvctomat(times)
# vector covariates for functions
dose <- c(rep(2,20),rep(5,20))
times <- rep(1:20,2)
# functions
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
# response
conc <- matrix(rgamma(40,shape(log(c(0.1,0.4))),
	scale=mu(log(c(1,0.3,0.2))))/shape(log(c(0.1,0.4))),ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- restovec(ifelse(conc>0,conc,0.01),name="conc")
reps <- rmna(conc, ccov=dd, tvcov=tt)
# constant shape parameter
gar(conc, dist="gamma", times=1:20, mu=mu,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=1)
# or
gar(conc, dist="gamma", times=1:20, mu=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	preg=list(absorption=0,elimination=log(0.4),volume=log(0.1)),
	pdepend=0.5, pshape=1, envir=reps)
# generalized gamma distribution
gar(conc, dist="gen gamma", times=1:20, mu=mu,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=c(1,1))
# (if the covariates contained NAs, reps would have to be used as
# response instead of conc)
#
# time dependent shape parameter
gar(conc, dist="gamma", times=1:20, mu=mu, shape=shape,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=log(c(1,0.2)))
# or
gar(conc, dist="gamma", times=1:20, mu=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	shape=~exp(b1-b2)*times*dose*exp(-exp(b1)*times),
	preg=list(absorption=0,elimination=log(0.4),volume=log(0.1)),
	pdepend=0.5, pshape=list(b1=0,b2=log(0.2)), envir=reps)
# generalized gamma distribution
gar(conc, dist="gen gamma", times=1:20, mu=mu, shape=shape,
	preg=log(c(1,0.4,0.1)), pdepend=0.5,
	pshape=c(log(c(1,0.2)),2))
#
# shape function depends on location parameter
shape <- function(p, mu) p[1]+p[2]*mu
gar(conc, dist="gamma", times=1:20, mu=mu, shape=shape, shfn=TRUE,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=c(1,0))
# or
gar(conc, dist="gamma", times=1:20, mu=mu, shape=~a+d*mu, shfn=TRUE,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=c(1,0))
}
\keyword{models}

\eof
\name{gausscop}
\title{Multivariate Gaussian Copula with Arbitrary Marginals}
\alias{gausscop}
\usage{
gausscop(response=NULL, distribution="gamma", mu=NULL, shape=NULL,
	autocorr="exponential", pmu=NULL, pshape=NULL, par=NULL,
	pre=NULL, delta=NULL, shfn=FALSE, common=FALSE, envir=parent.frame(),
	print.level=0, ndigit=10, gradtol=0.00001, steptol=0.00001,
	iterlim=100, fscale=1, stepmax=10*sqrt(theta%*%theta),
	typsiz=abs(c(theta)))
fitted.gausscop(z)
residuals.gausscop(z)
}
\alias{fitted.gausscop}
\alias{residuals.gausscop}
\description{
\code{gausscop} fits multivariate repeated measurements models based
on the Gaussian copula with a choice of marginal distributions.
Dependence among responses is provided by the correlation matrix
containing random effects and/or autoregression.

With two levels of nesting, the first is the individual and the second
will consist of clusters within individuals.

For clustered (non-longitudinal) data, where only random effects will
be fitted, \code{times} are not necessary.

This function is designed to fit linear and nonlinear models with
time-varying covariates observed at arbitrary time points. A
continuous-time AR(1) and zero, one, or two levels of nesting can be
handled.

Nonlinear regression models can be supplied as formulae where
parameters are unknowns in which case factor variables cannot be used
and parameters must be scalars. (See \code{\link[rmutil]{finterp}}.)
}
\arguments{
\item{response}{A list of two or three column matrices with response
values, times, and possibly nesting categories, for each individual,
one matrix or dataframe of response values, or an object of class,
\code{response} (created by \code{\link[rmutil]{restovec}}) or \code{repeated}
(created by \code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{distribution}{The marginal distribution: exponential, gamma,
Weibull, Pareto, inverse Gauss, logistic, Cauchy, Laplace, or Levy.}
\item{mu}{The linear or nonlinear regression model to be fitted for
the location parameter. For marginal distributions requiring positive
response values, a log link is used. This model can be a function of
the parameters or a formula beginning with ~, specifying either a
linear regression function for the location parameter in the Wilkinson
and Rogers notation or a general function with named unknown
parameters that describes the location, returning a vector the same
length as the number of observations.}
\item{shape}{The linear or nonlinear regression model to be fitted for
the log shape parameter. This can be a function of the parameters
or a formula beginning with ~, specifying either a linear regression
function for the location parameter in the Wilkinson and Rogers
notation or a general function with named unknown parameters that
describes the location. If it contains unknown parameters, the keyword
\code{mu} may be used to specify a function of the location parameter.}
\item{autocorr}{The form of the autocorrelation function:
\code{exponential} is the usual \eqn{\rho^{|t_i-t_j|}}{rho^|t_i-t_j|};
\code{gaussian} is \eqn{\rho^{(t_i-t_j)^2}}{rho^((t_i-t_j)^2)};
\code{cauchy} is \eqn{1/(1+\rho(t_i-t_j)^2)}{1/(1+rho(t_i-t_j)^2)};
\code{spherical} is
\eqn{((|t_i-t_j|\rho)^3-3|t_i-t_j|\rho+2)/2}{((|t_i-t_j|rho)^3-3|t_i-t_j|rho+2)/2}
for \eqn{|t_i-t_j|\leq1/\rho}{|t_i-t_j|<=1/rho} and zero otherwise.}
\item{pmu}{Initial parameter estimates for the location regression model.}
\item{pshape}{Initial parameter estimate for the shape regression model.}
\item{par}{If supplied, an initial estimate for the autocorrelation
parameter.}
\item{pre}{Zero, one or two parameter estimates for the variance
components, depending on the number of levels of nesting.}
\item{delta}{Scalar or vector giving the unit of measurement
for each response value, set to unity by default. For example, if a
response is measured to two decimals, \code{delta=0.01}. Ignored if
response has class, \code{response} or \code{repeated}.}
\item{shfn}{If TRUE, the supplied shape function depends on the
location function. The name of this location function must be the last
argument of the shape function.}
\item{common}{If TRUE, \code{mu} and \code{shape} must both be
functions with, as argument, a vector of parameters having some or all
elements in common between them so that indexing is in common
between them; all parameter estimates must be supplied in \code{pmu}.
If FALSE, parameters are distinct between the two functions and
indexing starts at one in each function.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}. If \code{response} has class \code{repeated}, it is
used as the environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
\item{z}{An object of class, \code{gausscop}.}
}
\references{
Song, P.X.K. (2000) Multivariate dispersion models generated from
Gaussian copula. Scandinavian Journal of Statistics 27, 305-320.
}
\value{
A list of class \code{gausscop} is returned that contains all of the
relevant information calculated, including error codes.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}},
\code{\link[rmutil]{finterp}}, \code{\link[repeated]{gar}},
\code{\link[rmutil]{gettvc}}, \code{\link[repeated]{glmm}},
\code{\link[repeated]{gnlmm}}, \code{\link[gnlm]{gnlr}},
\code{\link[rmutil]{iprofile}}, \code{\link[repeated]{kalseries}},
\code{\link[rmutil]{mprofile}}, \code{\link[growth]{potthoff}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}.}
\examples{
library(gnlm)
# linear models
y <- matrix(rgamma(40,1,1),ncol=5)+rep(rgamma(8,0.5,1),5)
x1 <- c(rep(0,4),rep(1,4))
reps <- rmna(restovec(y),ccov=tcctomat(x1))
# independence with default gamma marginals
gnlr(y, pmu=1, psh=0, dist="gamma", env=reps)
gausscop(y, pmu=1, pshape=0, env=reps)
gausscop(y, mu=~x1, pmu=c(1,0), pshape=0, env=reps)
# AR(1)
gausscop(y, pmu=1, pshape=0, par=0.1, env=reps)
# random effect
gausscop(y, pmu=1, pshape=0, pre=0.1, env=reps)
# try other marginal distributions
gausscop(y, pmu=1, pshape=0, pre=0.1, env=reps, dist="Weibull")
gausscop(y, pmu=1, pshape=0, pre=0.1, env=reps, dist="inverse Gauss",
	stepmax=1)
gausscop(y, pmu=1, pshape=0, pre=0.1, env=reps, dist="Cauchy")
#
# first-order one-compartment model
# create data objects for formulae
dose <- c(2,5)
dd <- tcctomat(dose)
times <- matrix(rep(1:20,2), nrow=2, byrow=TRUE)
tt <- tvctomat(times)
# vector covariates for functions
dose <- c(rep(2,20),rep(5,20))
times <- rep(1:20,2)
# functions
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
lmu <- function(p) p[1]-p[3]+log(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
lshape <- function(p) p[1]-p[2]+log(times*dose)-exp(p[1])*times
# response
conc <- matrix(rgamma(40,shape(log(c(0.1,0.4))),
	scale=mu(log(c(1,0.3,0.2))))/shape(log(c(0.1,0.4))),ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- restovec(ifelse(conc>0,conc,0.01),name="conc")
reps <- rmna(conc, ccov=dd, tvcov=tt)
# constant shape parameter
gausscop(conc, mu=lmu, pmu=log(c(1,0.4,0.1)), par=0.5, pshape=0, envir=reps)
# or
gausscop(conc, mu=~absorption-volume+
	log(dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times))),
	pmu=list(absorption=0,elimination=log(0.4),volume=log(0.1)),
	par=0.5, pshape=0, envir=reps)
# compare to gar autoregression
gar(conc, dist="gamma", times=1:20, mu=mu,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=1)
#
# time dependent shape parameter
gausscop(conc, mu=lmu, shape=lshape,
	pmu=log(c(1,0.4,0.1)), par=0.5, pshape=c(-0.1,-0.1))
# or
gausscop(conc, mu=~absorption-volume+
	log(dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times))),
	shape=~b1-b2+log(times*dose)-exp(b1)*times,
	pmu=list(absorption=0,elimination=log(0.4),volume=log(0.1)),
	par=0.5, pshape=list(b1=-0.1,b2=-0.1), envir=reps)
#
# shape depends on location
lshape <- function(p, mu) p[1]*log(abs(mu))
gausscop(conc, mu=lmu, shape=lshape, shfn=TRUE, pmu=log(c(1,0.4,0.1)),
	par=0.5, pshape=1)
# or
gausscop(conc, mu=~absorption-volume+
	log(dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times))),
	shape=~d*log(abs(mu)), shfn=TRUE,
	pmu=list(absorption=0,elimination=log(0.4),volume=log(0.1)),
	par=0.5, pshape=list(d=1), envir=reps)
}
\keyword{models}

\eof
\name{glmm}
\title{Generalized Linear Mixed Models}
\alias{glmm}
\usage{
glmm(formula, family=gaussian, data=list(), weights=NULL,
	offset=NULL, nest, delta=1, maxiter=20, points=10, print.level=0,
	control=glm.control(epsilon=0.0001,maxit=10,trace=FALSE))
}
\description{
\code{glmm} fits a generalized linear mixed model with a random
intercept using a normal mixing distribution computed by Gauss-Hermite
integration. For the normal, gamma, and inverse Gaussian
distributions, the deviances supplied are -2 log likelihood, not the
usual \code{\link{glm}} deviance; the degrees of freedom take into
account estimation of the dispersion parameter.

If weights and/or offset are to be used or the formula transforms
some variables, all of the data must be supplied in a dataframe.
Because the \code{\link{glm}} function is such a hack, if this is not
done, weird error messages will result.

na.omit is not allowed.
}
\arguments{
\item{formula}{A symbolic description of the model to be fitted. If it
contains transformations of the data, including cbind for binomial
data, a dataframe must be supplied.}
\item{family}{A description of the error distribution and link
function to be used in the model; see \code{\link{family}} for details.}
\item{data}{A dataframe containing the variables in the model, that is
optional in simple cases, but required in certain situations as
specified elsewhere in this help page.}
\item{weights}{An optional weight vector. If this is used, data must
be supplied in a data.frame.}
\item{offset}{The known component in the linear predictor. If this is
used, data must be supplied in a data.frame. An offset cannot be
specified in the model formula.}
\item{nest}{The variable classifying observations by the unit
(cluster) upon which they were observed.}
\item{delta}{If the response variable has been transformed, this is
the Jacobian of that transformation, so that AICs are comparable.}
\item{maxiter}{The maximum number of iterations of the outer loop for
numerical integration.}
\item{points}{The number of points for Gauss-Hermite integration of
the random effect.}
\item{print.level}{If set equal to 2, the log probabilities are
printed out when the underflow error is given.}
\item{control}{A list of parameters for controlling the fitting
process.}
}
\value{
\code{glmm} returns a list of class \code{glmm}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{family}}, \code{\link[gnlm]{fmr}}, \code{\link{glm}},
\code{\link{glm.control}}, \code{\link[repeated]{gnlmix}},
\code{\link[repeated]{gnlmm}}, \code{\link[gnlm]{gnlr}},
\code{\link[gnlm]{gnlr3}}, \code{\link[repeated]{hnlmix}},
\code{\link[nls]{nls}}.
}
\examples{
# Poisson counts
nest <- gl(5,4)
y <- rpois(20,5+2*codes(nest))
# overdispersion model
glmm(y~1, family=poisson, nest=gl(20,1), points=3)
# clustered model
glmm(y~1, family=poisson, nest=nest, points=3)
#
# binomial data with model for overdispersion
df <- data.frame(r=rbinom(10,10,0.5), n=rep(10,10), x=c(rep(0,5),
	rep(1,5)), nest=1:10)
glmm(cbind(r,n-r)~x, family=binomial, nest=nest, data=df)
}
\keyword{models}

\eof
\name{gnlmix}
\title{Generalized Nonlinear Regression with a Random Parameter}
\alias{gnlmix}
\usage{
gnlmix(y=NULL, distribution="normal", mixture="normal",
	random=NULL, nest=NULL, mu=NULL, shape=NULL, linear=NULL,
	pmu=NULL, pshape=NULL, pmix=NULL, delta=1, common=FALSE,
	envir=parent.frame(), print.level=0, typsiz=abs(p),
	ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p), steptol=0.00001,
	iterlim=100, fscale=1, eps=1.0e-4, points=5, steps=10)
}
\description{
\code{gnlmix} fits user-specified nonlinear regression equations to one
or both parameters of the common one and two parameter distributions.
One parameter of the location regression is random with some
specified mixing distribution. 

It is recommended that initial estimates for \code{pmu} and
\code{pshape} be obtained from \code{gnlr}.

These nonlinear regression models must be supplied as formulae where
parameters are unknowns. (See \code{\link[rmutil]{finterp}}.)
}
\arguments{
\item{y}{A response vector of uncensored data, a two column matrix
for binomial data, or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{distribution}{The distribution for the response: binomial, beta
binomial, double binomial, mult(iplicative) binomial,
Poisson, negative binomial, double Poisson, mult(iplicative) Poisson,
gamma count, Consul generalized Poisson, logarithmic series,
geometric, normal, inverse Gauss, logistic, exponential, gamma,
Weibull, extreme value, Cauchy, Pareto, Laplace, Levy, beta,
simplex, or two-sided power. (For definitions of distributions, see
the corresponding [dpqr]distribution help.)}
\item{mixture}{The mixing distribution for the random parameter:
normal, Cauchy, logistic, Laplace, inverse Gauss, gamma, inverse gamma,
Weibull, beta, simplex, or two-sided power. The first four have zero location
parameter, the next three have unit location parameter, and the last
two have location parameter set to 0.5.}
\item{random}{The name of the random parameter in the \code{mu} formula.}
\item{nest}{The variable classifying observations by the unit upon
which they were observed. Ignored if \code{y} or \code{envir} has class,
\code{response} or \code{repeated}.}
\item{mu}{A user-specified formula containing named unknown
parameters, giving the regression equation for the location
parameter. This may contain the keyword, \code{linear} referring to a
linear part.}
\item{shape}{A user-specified formula containing named unknown
parameters, giving the regression equation for the shape
parameter. This may contain the keyword, \code{linear} referring to a
linear part. If nothing is supplied, this parameter is taken to
be constant. This parameter is the logarithm of the usual one.}
\item{linear}{A formula beginning with ~ in W&R notation, specifying
the linear part of the regression function for the location parameter
or list of two such expressions for the location and/or shape parameters.}
\item{pmu}{Vector of initial estimates for the location parameters.
These must be supplied either in their order of appearance in the formula
or in a named list.}
\item{pshape}{Vector of initial estimates for the shape parameters.
These must be supplied either in their order of appearance in the
expression or in a named list.}
\item{pmix}{Initial estimate for the logarithm of the dispersion
parameter of the mixing distribution.}
\item{delta}{Scalar or vector giving the unit of measurement (always
one for discrete data) for each response value, set to unity by
default. For example, if a response is measured to two decimals,
\code{delta=0.01}. If the response is transformed, this must be multiplied by
the Jacobian. The transformation cannot contain unknown
parameters. For example, with a log transformation,
\code{delta=1/y}. (The delta values for the censored response are
ignored.)}
\item{common}{If TRUE, the formulae with unknowns for the location and
shape have names in common. All parameter estimates must
be supplied in \code{pmu}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{y}. If \code{y} has class \code{repeated}, it is used as
the environment.}
\item{eps}{Precision of the Romberg integration.}
\item{steps}{For the Romberg integration, the maximum number of steps,
by default set to 10.}
\item{points}{For the Romberg integration, the number of extrapolation
points so that 2*points is the order of integration, by default set to 5;
points=2 is Simpson's rule.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of class \code{gnlm} is returned that contains all of the
relevant information calculated, including error codes.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[rmutil]{finterp}},
\code{\link[growth]{elliptic}}, \code{\link[repeated]{glmm}},
\code{\link[repeated]{gnlmm}}, \code{\link[gnlm]{gnlr}},
\code{\link[repeated]{hnlmix}}, \code{\link[repeated]{kalseries}},
\code{\link[gnlm]{nlr}}, \code{\link[nls]{nls}}.
}
\examples{
library(growth)
dose <- c(9,12,4,9,11,10,2,11,12,9,9,9,4,9,11,9,14,7,9,8)
#y <- rgamma(20,shape=2+0.3*dose,scale=2)+rep(rnorm(4,0,4),rep(5,4))
y <- c(8.674419, 11.506066, 11.386742, 27.414532, 12.135699,  4.359469,
       1.900681, 17.425948,  4.503345,  2.691792,  5.731100, 10.534971,
      11.220260,  6.968932,  4.094357, 16.393806, 14.656584,  8.786133,
      20.972267, 17.178012)
resp <- restovec(matrix(y, nrow=4, byrow=TRUE), name="y")
reps <- rmna(resp, tvcov=tvctomat(matrix(dose, nrow=4, byrow=TRUE), name="dose"))

# same linear normal model with random normal intercept fitted four ways
elliptic(reps, model=~dose, preg=c(0,0.6), pre=4)
glmm(y~dose, nest=individuals, data=reps)
gnlmm(reps, mu=~dose, pmu=c(8.7,0.25), psh=3.5, psd=3)
gnlmix(reps, mu=~a+b*dose+rand, random="rand", pmu=c(8.7,0.25),
	pshape=3.44, pmix=2.3)

# gamma model with log link and random normal intercept fitted three ways
glmm(y~dose, family=Gamma(link=log), nest=individuals, data=reps, points=8)
gnlmm(reps, distribution="gamma", mu=~exp(a+b*dose), pmu=c(2,0.03),
	psh=1, psd=0.3)
gnlmix(reps, distribution="gamma", mu=~exp(a+b*dose+rand), random="rand",
	pmu=c(2,0.04), pshape=1, pmix=-2)

# gamma model with log link and random gamma mixtures
gnlmix(reps, distribution="gamma", mixture="gamma",
	mu=~exp(a*rand+b*dose), random="rand", pmu=c(2,0.04),
	pshape=1.24, pmix=3.5)
gnlmix(reps, distribution="gamma", mixture="gamma",
	mu=~exp(a+b*dose)*rand, random="rand", pmu=c(2,0.04),
	pshape=1.24, pmix=2.5)
}
\keyword{models}

\eof
\name{gnlmm}
\title{Generalized Nonlinear Mixed Models}
\alias{gnlmm}
\usage{
gnlmm(y=NULL, distribution="normal", mu=NULL, shape=NULL,
	linear=NULL, nest=NULL, pmu=NULL, pshape=NULL, psd=NULL, exact=FALSE,
	wt=1, delta=1, shfn=FALSE, scale=NULL, points=10, common=FALSE,
	envir=parent.frame(), print.level=0, typsiz=abs(p),
	ndigit=10, gradtol=0.00001, stepmax=sqrt(p%*%p)/10, steptol=0.00001,
	iterlim=100, fscale=1)
}
\description{
\code{gnlmm} fits user-specified nonlinear regression equations to one
or both parameters of the common one and two parameter distributions.
The intercept of the location regression has a normally-distributed
random effect. This normal mixing distribution is computed by
Gauss-Hermite integration.

The \code{scale} of the random effect is the link function to be
applied. For example, if it is \code{log}, the supplied mean function,
\code{mu}, is transformed as exp(log(mu)+sd), where sd is the random
effect parameter.

It is recommended that initial estimates for \code{pmu} and
\code{pshape} be obtained from \code{gnlr}.

Nonlinear regression models can be supplied as formulae where
parameters are unknowns in which case factor variables cannot be used
and parameters must be scalars. (See \code{\link[rmutil]{finterp}}.)

The printed output includes the -log likelihood (not the deviance),
the corresponding AIC, the maximum likelihood estimates, standard
errors, and correlations.
}
\arguments{
\item{y}{A response vector for uncensored data, a two column matrix
for binomial data or censored data, with the second column being the
censoring indicator (1: uncensored, 0: right censored, -1: left
censored), or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}}) or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here. The beta, simplex, and two-sided power
distributions for proportions do not allow censoring.}
\item{distribution}{Either a character string containing the name of the
distribution or a function giving the -log likelihood and calling the
location and shape functions. Distributions are
binomial, beta binomial, double binomial, mult(iplicative) binomial,
Poisson, negative binomial, double Poisson, mult(iplicative) Poisson,
gamma count, Consul generalized Poisson, logarithmic series,
geometric, normal, inverse Gauss, logistic, exponential, gamma,
Weibull, extreme value, Cauchy, Pareto, Laplace, and Levy, beta,
simplex, and two-sided power. All but the binomial-based distributions
and the beta, simplex, and two-sided power may be right and/or left
censored. (For definitions of distributions, see the corresponding
[dpqr]distribution help.)}
\item{mu}{A user-specified function of \code{pmu}, and possibly
\code{linear}, giving the regression equation for the location. This
may contain a linear part as the second argument to the function. It
may also be a formula beginning with ~, specifying a either linear
regression function for the location parameter in the Wilkinson and
Rogers notation or a general function with named unknown parameters.
If it contains unknown parameters, the keyword \code{linear} may be
used to specify a linear part. If nothing is supplied, the location is
taken to be constant unless the linear argument is given.}
\item{shape}{A user-specified function of \code{pshape}, and possibly
\code{linear} and/or \code{mu}, giving the regression equation for the
dispersion or shape parameter. This may contain a linear part as the
second argument to the function and the location function as last
argument (in which case \code{shfn} must be set to TRUE). It may also
be a formula beginning with ~, specifying either a linear regression
function for the shape parameter in the Wilkinson and Rogers notation
or a general function with named unknown parameters. If it contains
unknown parameters, the keyword \code{linear} may be used to specify a
linear part and the keyword \code{mu} to specify a function of the
location parameter. If nothing is supplied, this parameter is taken to
be constant unless the linear argument is given. This parameter is the
logarithm of the usual one.}
\item{linear}{A formula beginning with ~ in W&R notation, specifying
the linear part of the regression function for the location parameter
or list of two such expressions for the location and/or shape parameters.}
\item{nest}{The variable classifying observations by the unit upon
which they were observed. Ignored if \code{y} or \code{envir} has
class, response.}
\item{pmu}{Vector of initial estimates for the location parameters.
If \code{mu} is a formula with unknown parameters, their estimates
must be supplied either in their order of appearance in the expression
or in a named list.}
\item{pshape}{Vector of initial estimates for the shape parameters.
If \code{shape} is a formula with unknown parameters, their estimates
must be supplied either in their order of appearance in the expression
or in a named list.}
\item{psd}{Initial estimate of the standard deviation of the normal
mixing distribution.}
\item{exact}{If TRUE, fits the exact likelihood function for
continuous data by integration over intervals of observation,
i.e. interval censoring.}
\item{wt}{Weight vector.}
\item{delta}{Scalar or vector giving the unit of measurement (always
one for discrete data) for each response value, set to unity by
default. Ignored if y has class, response. For example, if a response
is measured to two decimals, \code{delta=0.01}. If the response is
transformed, this must be multiplied by the Jacobian. The
transformation cannot contain unknown parameters. For example, with a
log transformation, \code{delta=1/y}. (The delta values for the
censored response are ignored.)}
\item{shfn}{If true, the supplied shape function depends on the
location (function). The name of this location function must be the
last argument of the shape function.}
\item{scale}{The scale on which the random effect is applied:
\code{identity}, \code{log}, \code{logit}, \code{reciprocal}, or \code{exp}.}
\item{points}{The number of points for Gauss-Hermite integration of
the random effect.}
\item{common}{If TRUE, \code{mu} and \code{shape} must both be either
functions with, as argument, a vector of parameters having some or all
elements in common between them so that indexing is in common
between them or formulae with unknowns. All parameter estimates must
be supplied in \code{pmu}. If FALSE, parameters are distinct between
the two functions and indexing starts at one in each function.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{y}. If \code{y} has class \code{repeated}, it is used as
the environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of class \code{gnlm} is returned that contains all of the
relevant information calculated, including error codes.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{finterp}}, \code{\link[gnlm]{fmr}}, \code{\link{glm}},
\code{\link[repeated]{gnlmix}}, \code{\link[repeated]{glmm}},
\code{\link[gnlm]{gnlr}}, \code{\link[gnlm]{gnlr3}},
\code{\link[repeated]{hnlmix}}, \code{\link{lm}},
\code{\link[gnlm]{nlr}}, \code{\link[nls]{nls}}.
}
\examples{
library(gnlm)
# data objects
sex <- c(0,1)
sx <- tcctomat(sex)
dose <- matrix(rpois(20,10),nrow=2)
dd <- tvctomat(dose)
# vectors for functions
dose <- as.vector(t(dose))
sex <- c(rep(0,10),rep(1,10))
nest <- rbind(rep(1,10),rep(2,10))
y <- exp(0.2+0.3*dose+0.5*sex)+rgamma(20,2,scale=5)+rep(rnorm(10),rep(2,10))
y <- restovec(matrix(y, nrow=2), nest=nest, name="y")
reps <- rmna(y, ccov=sx, tvcov=dd)
#
# log linear regression with gamma distribution
mu <- function(p) exp(p[1]+p[2]*sex+p[3]*dose)
print(z <- gnlr(y, dist="gamma", mu=mu, pmu=c(1,0,0), pshape=1))
gnlmm(y, dist="gamma", mu=mu, nest=nest, pmu=z$coef[1:3],
	pshape=z$coef[4], psd=0.1, points=3)
# or equivalently
gnlmm(y, dist="gamma", mu=~exp(b0+b1*sex+b2*dose), nest=nest,
	pmu=z$coef[1:3], pshape=z$coef[4], psd=0.1, points=3, envir=reps)
# or with identity link
print(z <- gnlr(y, dist="gamma", mu=~sex+dose, pmu=c(0.1,0,0), pshape=1))
gnlmm(y, dist="gamma", mu=~sex+dose, nest=nest, pmu=z$coef[1:3],
	pshape=z$coef[4], psd=0.1, points=3)
# or
gnlmm(y, dist="gamma", mu=~b0+b1*sex+b2*dose, nest=nest, pmu=z$coef[1:3],
	pshape=z$coef[4], psd=0.1, points=3, envir=reps)
#
# nonlinear regression with gamma distribution
mu <- function(p) p[1]+exp(p[2]+p[3]*sex+p[4]*dose)
print(z <- gnlr(y, dist="gamma", mu=mu, pmu=c(1,1,0,0), pshape=1))
gnlmm(y, dist="gamma", mu=mu, nest=nest, pmu=z$coef[1:4],
	pshape=z$coef[5], psd=0.1, points=3)
# or
mu2 <- function(p, linear) p[1]+exp(linear)
gnlmm(y, dist="gamma", mu=mu2, linear=~sex+dose, nest=nest,
	pmu=z$coef[1:4], pshape=1, psd=0.1, points=3)
# or
gnlmm(y, dist="gamma", mu=~a+exp(linear), linear=~sex+dose, nest=nest,
	pmu=z$coef[1:4], pshape=1, psd=0.1, points=3)
# or
gnlmm(y, dist="gamma", mu=~b4+exp(b0+b1*sex+b2*dose), nest=nest,
	pmu=z$coef[1:4], pshape=z$coef[5], psd=0.1,
	points=3, envir=reps)
#
# include regression for the shape parameter with same mu function
shape <- function(p) p[1]+p[2]*sex
print(z <- gnlr(y, dist="gamma", mu=mu, shape=shape, pmu=z$coef[1:4],
	pshape=rep(1,2)))
gnlmm(y, dist="gamma", mu=mu, shape=shape, nest=nest,
	pmu=z$coef[1:4], pshape=z$coef[5:6], psd=0.1, points=3)
# or
gnlmm(y, dist="gamma", mu=mu, shape=shape, nest=nest, pmu=z$coef[1:4],
	pshape=z$coef[5:6], psd=0.1, points=3, envir=reps)
# or
gnlmm(y, dist="gamma", mu=~b4+exp(b0+b1*sex+b2*dose), shape=~a1+a2*sex,
	nest=nest, pmu=z$coef[1:4], pshape=z$coef[5:6], psd=0.1,
	points=3, envir=reps)
}
\keyword{models}

\eof
\name{hidden}
\title{Discrete-time Hidden Markov Chain Models}
\alias{hidden}
\usage{
hidden(response=NULL, totals=NULL, distribution="Bernoulli",
	mu=NULL, cmu=NULL, tvmu=NULL, pgamma, pmu=NULL, pcmu=NULL,
	ptvmu=NULL, pshape=NULL, pfamily=NULL, par=NULL, pintercept=NULL,
	delta=NULL, envir=parent.frame(), print.level=0, ndigit=10,
	gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100,
	typsiz=abs(p), stepmax=10*sqrt(p%*%p))
plot.hidden(z, nind=1, state=NULL, smooth=FALSE, main=NULL,
	ylab=NULL, xlab="Time", xlim=NULL, ...)
}
\alias{plot.hidden}
\description{
\code{hidden} fits a two or more state hidden Markov chain model with
a variety of distributions. All series on different individuals are
assumed to start at the same time point. Time points are equal,
discrete steps.

To fit an `observed' Markov chain, as well, with Bernoulli or
multinomial responses, use the lagged response as a time-varying
covariate. For quantitative responses, specifying \code{par} allows an
`observed" autoregression to be fitted as well as the hidden Markov chain.

All functions and formulae for the location parameter are on the
(generalized) logit scale for the Bernoulli, binomial, and multinomial
distributions.

If \code{cmu} and \code{tvmu} are used, these two mean functions are
additive so that interactions between time-constant and time-varying
variables are not possible.

The object returned can be plotted to give the probabilities of being
in each hidden state at each time point. For distributions other than
the multinomial, proportional odds, and continuation ratio, the
(recursive) predicted values can be plotted using
\code{\link[rmutil]{mprofile}} and \code{\link[rmutil]{iprofile}}.

See MacDonald, I.L. and Zucchini, W. (1997) Hidden Markov and Other
Models for Discrete-valued Time Series. Chapman and Hall.
}
\arguments{
\item{response}{A list of two or three column matrices with counts or
category indicators, times, and possibly totals (if the distribution
is binomial), for each individual, one matrix or dataframe of counts,
or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here. If there is only one series, a vector of
responses may be supplied instead.

Multinomial and ordinal categories must be integers numbered from 0.}
\item{totals}{If response is a matrix, a corresponding matrix of
totals if the distribution is binomial. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{distribution}{Bernoulli, Poisson, multinomial, proportional odds,
continuation ratio, binomial, exponential, beta binomial, negative
binomial, normal, inverse Gauss, logistic, gamma, Weibull, Cauchy,
Laplace, Levy, Pareto, gen(eralized) gamma, gen(eralized) logistic,
Hjorth, Burr, gen(eralized) Weibull, gen(eralized) extreme value,
gen(eralized) inverse Gauss, power exponential, skew Laplace, or
Student t. (For definitions of distributions, see the corresponding
[dpqr]distribution help.)}
\item{mu}{A general location function with two possibilities: (1) a
list of formulae (with parameters having different names) or functions
(with one parameter vector numbering for all of them) each returning
one value per observation; or (2) a single formula or function which
will be used for all states (and all categories if multinomial) but
with different parameter values in each so that pmu must be a vector
of length the number of unknowns in the function or formula times the
number of states (times the number of categories minus one if
multinomial).}
\item{cmu}{A time-constant location function with three possibilities:
(1) a list of formulae (with parameters having different names) or
functions (with one parameter vector numbering for all of them) each
returning one value per individual; (2) a single formula or function
which will be used for all states (and all categories if multinomial)
but with different parameter values in each so that pcmu must be a
vector of length the number of unknowns in the function or formula
times the number of states (times the number of categories minus one
if multinomial); or (3) a function returning an array with one row for
each individual, one column for each state of the hidden Markov chain,
and, if multinomial, one layer for each category but the last. If
used, this function or formula should contain the intercept. Ignored
if \code{mu} is supplied.}
\item{tvmu}{A time-varying location function with three possibilities:
(1) a list of formulae (with parameters having different names) or
functions (with one parameter vector numbering for all of them) each
returning one value per time point; (2) a single formula or function
which will be used for all states (and all categories if multinomial)
but with different parameter values in each so that ptvmu must be a
vector of length the number of unknowns in the function or formula
times the number of states (times the number of categories minus one
if multinomial); or (3) a function returning an array with one row for
each time point, one column for each state of the hidden Markov chain,
and, if multinomial, one layer for each category but the last. This
function or formula is usually a function of time; it is the same for
all individuals. It only contains the intercept if \code{cmu} does
not. Ignored if \code{mu} is supplied.}
\item{pgamma}{A square \code{mxm} matrix of initial estimates of the hidden
Markov transition matrix, where \code{m} is the number of hidden states.
Rows must sum to one. If the matrix contains zeroes or ones, these are
fixed and not estimated. (Ones cannot appear on the diagonal.)
If a \code{1x1} matrix or a scalar value of 1 is given, the independence
model is fitted.}
\item{pmu}{Initial estimates of the unknown parameters in \code{mu}.}
\item{pcmu}{Initial estimates of the unknown parameters in \code{cmu}.}
\item{ptvmu}{Initial estimates of the unknown parameters in \code{tvmu}.}
\item{pshape}{Initial estimate(s) of the dispersion parameter, for
those distributions having one. This can be one value or a vector with
a different value for each state.}
\item{pfamily}{Initial estimate of the family parameter, for
those distributions having one.}
\item{par}{Initial estimate of the autoregression parameter.}
\item{pintercept}{For multinomial, proportional odds, and continuation
ratio models, \code{p-2} initial estimates for intercept contrasts
from the first intercept, where \code{p} is the number of categories.}
\item{delta}{Scalar or vector giving the unit of measurement (always
one for discrete data) for each response value, set to unity by
default. For example, if a response is measured to two decimals,
delta=0.01. If the response is transformed, this must be multiplied by
the Jacobian. For example, with a log transformation,
\code{delta=1/response}. Ignored if response has class, \code{response} or
\code{repeated}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}.
If \code{response} has class \code{repeated}, it is used as the
environment.}
\item{nind}{For plotting: numbers of individuals to plot.}
\item{state}{For plotting: states to plot.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of classes \code{hidden} and \code{recursive} (unless
multinomial, proportional odds, or continuation ratio) is returned
that contains all of the relevant information calculated, including
error codes.
}
\author{J.K. Lindsey and P.J. Lindsey}
\references{
MacDonald, I.L. and Zucchini, W. (1997) Hidden Markov and other Models
for Discrete-valued Time Series. Chapman & Hall.
}
\seealso{
\code{\link[repeated]{chidden}}, \code{\link[repeated]{gar}},
\code{\link[repeated]{gnlmm}}, \code{\link[rmutil]{iprofile}},
\code{\link[repeated]{kalcount}}, \code{\link[rmutil]{mprofile}},
\code{\link[repeated]{nbkal}}, \code{\link[rmutil]{read.list}},
\code{\link[rmutil]{restovec}}, \code{\link[rmutil]{rmna}}.
}
\examples{
# generate two random Poisson sequences with change-points
y <- rbind(c(rpois(5,1), rpois(15,5)), c(rpois(15,1), rpois(5,5)))
print(z <- hidden(y,dist="Poisson", cmu=~1, pcmu=c(1,5),
	pgamma=matrix(c(0.9,0.2,0.1,0.8),ncol=2)))
# or equivalently
mu <- function(p) array(rep(p[1:2],rep(2,2)), c(2,2))
print(z <- hidden(y,dist="Poisson", cmu=mu, pcmu=c(1,5),
	pgamma=matrix(c(0.9,0.2,0.1,0.8),ncol=2)))
# or
print(z <- hidden(y,dist="Poisson", mu=~rep(a,40), pmu=c(1,5),
	pgamma=matrix(c(0.9,0.2,0.1,0.8),ncol=2)))
par(mfrow=c(3,2))
plot(z, nind=1:2)
plot(z, nind=1:2, smooth=TRUE)
plot(iprofile(z), lty=2)
plot(mprofile(z), add=TRUE)
plot(iprofile(z), nind=2, lty=2)
plot(mprofile(z), nind=2, add=TRUE)
}
\keyword{models}

\eof
\name{hnlmix}
\title{Generalized Nonlinear Regression using h-likelihood for a Random Parameter}
\alias{hnlmix}
\usage{
hnlmix(y=NULL, distribution="normal", mixture="normal",
	random=NULL, nest=NULL, mu=NULL, shape=NULL, linear=NULL,
	pmu=NULL, pshape=NULL, pmix=NULL, prandom=NULL, delta=1, common=FALSE,
	envir=parent.frame(), print.level=0, typsiz=abs(p),
	ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p), steptol=0.00001,
	iterlim=100, fscale=1, eps=1.0e-4)
}
\description{
\code{hnlmix} fits user-specified nonlinear regression equations to one
or both parameters of the common one and two parameter distributions.
One parameter of the location regression is random with some
specified mixing distribution.

It is recommended that initial estimates for \code{pmu} and
\code{pshape} be obtained from \code{gnlr}.

These nonlinear regression models must be supplied as formulae where
parameters are unknowns. (See \code{\link[rmutil]{finterp}}.)
}
\arguments{
\item{y}{A response vector of uncensored data, a two column matrix
for binomial data or censored data, with the second column being the
censoring indicator (1: uncensored, 0: right censored, -1: left
censored), or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{distribution}{The distribution for the response: binomial, beta
binomial, double binomial, mult(iplicative) binomial,
Poisson, negative binomial, double Poisson, mult(iplicative) Poisson,
gamma count, Consul generalized Poisson, logarithmic series,
geometric, normal, inverse Gauss, logistic, exponential, gamma,
Weibull, extreme value, Cauchy, Pareto, Laplace, Levy, beta,
simplex, or two-sided power. (For definitions of distributions, see
the corresponding [dpqr]distribution help.)}
\item{mixture}{The mixing distribution for the random parameter (whose
initial values are supplied in \code{prandom}):
normal, logistic, inverse Gauss, gamma, inverse gamma, Weibull, or beta. The
first two have zero location parameter, the next three have unit location
parameter, and the last one has location parameter set to 0.5.}
\item{random}{The name of the random parameter in the \code{mu} formula.}
\item{nest}{The cluster variable classifying observations by the unit upon
which they were observed. Ignored if \code{y} or \code{envir} has class,
\code{response} or \code{repeated}.}
\item{mu}{A user-specified formula containing named unknown
parameters, giving the regression equation for the location
parameter. This may contain the keyword, \code{linear} referring to a
linear part.}
\item{shape}{A user-specified formula containing named unknown
parameters, giving the regression equation for the shape
parameter. This may contain the keyword, \code{linear} referring to a
linear part. If nothing is supplied, this parameter is taken to
be constant. This parameter is the logarithm of the usual one.}
\item{linear}{A formula beginning with ~ in W&R notation, specifying
the linear part of the regression function for the location parameter
or list of two such expressions for the location and/or shape parameters.}
\item{pmu}{Vector of initial estimates for the location parameters.
These must be supplied either in their order of appearance in the formula
or in a named list.}
\item{pshape}{Vector of initial estimates for the shape parameters.
These must be supplied either in their order of appearance in the
expression or in a named list.}
\item{pmix}{If NULL, this parameter is estimated from the variances.
If a value is given, it is taken as fixed.}
\item{prandom}{Either one estimate of the random effects or one for
each cluster (see \code{nest}), in which case the last value is not
used. If the location parameter of the mixing distribution is zero,
the last value is recalculated so that their sum is zero; if it
is unity, they must all be positive and the last value is recalculated
so that the sum of their logarithms is zero; if it is 0.5, they must
all lie in (0,1) and the last value is recalculated so that the sum of
their logits is zero.}
\item{delta}{Scalar or vector giving the unit of measurement (always
one for discrete data) for each response value, set to unity by
default. For example, if a response is measured to two decimals,
\code{delta=0.01}. If the response is transformed, this must be multiplied by
the Jacobian. The transformation cannot contain unknown
parameters. For example, with a log transformation,
\code{delta=1/y}. (The delta values for the censored response are
ignored.)}
\item{common}{If TRUE, the formulae with unknowns for the location and
shape have names in common. All parameter estimates must
be supplied in \code{pmu}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{y}. If \code{y} has class \code{repeated}, it is used as
the environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of class \code{hnlmix} is returned that contains all of the
relevant information calculated, including error codes.

The two variances and shrinkage estimates of the random effects are provided.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[rmutil]{finterp}},
\code{\link[growth]{elliptic}}, \code{\link[repeated]{glmm}},
\code{\link[repeated]{gnlmix}}, \code{\link[repeated]{gnlmm}},
\code{\link[gnlm]{gnlr}}, \code{\link[repeated]{kalseries}},
\code{\link[gnlm]{nlr}}, \code{\link[nls]{nls}}.
}
\examples{
library(growth)
dose <- c(9,12,4,9,11,10,2,11,12,9,9,9,4,9,11,9,14,7,9,8)
#y <- rgamma(20,2+0.3*dose,scale=2)+rep(rnorm(4,0,4),rep(5,4))
y <- c(8.674419, 11.506066, 11.386742, 27.414532, 12.135699,  4.359469,
       1.900681, 17.425948,  4.503345,  2.691792,  5.731100, 10.534971,
      11.220260,  6.968932,  4.094357, 16.393806, 14.656584,  8.786133,
      20.972267, 17.178012)
resp <- restovec(matrix(y, nrow=4, byrow=TRUE), name="y")
reps <- rmna(resp, tvcov=tvctomat(matrix(dose, nrow=4, byrow=TRUE), name="dose"))

# same linear normal model with random normal intercept fitted four ways
elliptic(reps, model=~dose, preg=c(0,0.6), pre=4)
glmm(y~dose, nest=individuals, data=reps)
gnlmm(reps, mu=~dose, pmu=c(8.7,0.25), psh=3.5, psd=3)
hnlmix(reps, mu=~a+b*dose+rand, random="rand", pmu=c(8.7,0.25),
	pshape=3.44, prandom=0)

# gamma model with log link and random normal intercept fitted three ways
glmm(y~dose, family=Gamma(link=log), nest=individuals, data=reps, points=8)
gnlmm(reps, distribution="gamma", mu=~exp(a+b*dose), pmu=c(2,0.03),
	psh=1, psd=0.3)
hnlmix(reps, distribution="gamma", mu=~exp(a+b*dose+rand), random="rand",
	pmu=c(2,0.04), pshape=1, prandom=0)

# gamma model with log link and random gamma mixtures
hnlmix(reps, distribution="gamma", mixture="gamma",
	mu=~exp(a*rand+b*dose), random="rand", pmu=c(2,0.04),
	pshape=1.24, prandom=1)
hnlmix(reps, distribution="gamma", mixture="gamma",
	mu=~exp(a+b*dose)*rand, random="rand", pmu=c(2,0.04),
	pshape=1.24, prandom=1)
}
\keyword{models}

\eof
\name{kalcount}
\title{Repeated Measurements Models for Counts with Frailty or Serial
Dependence}
\alias{kalcount}
\usage{
kalcount(response=NULL, times=NULL, origin=0,
	intensity="exponential", depend="independence", update="Markov",
	mu=NULL, shape=NULL, density=FALSE, ccov=NULL, tvcov=NULL, preg=NULL,
	ptvc=NULL, pbirth=NULL, pintercept=NULL, pshape=NULL, pinitial=1,
	pdepend=NULL, pfamily=NULL, envir=parent.frame(), print.level=0,
	ndigit=10, gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100,
	typsiz=abs(p), stepmax=10*sqrt(p%*%p))
}
\description{
\code{kalcount} is designed to handle repeated measurements models
with time-varying covariates. The distributions have two extra
parameters as compared to the functions specified by \code{intensity}
and are generally longer tailed than those distributions. Dependence
among observations on a unit can be through gamma or power variance
family frailties (a type of random effect), with or without
autoregression, or serial dependence over time.

By default, a gamma mixture of the distribution specified in
\code{intensity} is used, as the conditional distribution in the
\code{serial} dependence models, and as a symmetric multivariate
(random effect) model for \code{frailty} dependence.

Unless specified otherwise, the time origin is taken to be zero. The
given times are the ends of the periods in which the counts occurred.

Here, the variance, with exponential intensity, is a quadratic
function of the mean, whereas, for \code{\link[repeated]{nbkal}}, it is
proportional to the mean function.

If the counts on a unit are clustered, not longitudinal, use the
failty dependence with the default exponential intensity, yielding a
multivariate negative binomial distribution.

Nonlinear regression models can be supplied as formulae where
parameters are unknowns in which case factor variables cannot be used and
parameters must be scalars. (See \code{\link[rmutil]{finterp}}.)

Marginal and individual profiles can be plotted using
\code{\link[rmutil]{mprofile}} and \code{\link[rmutil]{iprofile}} and
residuals with \code{\link[rmutil]{plot.residuals}}.
}
\arguments{
\item{response}{A list of two column matrices with counts and
corresponding times for each individual, one matrix or dataframe of
counts, or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{times}{When response is a matrix, a vector of possibly unequally
spaced times when they are the same for all individuals or a matrix of
times. Not necessary if equally spaced. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{origin}{If the time origin is to be before the start of
observations, a positive constant to be added to all times.}
\item{intensity}{The form of function to be put in the Pareto distribution.
Choices are exponential, Weibull, gamma, log normal, log logistic,
log Cauchy, log Student, and gen(eralized) logistic.}
\item{depend}{Type of dependence. Choices are \code{independence},
\code{frailty}, and \code{serial}.}
\item{update}{Type of for serial dependence. Choices are
\code{Markov}, \code{serial}, \code{event}, \code{cumulated},
\code{count}, and \code{kalman}. With \code{frailty} dependence, weighting by
length of observation time may be specified by setting update to \code{time}.}
\item{mu}{A regression function for the location parameter or a
formula beginning with ~, specifying either a linear regression
function in the Wilkinson and Rogers notation (a log link is assumed)
or a general function with named unknown parameters. Give the initial
estimates in \code{preg} if there are no time-varying covariates and
in \code{ptvc} if there are.}
\item{shape}{A regression function for the shape parameter or a
formula beginning with ~, specifying either a linear regression
function in the Wilkinson and Rogers notation or a general function
with named unknown parameters. It must yield one value per observation.}
\item{density}{If TRUE, the density of the function specified in
\code{intensity} is used instead of the intensity.}
\item{ccov}{A vector or matrix containing time-constant baseline
covariates with one row per individual, a model formula using
vectors of the same size, or an object of class, \code{tccov} (created
by \code{\link[rmutil]{tcctomat}}). If response has class, \code{repeated},
the covariates must be supplied as a Wilkinson and Rogers formula
unless none are to be used or \code{mu} is given.}
\item{tvcov}{A list of matrices with time-varying covariate values,
observed in the time periods in \code{response}, for each individual
(one column per variable), one matrix or dataframe of such covariate
values, or an object of class, \code{tvcov} (created by
\code{\link[rmutil]{tvctomat}}). If response has class, \code{repeated}, the
covariates must be supplied as a Wilkinson and Rogers formula unless
none are to be used or \code{mu} is given.}
\item{preg}{Initial parameter estimates for the regression model:
intercept plus one for each covariate in \code{ccov}. If \code{mu} is
a formula or function, the parameter estimates must be given here only
if there are no time-varying covariates. If \code{mu} is a formula
with unknown parameters, their estimates must be supplied either in
their order of appearance in the expression or in a named list.}
\item{ptvc}{Initial parameter estimates for the coefficients of the
time-varying covariates, as many as in \code{tvcov}. If \code{mu} is a
formula or function, the parameter estimates must be given here if
there are time-varying covariates present.}
\item{pbirth}{If supplied, this is the initial estimate for the
coefficient of the birth model.}
\item{pintercept}{The initial estimate of the intercept for the
generalized logistic intensity.}
\item{pshape}{An initial estimate for the shape parameter of the
intensity function (except exponential intensity). If \code{shape} is
a function or formula, the corresponding initial estimates. If
\code{shape} is a formula with unknown parameters, their estimates
must be supplied either in their order of appearance in the expression
or in a named list.}
\item{pinitial}{An initial estimate for the initial parameter. With
\code{frailty} dependence, this is the frailty parameter.}
\item{pdepend}{An initial estimate for the serial dependence
parameter. For \code{frailty} dependence, if a value is given here, an
autoregression is fitted as well as the frailty.}
\item{pfamily}{An optional initial estimate for the second parameter
of a two-parameter power variance family mixture instead of the
default gamma mixture. This yields a gamma mixture as \code{family ->
0}, an inverse Gauss mixture for \code{family = 0.5}, and a compound
distribution of a Poisson-distributed number of gamma distributions
for \code{-1 < family < 0}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}.
If \code{response} has class \code{repeated}, it is used as the
environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of classes \code{kalcount} and \code{recursive} is returned.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}},
\code{\link[rmutil]{finterp}}, \code{\link[repeated]{gar}},
\code{\link[rmutil]{gettvc}}, \code{\link[repeated]{gnlmm}},
\code{\link[gnlm]{gnlr}}, \code{\link[rmutil]{iprofile}},
\code{\link[repeated]{kalseries}}, \code{\link[event]{kalsurv}},
\code{\link[rmutil]{mprofile}}, \code{\link[repeated]{nbkal}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}.
}
\examples{
treat <- c(0,0,1,1)
tr <- tcctomat(treat)
dose <- # matrix(rpois(20,10),ncol=5)
	matrix(c(9,13,16,7,12,6,9,10,11,9,10,10,7,9,9,9,8,10,15,4),
		ncol=5,byrow=TRUE)
dd <- tvctomat(dose)
y <- # matrix(rpois(20,1+3*rep(treat,5)),ncol=5)
	restovec(matrix(c(1,1,1,1,0,1,0,1,0,5,3,3,4,1,4,4,2,3,2,5),
		ncol=5,byrow=TRUE))
reps <- rmna(y, ccov=tr, tvcov=dd)
#
# log normal intensity, independence model
kalcount(y, intensity="log normal", dep="independence", preg=1,
	pshape=0.1)
# random effect
kalcount(y, intensity="log normal", dep="frailty", pinitial=0.1,
	preg=1, psh=0.1)
# serial dependence
kalcount(y, intensity="log normal", dep="serial", pinitial=0.1,
	preg=1, pdep=0.01, psh=0.1)
# random effect and autoregression
kalcount(y, intensity="log normal", dep="frailty", pinitial=0.1,
	pdep=0.1, preg=1, psh=0.1)
# add time-constant variable
kalcount(y, intensity="log normal", pinitial=0.1, psh=0.1,
	preg=c(1,0), ccov=treat)
# or equivalently
kalcount(y, intensity="log normal", mu=~treat, pinitial=0.1,
	psh=0.1, preg=c(1,0))
# or
kalcount(y, intensity="log normal", mu=~b0+b1*treat,
	pinitial=0.1, psh=0.1, preg=c(1,0), envir=reps)
# add time-varying variable
kalcount(y, intensity="log normal", pinitial=0.1, psh=0.1,
	preg=c(1,0), ccov=treat, ptvc=0, tvc=dose)
# or equivalently, from the environment
dosev <- as.vector(t(dose))
kalcount(y, intensity="log normal", mu=~b0+b1*rep(treat,rep(5,4))+b2*dosev,
	pinitial=0.1, psh=0.1, ptvc=c(1,0,0))
# or from the reps data object
kalcount(y, intensity="log normal", mu=~b0+b1*treat+b2*dose,
	pinitial=0.1, psh=0.1, ptvc=c(1,0,0), envir=reps)
# try power variance family
kalcount(y, intensity="log normal", mu=~b0+b1*treat+b2*dose,
	pinitial=0.001, psh=14, ptvc=c(5,-1,0.1), envir=reps,
	pfamily=0.8)
}
\keyword{models}

\eof
\name{kalseries}
\title{Repeated Measurements Models for Continuous Variables with
Frailty or Serial Dependence}
\alias{kalseries}
\usage{
kalseries(response=NULL, times=NULL, intensity="exponential",
	depend="independence", mu=NULL, shape=NULL, density=FALSE, ccov=NULL,
	tvcov=NULL, torder=0, interaction=NULL, preg=NULL, ptvc=NULL,
	pintercept=NULL, pshape=NULL, pinitial=1, pdepend=NULL,
	pfamily=NULL, delta=NULL, transform="identity", link="identity",
	envir=parent.frame(), print.level=0, ndigit=10, gradtol=0.00001,
	steptol=0.00001, fscale=1, iterlim=100, typsiz=abs(p),
	stepmax=10*sqrt(p%*%p))
}
\description{
\code{kalseries} is designed to handle repeated measurements models with
time-varying covariates. The distributions have two extra parameters
as compared to the functions specified by \code{intensity} and are
generally longer tailed than those distributions. Dependence among
observations on a unit can be through gamma or power variance family
frailties (a type of random effect), with or without autoregression,
or one of two types of serial dependence over time.

By default, a gamma mixture of the distribution specified in
\code{intensity} is used, as the conditional distribution in the
\code{Markov} and \code{serial} dependence models, and as a symmetric
multivariate (random effect) model for \code{frailty} dependence. For
example, with a Weibull \code{intensity} and \code{frailty}
dependence, this yields a multivariate Burr distribution and with
\code{Markov} or \code{serial} dependence, univariate Burr conditional
distributions.

If a value for \code{pfamily} is used, the gamma mixture is replaced
by a power variance family mixture.

Nonlinear regression models can be supplied as formulae where
parameters are unknowns in which case factor variables cannot be used and
parameters must be scalars. (See \code{\link[rmutil]{finterp}}.)

Marginal and individual profiles can be plotted using
\code{\link[rmutil]{mprofile}} and \code{\link[rmutil]{iprofile}} and
residuals with \code{\link[rmutil]{plot.residuals}}.
}
\arguments{
\item{response}{A list of two column matrices with responses and
corresponding times for each individual, one matrix or dataframe of
response values, or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{times}{When response is a matrix, a vector of possibly unequally
spaced times when they are the same for all individuals or a matrix of
times. Not necessary if equally spaced. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{intensity}{The form of function to be put in the Pareto distribution.
Choices are exponential, Weibull, gamma, normal, logistic, Cauchy,
log normal, log logistic, log Cauchy, log Student, inverse
Gauss, and gen(eralized) logistic. (For definitions of distributions,
see the corresponding [dpqr]distribution help.)}
\item{depend}{Type of dependence. Choices are \code{independence},
\code{Markov}, \code{serial}, and \code{frailty}.}
\item{mu}{A regression function for the location parameter or a
formula beginning with ~, specifying either a linear regression
function in the Wilkinson and Rogers notation or a general function
with named unknown parameters. Give the initial estimates in
\code{preg} if there are no time-varying covariates and in \code{ptvc}
if there are.}
\item{shape}{A regression function for the shape parameter or a
formula beginning with ~, specifying either a linear regression
function in the Wilkinson and Rogers notation or a general function
with named unknown parameters. It must yield one value per observation.}
\item{density}{If TRUE, the density of the function specified in
\code{intensity} is used instead of the intensity.}
\item{ccov}{A vector or matrix containing time-constant baseline
covariates with one row per individual, a model formula using
vectors of the same size, or an object of class, \code{tccov} (created
by \code{\link[rmutil]{tcctomat}}). If response has class, \code{repeated},
the covariates must be supplied as a Wilkinson and Rogers formula
unless none are to be used or \code{mu} is given.}
\item{tvcov}{A list of matrices with time-varying covariate values,
observed at the event times in \code{response}, for each individual
(one column per variable), one matrix or dataframe of such
covariate values, or an object of class, \code{tvcov} (created by
\code{\link[rmutil]{tvctomat}}). If a time-varying covariate is observed at
arbitrary time, \code{\link[rmutil]{gettvc}} can be used to find the most
recent values for each response and create a suitable list. If
response has class, \code{repeated}, the covariates must be supplied
as a Wilkinson and Rogers formula unless none are to be used or
\code{mu} is given.}
\item{torder}{The order of the polynomial in time to be fitted.}
\item{interaction}{Vector of length equal to the number of
time-constant covariates, giving the levels of interactions between
them and the polynomial in time in the \code{linear model}.}
\item{preg}{Initial parameter estimates for the regression model:
intercept, one for each covariate in \code{ccov}, and \code{torder} plus
sum(\code{interaction}). If \code{mu} is a formula or function, the
parameter estimates must be given here only if there are no
time-varying covariates. If \code{mu} is a formula with unknown
parameters, their estimates must be supplied either in their order of
appearance in the expression or in a named list.}
\item{ptvc}{Initial parameter estimates for the coefficients of the
time-varying covariates, as many as in \code{tvcov}. If \code{mu} is a
formula or function, the parameter estimates must be given here if
there are time-varying covariates present.}
\item{pintercept}{The initial estimate of the intercept for the
generalized logistic intensity.}
\item{pshape}{An initial estimate for the shape parameter of the
intensity function (except exponential intensity). If \code{shape} is
a function or formula, the corresponding initial estimates. If
\code{shape} is a formula with unknown parameters, their estimates
must be supplied either in their order of appearance in the expression
or in a named list.}
\item{pinitial}{An initial estimate for the initial parameter. With
\code{frailty} dependence, this is the frailty parameter.}
\item{pdepend}{An initial estimate for the serial dependence
parameter. For \code{frailty} dependence, if a value is given here, an
autoregression is fitted as well as the frailty.}
\item{pfamily}{An optional initial estimate for the second parameter
of a two-parameter power variance family mixture instead of the
default gamma mixture. This yields a gamma mixture as \code{family ->
0}, an inverse Gauss mixture for \code{family = 0.5}, and a compound
distribution of a Poisson-distributed number of gamma distributions
for \code{-1 < family < 0}.}
\item{delta}{Scalar or vector giving the unit of measurement for each
response value, set to unity by default. For example, if a response is
measured to two decimals, delta=0.01. If the response has been
pretransformed, this must be multiplied by the Jacobian. This
transformation cannot contain unknown parameters. For example, with a
log transformation, \code{delta=1/y}. The jacobian is calculated
automatically for the transform option. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{transform}{Transformation of the response variable: \code{identity},
\code{exp}, \code{square}, \code{sqrt}, or \code{log}.}
\item{link}{Link function for the mean: \code{identity}, \code{exp},
\code{square}, \code{sqrt}, or \code{log}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}.
If \code{response} has class \code{repeated}, it is used as the
environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
A list of classes \code{kalseries} and \code{recursive} is returned.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}},
\code{\link[rmutil]{finterp}}, \code{\link[repeated]{gar}},
\code{\link[rmutil]{gettvc}}, \code{\link[repeated]{gnlmm}},
\code{\link[gnlm]{gnlr}}, \code{\link[rmutil]{iprofile}},
\code{\link[repeated]{kalcount}}, \code{\link[event]{kalsurv}},
\code{\link[rmutil]{mprofile}}, \code{\link[rmutil]{read.list}},
\code{\link[rmutil]{restovec}}, \code{\link[rmutil]{rmna}},
\code{\link[rmutil]{tcctomat}}, \code{\link[rmutil]{tvctomat}}.
}
\examples{
treat <- c(0,0,1,1)
tr <- tcctomat(treat)
dose <- matrix(rpois(20,10), ncol=5)
dd <- tvctomat(dose)
y <- restovec(matrix(rnorm(20), ncol=5), name="y")
reps <- rmna(y, ccov=tr, tvcov=dd)
#
# normal intensity, independence model
kalseries(y, intensity="normal", dep="independence", preg=1, pshape=5)
# random effect
kalseries(y, intensity="normal", dep="frailty", preg=1, pinitial=1, psh=5)
# serial dependence
kalseries(y, intensity="normal", dep="serial", preg=1, pinitial=1,
	pdep=0.1, psh=5)
# random effect and autoregression
kalseries(y, intensity="normal", dep="frailty", preg=1, pinitial=1,
	pdep=0.1, psh=5)
#
# add time-constant variable
kalseries(y, intensity="normal", dep="serial", pinitial=1,
	pdep=0.1, psh=5, preg=c(1,0), ccov=treat)
# or equivalently
kalseries(y, intensity="normal", mu=~treat, dep="serial", pinitial=1,
	pdep=0.1, psh=5, preg=c(1,0))
# or
kalseries(y, intensity="normal", mu=~b0+b1*treat, dep="serial",
	pinitial=1, pdep=0.1, psh=5, preg=c(1,0), envir=reps)
#
# add time-varying variable
kalseries(y, intensity="normal", dep="serial", pinitial=1, pdep=0.1,
	psh=5, preg=c(1,0), ccov=treat, ptvc=0, tvc=dose)
# or equivalently, from the environment
dosev <- as.vector(t(dose))
kalseries(y, intensity="normal",
	mu=~b0+b1*rep(treat,rep(5,4))+b2*dosev,
	dep="serial", pinitial=1, pdep=0.1, psh=5, ptvc=c(1,0,0))
# or from the reps data object
kalseries(y, intensity="normal", mu=~b0+b1*treat+b2*dose,
	dep="serial", pinitial=1, pdep=0.1, psh=5, ptvc=c(1,0,0),
	envir=reps)
# try power variance family instead of gamma distribution for mixture
kalseries(y, intensity="normal", mu=~b0+b1*treat+b2*dose,
	dep="serial", pinitial=1, pdep=0.1, psh=5, ptvc=c(1,0,0),
	pfamily=0.1, envir=reps)
# first-order one-compartment model
# data objects for formulae
dose <- c(2,5)
dd <- tcctomat(dose)
times <- matrix(rep(1:20,2), nrow=2, byrow=TRUE)
tt <- tvctomat(times)
# vector covariates for functions
dose <- c(rep(2,20),rep(5,20))
times <- rep(1:20,2)
# functions
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
# response
conc <- matrix(rgamma(40,shape(log(c(0.01,1))),
	scale=mu(log(c(1,0.3,0.2))))/shape(log(c(0.1,0.4))),ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- restovec(ifelse(conc>0,conc,0.01))
reps <- rmna(conc, ccov=dd, tvcov=tt)
#
# constant shape parameter
kalseries(reps, intensity="gamma", dep="independence", mu=mu,
	ptvc=c(-1,-1.1,-1), pshape=1.5)
# or
kalseries(reps, intensity="gamma", dep="independence",
	mu=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	ptvc=list(absorption=-1,elimination=-1.1,volume=-1),
	pshape=1.2)
# add serial dependence
kalseries(reps, intensity="gamma", dep="serial", pdep=0.9,
	mu=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	ptvc=list(absorption=-1,elimination=-1.1,volume=-1),
	pshape=0.2)
# time dependent shape parameter
kalseries(reps, intensity="gamma", dep="independence", mu=mu,
	shape=shape, ptvc=c(-1,-1.1,-1), pshape=c(-3,0))
# or
kalseries(reps, intensity="gamma", dep="independence",
	mu=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	ptvc=list(absorption=-1,elimination=-1.1,volume=-1),
	shape=~exp(b1-b2)*times*dose*exp(-exp(b1)*times),
	pshape=list(b1=-3,b2=0))
# add serial dependence
kalseries(reps, intensity="gamma", dep="serial", pdep=0.5,
	mu=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	ptvc=list(absorption=-1,elimination=-1.1,volume=-1),
	shape=~exp(b1-b2)*times*dose*exp(-exp(b1)*times),
	pshape=list(b1=-3,b2=0))
}
\keyword{models}

\eof
\name{logitord}
\title{Ordinal Random Effects Models with Dropouts}
\alias{logitord}
\usage{
logitord(y, id, out.ccov=NULL, drop.ccov=NULL, tvcov=NULL,
	out.tvcov=!is.null(tvcov), drop.tvcov=!is.null(tvcov),
	pout, pdrop, prand.out, prand.drop,
	random.out.int=TRUE, random.out.slope=!is.null(tvcov),
	random.drop.int=TRUE, random.drop.slope=!is.null(tvcov),
	binom.mix=5, fcalls=900, eps=0.0001, print.level=0)
}
\description{
\code{logitord} fits an longitudinal proportional odds model in
discrete time to the ordinal outcomes and a logistic model to the
probability of dropping out using a common random effect for the two.
}
\arguments{
\item{y}{A vector of binary or ordinal responses with levels 1 to k
and 0 indicating drop-out.}
\item{id}{Identification number for each individual.}
\item{out.ccov}{A vector, matrix, or model formula of time-constant
covariates for the outcome regression, with variables having the same
length as \code{y}.}
\item{drop.ccov}{A vector, matrix, or model formula of time-constant
covariates for the drop-out regression, with variables having the same
length as \code{y}.}
\item{tvcov}{One time-varying covariate vector.}
\item{out.tvcov}{Include the time-varying covariate in the outcome
regression.}
\item{drop.tvcov}{Include the time-varying covariate in the drop-out
regression.}
\item{pout}{Initial estimates of the outcome regression coefficients,
with length equal to the number of levels of the response plus the
number of covariates minus one.}
\item{pdrop}{Initial estimates of the drop-out regression coefficients,
with length equal to one plus the number of covariates.}
\item{prand.out}{Optional initial estimates of the outcome random
parameters.}
\item{prand.drop}{Optional initial estimates of the drop-out random
parameters.}
\item{random.out.int}{If TRUE, the outcome intercept is random.}
\item{random.out.slope}{If TRUE, the slope of the time-varying covariate
is random for the outcome regression (only possible if a time-varying
covariate is supplied and if out.tvcov and random.out.int are TRUE).}
\item{random.drop.int}{If TRUE, the drop-out intercept is random.}
\item{random.drop.slope}{If TRUE, the slope of the time-varying covariate
is random for the drop-out regression (only possible if a time-varying
covariate is supplied and if drop.tvcov and random.drop.int are TRUE).}
\item{binom.mix}{The total in the binomial distribution used to
approximate the normal mixing distribution.}
\item{fcalls}{Number of function calls allowed.}
\item{eps}{Convergence criterion.}
\item{print.level}{If 1, the iterations are printed out.}
}
\references{
Ten Have, T.R., Kunselman, A.R., Pulkstenis, E.P. and Landis, J.R.
(1998) Biometrics 54, 367-383, for the binary case.
}
\value{
A list of class \code{logitord} is returned.
}
\author{T.R. Ten Have and J.K. Lindsey}
\seealso{
\code{\link[gnlm]{nordr}}, \code{\link[gnlm]{ordglm}}.
}
\examples{
y <- trunc(runif(20,max=4))
id <- gl(4,5)
age <- rpois(20,20)
times <- rep(1:5,4)
logitord(y, id=id, out.ccov=~age, drop.ccov=age, pout=c(1,0,0),
	pdrop=c(1,0))
logitord(y, id, tvcov=times, pout=c(1,0,0), pdrop=c(1,0))
}
\keyword{models}

\eof
\name{marg.hom}
\title{Marginal Homogeneity Models}
\alias{marg.hom}
\usage{
marg.hom(freq,marg1,marg2)
}
\description{
\code{marg.hom} fits a marginal homogeneity model to a contingency
table that has two margins of equal size.
}
\arguments{
\item{freq}{Vector of frequencies}
\item{marg1}{Factor variable for the first margin}
\item{marg2}{Factor variable for the second margin}
}
\value{
A list containing the call, the model, the deviance, the degrees of
freedom, the aic, the fitted values, and the residuals is returned.
}
\author{J.K. Lindsey}
\examples{
# 4x4x2 table in Freq, with margins indexed by Left and Right
Freq <- rpois(32,10)
Left <- gl(4,1,32)
Right <- gl(4,4,32)
marg.hom(Freq, Left, Right)
}
\keyword{models}

\eof
\name{nbkal}
\title{Negative Binomial Models with Kalman Update}
\alias{nbkal}
\usage{
nbkal(response, times, mu, preg, pdepend, kalman=TRUE,
	print.level=0, ndigit=10, gradtol=0.00001, steptol=0.00001,
	fscale=1, iterlim=100, typsiz=abs(p), stepmax=10*sqrt(p%*%p))
}
\description{
\code{nbkal} fits a negative binomial regression with Kalman update
over time. The variance is proportional to the mean function, whereas,
for \code{\link[repeated]{kalcount}} with exponential intensity, it is
a quadratic function of the mean.

Marginal and individual profiles can be plotted using
\code{\link[rmutil]{mprofile}} and \code{\link[rmutil]{iprofile}} and
residuals with \code{\link[rmutil]{plot.residuals}}.
}
\arguments{
\item{response}{A list of two column matrices with counts and
corresponding times for each individual, one matrix or dataframe of
counts, or an object of class, response (created by
\code{\link[rmutil]{restovec}}) or repeated (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}).}
\item{times}{When response is a matrix, a vector of possibly unequally
spaced times when they are the same for all individuals or a matrix of
times. Not necessary if equally spaced. Ignored if response has class,
response or repeated.}
\item{mu}{The mean function.}
\item{preg}{The initial parameter estimates for the mean function.}
\item{pdepend}{The estimates for the dependence parameters, either one or
three.}
\item{kalman}{If TRUE, fits the kalman update model, otherwise, a
standard negative binomial distribution.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
}
\references{
Lambert, P. (1996) Applied Statistics 45, 31-38.

Lambert, P. (1996) Biometrics 52, 50-55.
}
\value{
A list of classes \code{nbkal} and \code{recursive} is returned.
}
\author{P. Lambert and J.K. Lindsey}
\seealso{
\code{\link[repeated]{gar}}, \code{\link[repeated]{gnlmm}},
\code{\link[gnlm]{gnlr}}, \code{\link[rmutil]{iprofile}}
\code{\link[repeated]{kalcount}}, \code{\link[rmutil]{mprofile}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{rmna}},
\code{\link[rmutil]{restovec}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}.
}
\examples{
y <- matrix(rnbinom(20,5,0.5), ncol=5)
times <- matrix(rep(seq(10,50,by=10),4), ncol=5, byrow=TRUE)
y0 <- matrix(rep(rnbinom(5,5,0.5),4), ncol=5, byrow=TRUE)
mu <- function(p) p[1]*log(y0)+(times<30)*p[2]*
	(times-30)+(times>30)*p[3]*(times-30)
nbkal(y, preg=c(1.3,0.008,-0.05), times=times, pdep=1.2, mu=mu)
}
\keyword{models}

\eof
\name{repeated}
\title{Non-normal Repeated Measurements Library}
\alias{repeated}
\description{
\code{\link[repeated]{binnest}}			Binary Random Effects Model with Two Levels of Nesting

\code{\link[repeated]{biv.betab}}		Bivariate Beta-binomial Regression

\code{\link[repeated]{biv.binom}}		Marginal Bivariate Binomial Regression

\code{\link[repeated]{capture}}			Capture-recapture Model

\code{\link[repeated]{catmiss}}			Marginal Probabilities for Categorical Repeated Measures with Missing Data

\code{\link[repeated]{chidden}}			Continuous-Time Hidden Markov Chain Models

\code{\link[repeated]{cmcre}}		Continuous-time Two-state Markov Process with Random Effect

\code{\link[repeated]{cphidden}}			Changepoint Location using a Continuous-time Two-state Hidden Markov Chain

\code{\link[repeated]{gar}}			Generalized Autoregression

\code{\link[repeated]{gausscop}}	Multivariate Gaussian Copula with Arbitrary Marginals

\code{\link[repeated]{gnlmix}}			Generalized Nonlinear Regression with a Random Parameter

\code{\link[repeated]{glmm}}			Generalized Linear Mixed Models

\code{\link[repeated]{gnlmm}}			Generalized Nonlinear Mixed Models

\code{\link[repeated]{hidden}}			Discrete-Time Hidden Markov Chain Models

\code{\link[repeated]{hnlmix}}			Generalized Nonlinear Regression using h-likelihood for a Random Parameter

\code{\link[repeated]{kalcount}}		Generalized Repeated Measurements Models for Counts

\code{\link[repeated]{kalseries}}		Generalized Repeated Measurements Models for Continuous Variables

\code{\link[repeated]{logitord}}		Ordinal Random Effects Models with Dropouts

\code{\link[repeated]{marg.hom}}		Marginal Homogeneity Model

\code{\link[repeated]{nbkal}}			Negative Binomial Model with Kalman Update
}
\keyword{documentation}

\eof
