\name{Beta Binomial}
\title{Beta Binomial Distribution}
\usage{
dbetabinom(y, size, m, s, log=FALSE)
pbetabinom(q, size, m, s)
qbetabinom(p, size, m, s)
rbetabinom(n, size, m, s)
}
\alias{dbetabinom}
\alias{pbetabinom}
\alias{qbetabinom}
\alias{rbetabinom}
\description{
These functions provide information about the beta binomial
distribution with parameters \code{m} and \code{s}: density,
cumulative distribution, quantiles, and random generation.

The beta binomial distribution with total \eqn{= n} and
\code{prob} \eqn{= m} has density
\deqn{p(y) = \frac{B(y+\sigma \mu, n-y+\sigma*(1-\mu)) {n \choose y}
}{B(s m,s (1-m))}%
}{p(y) = B(y+s m,n-y+s (1-m)) Choose(n,y) / B(s m,s (1-m))}
for \eqn{y = 0, \ldots, n} where \eqn{B()} is the beta function.}
\arguments{
\item{y}{vector of frequencies}
\item{q}{vector of quantiles}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{size}{vector of totals}
\item{m}{vector of probabilities of success}
\item{s}{vector of overdispersion parameters}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dbinom}} for the binomial, \code{\link[rmutil]{ddoublebinom}} for
the double binomial, and \code{\link[rmutil]{dmultbinom}}
for the multiplicative binomial distribution.
}
\examples{
# compute P(45 < y < 55) for y beta binomial(100,0.5,1.1)
sum(dbetabinom(46:54, 100, 0.5, 1.1))
pbetabinom(54,100,0.5,1.1)-pbetabinom(45,100,0.5,1.1)
pbetabinom(2,10,0.5,1.1)
qbetabinom(0.33,10,0.5,1.1)
rbetabinom(10,10,0.5,1.1)
}
\keyword{distribution}

\eof
\name{Box-Cox}
\title{Box-Cox Distribution}
\usage{
dboxcox(y, m, s=1, f=1, log=FALSE)
pboxcox(q, m, s=1, f=1)
qboxcox(p, m, s=1, f=1)
hboxcox(y, m, s=1, f=1)
rboxcox(n, m, s=1, f=1)
}
\alias{dboxcox}
\alias{pboxcox}
\alias{qboxcox}
\alias{hboxcox}
\alias{rboxcox}
\description{
These functions provide information about the Box-Cox
distribution with location parameter equal to \code{m}, dispersion
equal to \code{s}, and power transformation equal to \code{f}: density,
cumulative distribution, quantiles, log hazard, and random generation.

The Box-Cox distribution has density
\deqn{
f(y) =
\frac{1}{\sqrt{2 \pi \sigma^2}} \exp(-((y^\nu/\nu-\mu)^2/(2 \sigma^2)))/
(1-I(\nu<0)-sign(\nu)*pnorm(0,\mu,sqrt(\sigma)))}{
f(y) = 1/sqrt(2 pi s^2) exp(-((y^f/f - mu)^2/(2 s^2)))/
(1-I(f<0)-sign(f)*pnorm(0,m,sqrt(s)))}
where \eqn{\mu}{m} is the location parameter of the distribution,
\eqn{\sigma}{s} is the dispersion, \eqn{\nu}{f} is the family
parameter, \eqn{I()} is the indicator function, and \eqn{y>0}.

\eqn{\nu=1}{f=1} gives a truncated normal distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of power parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dnorm}} for the normal or Gaussian distribution.
}
\examples{
dboxcox(2, 5, 5, 2)
pboxcox(2, 5, 5, 2)
qboxcox(0.1, 5, 5, 2)
rboxcox(10, 5, 5, 2)
}
\keyword{distribution}

\eof
\name{Burr}
\title{Burr Distribution}
\usage{
dburr(y, m, s, f, log=FALSE)
pburr(q, m, s, f)
qburr(p, m, s, f)
hburr(y, m, s, f)
rburr(n, m, s, f)
}
\alias{dburr}
\alias{pburr}
\alias{qburr}
\alias{hburr}
\alias{rburr}
\description{
These functions provide information about the Burr distribution with
location parameter equal to \code{m}, dispersion equal to
\code{s}, and family parameter equal to \code{f}: density,
cumulative distribution, quantiles, log hazard, and random generation.

The Burr distribution has density
\deqn{
f(y) = \frac{\nu \sigma (y / \mu)^{\sigma-1}}
{\mu (1+(y/\mu)^\sigma)^{\nu+1}}}{
f(y) = f s (y/m)^(s-1)/(m (1+(y/m)^s)^(f+1))}
where \eqn{\mu}{m} is the location parameter of the distribution,
\eqn{\sigma}{s} is the dispersion, and \eqn{\nu}{f} is the family
parameter.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of family parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\examples{
dburr(2, 5, 1, 2)
pburr(2, 5, 1, 2)
qburr(0.3, 5, 1, 2)
rburr(10, 5, 1, 2)
}
\keyword{distribution}

\eof
\name{Consul}
\title{Consul Distribution}
\usage{
dconsul(y, m, s, log=FALSE)
pconsul(q, m, s)
qconsul(p, m, s)
rconsul(n, m, s)
}
\alias{dconsul}
\alias{pconsul}
\alias{qconsul}
\alias{rconsul}
\description{
These functions provide information about the Consul
distribution with parameters \code{m} and \code{s}: density,
cumulative distribution, quantiles, and random generation.

The Consul distribution with \code{mu} \eqn{= m} has density
\deqn{p(y) = \mu \exp(-(\mu+y(\lambda-1))/\lambda) (\mu+y(\lambda-1))^(y-1)/(\lambda^y y!)%
}{p(y) = m exp(-(m+y(s-1))/s) (m+y(s-1))^(y-1)/(s^y y!)}
for \eqn{y = 0, \ldots}.
}
\arguments{
\item{y}{vector of counts}
\item{q}{vector of quantiles}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of means}
\item{s}{vector of overdispersion parameters}
\item{log}{if TRUE, log probabilities are supplied.}
}
\seealso{
\code{\link{dpois}} for the Poisson, \code{\link[rmutil]{ddoublepois}} for
the double Poisson, \code{\link[rmutil]{dmultpois}} for
the multiplicative Poisson, \code{\link[rmutil]{dpvfpois}} for the power
variance function Poisson, and \code{\link[rmutil]{dnbinom}}
for the negative binomial distribution.
}

\examples{
dconsul(5,10,0.9)
pconsul(5,10,0.9)
qconsul(0.08,10,0.9)
rconsul(10,10,0.9)
}
\keyword{distribution}

\eof
\name{DataMethods}
\title{Methods for response, tccov, tvcov, and repeated Data Objects}
\usage{
as.data.frame(z)
as.matrix(z)
covariates(z, nind=NULL, names=NULL, expand=F)
covind(z)
delta(z, nind=NULL, names=NULL)
formula(z)
names(z)
nesting(z, nind=NULL)
nobs(z)
plot(z, name=NULL, nind=NULL, nest=1, ccov=NULL, add=F, lty=NULL, pch=NULL,
	main=NULL, ylim=NULL, xlim=NULL, xlab=NULL, ylab=NULL, ...)
print(z, nindmax=50)
response(z, nind=NULL, names=NULL)
resptype(z)
times(z, nind=NULL)
transform(z, times=NULL, ...)
units(z)
weights(z, nind=NULL)
}
\alias{DataMethods}
\alias{covariates}
\alias{covariates.tccov}
\alias{covariates.tvccov}
\alias{covariates.repeated}
\alias{covind}
\alias{covind.default}
\alias{delta}
\alias{delta.response}
\alias{delta.repeated}
\alias{description}
\alias{description.default}
\alias{description.repeated}
\alias{formula.tccov}
\alias{formula.repeated}
\alias{names.response}
\alias{names.tccov}
\alias{names.tvcov}
\alias{names.repeated}
\alias{nesting}
\alias{nesting.response}
\alias{nesting.repeated}
\alias{nobs}
\alias{nobs.default}
\alias{nobs.response}
\alias{nobs.tvcov}
\alias{nobs.data.frame}
\alias{plot.response}
\alias{plot.repeated}
\alias{print.response}
\alias{print.tccov}
\alias{print.tvcov}
\alias{print.repeated}
\alias{response}
\alias{response.response}
\alias{response.repeated}
\alias{resptype}
\alias{resptype.response}
\alias{resptype.repeated}
\alias{times}
\alias{times.default}
\alias{times.response}
\alias{transform.response}
\alias{transform.tccov}
\alias{transform.tvcov}
\alias{transform.repeated}
\alias{units}
\alias{units.default}
\alias{units.repeated}
\alias{weights.response}
\alias{weights.repeated}
\description{
Objects of class, \code{response}, contain response values, and possibly
the corresponding times, binomial totals, nesting categories, censor
indicators, and/or units of precision/Jacobian. Objects of class,
\code{tccov}, contain time-constant or inter-individual, baseline
covariates. Objects of class, \code{tvcov}, contain time-varying or
intra-individual covariates. Objects of class, \code{repeated},
contain a \code{response} object and possibly \code{tccov} and
\code{tvcov} objects.

In formula and functions, the key words, \code{times} can be used to
refer to the response times from the data object as a covariate,
\code{individuals} to the index for individuals as a factor covariate,
and \code{nesting} the index for nesting as a factor covariate. The
latter two only work for W&R notation.

The following methods are available for accessing the contents of such
data objects.

\code{as.data.frame}: places all of the variables in the data object
in one dataframe, extending time-constant covariates to the length of
the others unless the object has class, \code{tccov}. Binomial and
censored response variables have two columns, respectively `yes' and
`no' and response and censoring indicator, with the name given to the
response.

\code{as.matrix}: places all of the variables in the data object
in one matrix, extending time-constant covariates to the length of
the others unless the object has class, \code{tccov}. If any
covariates are factor variables (instead of the corresponding sets of
indicator variables), the matrix will be character instead of numeric.

\code{covariates}: extracts covariate matrices from a data object (for
formulae and functions, possibly for selected individuals. See
\code{\link[rmutil]{covariates.formulafn}}).

\code{covind}: gives the indexing of the response by individual (that
is, the nesting indicator for observations within individuals). It can
be used to expand time-constant covariates to the size of the repeated
measurements response.

\code{delta}: extracts the units of measurement vector and Jacobian of
any transformation of the response, possibly for selected individuals.
Note that, if the unit of measurement/Jacobian is available in the
\code{response} object, this is automatically included in the
calculation of the likelihood function in all library model functions.

\code{units}: prints the variable names and their description
and returns the latter.

\code{formula}: gives the formula used to create the time-constant
covariate matrix of a data object (for formulae and functions, see
\code{\link[rmutil]{formula.formulafn}}).

\code{names}: extracts the names of the response and/or covariates.

\code{nesting}: gives the coding variable(s) for individuals (same as
\code{covind}) and also for nesting within individuals if available,
possibly for selected individuals.

\code{nobs}: gives the number of observations per individual.

\code{plot}: plots the variables in the data object in various ways.
For \code{repeated} objects, \code{name} can be a response or a
time-varying covariate.

\code{print}: prints summary information about the variables in a data object.

\code{response}: extracts the response vector, possibly for selected
individuals. If there are censored observations, this is a two-column
matrix, with the censor indicator in the second column. For binomial
data, it is a two-column matrix with "positive" (y) and "negative"
(totals-y) frequencies.

\code{resptype}: extracts the type of each response.

\code{times}: extracts the times vector, possibly for selected
individuals.

\code{transform}: transforms variables. For example,
\code{transform(z, y=fcn1(y), times=fcn2(times))} where \code{fcn1}
and \code{fcn2} are transformation functions. When the response is
transformed, the Jacobian is automatically calculated. New response
variables and covariates can be created in this way, if the left hand
side is a new name (\code{ynew=fcn3(y)}), as well as replacing an old
variable with the transformed one. If the transformation reverses the
order of the responses, use its negative to keep the ordering and have
a positive Jacobian; for example, \code{ry=-1/y}. For \code{repeated}
objects, only the response and the times can be transformed.

\code{units}: prints the variable names and their units of measurement
and returns the latter.

\code{weights}: extracts the weight vector, possibly for selected
individuals.
}
\arguments{
\item{z}{A \code{response}, \code{tccov}, \code{tvcov}, or
\code{repeated} data object. For \code{covind} and \code{nobs}, this
may also be a model.}
\item{y}{The function, when the response is to be transformed.}
\item{times}{The function, when the times are to be transformed.}
\item{names}{The names of the response variable(s) or covariate(s).}
\item{nind}{The numbers of individuals to be used. (For plotting,
cannot be used simultaneously with \code{ccov}.)}
\item{expand}{For intra-class (time-constant) covariates, if TRUE,
expand them to give one value per observation rather than one per
individual. Only works with \code{repeated} objects when all
individuals are requested (\code{nind=NULL}).}
\item{ccov}{For plotting: If a vector of values for the time-constant
covariates is supplied, only individuals having that set of values
will have profiles plotted. These values must be in the order in which
the covariates appear when the data object is printed. For factor
variables, the codes must be given. If the name of a covariate is
supplied, a set of graphs is plotted, one for each covariate value,
showing profiles of all individuals having that value. (The covariate
can have a maximum of six values.) Cannot be used simultaneously with
\code{nind}.} 
\item{nest}{For plotting: nesting category to plot.}
\item{add}{For plotting: add to previous plot.}
\item{nindmax}{For printing a \code{response}, \code{tvcov}, or
\code{repeated} object, if the number of individuals is greater than
\code{nindmax}, the range of numbers of observations per individual is
printed instead of the vector of numbers.}
}
\value{
These methods extract information stored in \code{response},
\code{tccov}, \code{tvcov}, and \code{repeated} data objects created
respectively by \code{\link[rmutil]{restovec}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}, and \code{\link[rmutil]{rmna}}.

Note that if a vector of binomial totals or a censoring indicator is
present, this is extract as the second column of the matrix produced
by the \code{response} method.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{restovec}}, \code{\link[rmutil]{rmna}},
\code{\link[rmutil]{tcctomat}}, \code{\link[rmutil]{tvctomat}}.
}
\examples{
# set up some data and create the objects
#
y <- matrix(rnorm(20),ncol=5)
tt <- c(1,3,6,10,15)
print(resp <- restovec(y, times=tt, units="m", type="duration"))
x <- c(0,0,1,1)
x2 <- as.factor(c("a","b","a","b"))
tcc <- tcctomat(data.frame(x=x,x2=x2))
z <- matrix(rpois(20,5),ncol=5)
tvc <- tvctomat(z)
print(reps <- rmna(resp, tvcov=tvc, ccov=tcc))
#
plot(resp)
plot(reps)
plot(reps, nind=1:2)
plot(reps, ccov=c(0,1))
plot(reps, ccov="x2")
plot(reps, name="z", nind=3:4, pch=1:2)
plot(reps, name="z", ccov="x2")
#
response(resp)
response(transform(resp, y=1/y))
response(reps)
response(reps, nind=2:3)
response(transform(reps,y=1/y))
#
times(resp)
times(transform(resp,times=times-6))
times(reps)
#
delta(resp)
delta(reps)
delta(transform(reps,y=1/y))
delta(transform(reps,y=1/y), nind=3)
#
nobs(resp)
nobs(tvc)
nobs(reps)
#
units(resp)
units(reps)
#
resptype(resp)
resptype(reps)
#
weights(resp)
weights(reps)
#
covariates(tcc)
covariates(tcc, nind=2:3)
covariates(tvc)
covariates(tvc, nind=3)
covariates(reps)
covariates(reps, nind=3)
covariates(reps,names="x")
covariates(reps,names="z")
#
names(tcc)
names(tvc)
names(reps)
#
nesting(resp)
nesting(reps)
#
# because individuals are the only nesting, this is the same as
covind(resp)
covind(reps)
#
as.data.frame(resp)
as.data.frame(tcc)
as.data.frame(tvc)
as.data.frame(reps)
#
# use in glm
rm(y,x,z)
glm(y~x+z, data=reps)
}
\keyword{manip}

\eof
\name{Double Binomial}
\title{Double Binomial Distribution}
\usage{
ddoublebinom(y, size, m, s, log=FALSE)
pdoublebinom(q, size, m, s)
qdoublebinom(p, size, m, s)
rdoublebinom(n, size, m, s)
}
\alias{ddoublebinom}
\alias{pdoublebinom}
\alias{qdoublebinom}
\alias{rdoublebinom}
\description{
These functions provide information about the double binomial
distribution with parameters \code{m} and \code{s}: density,
cumulative distribution, quantiles, and random generation.

The double binomial distribution with total \eqn{= n} and
\code{prob} \eqn{= m} has density
\deqn{p(y) = c({n}, {m}, {s}){n \choose y} ({m}/{y})^({y}\log({s})) {((1-m)/(n-y))}^(({n-y})\log({s})) {y}^{y} {(n-y)}^{(n-y)})%
}{p(y) = c(n,m,s) Choose(n,y) n^(n log(s)) (m/y)^(y log(s))
((1-m)/(n-y))^(s(n-y)) y^y (n-y)^(n-y)}
for \eqn{y = 0, \ldots, n}, where c(.) is a normalizing constant.
}
\arguments{
\item{y}{vector of frequencies}
\item{q}{vector of quantiles}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{size}{vector of totals}
\item{m}{vector of probabilities of success}
\item{s}{vector of overdispersion parameters}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dbinom}} for the binomial, \code{\link[rmutil]{dmultbinom}} for
the multiplicative binomial, and \code{\link[rmutil]{dbetabinom}}
for the beta binomial distribution.
}
\examples{
# compute P(45 < y < 55) for y double binomial(100,0.5,1.1)
sum(ddoublebinom(46:54, 100, 0.5, 1.1))
pdoublebinom(54, 100, 0.5, 1.1)-pdoublebinom(45, 100, 0.5, 1.1)
pdoublebinom(2,10,0.5,1.1)
qdoublebinom(0.05,10,0.5,1.1)
rdoublebinom(10,10,0.5,1.1)
}
\keyword{distribution}

\eof
\name{DoublePoisson}
\title{Double Poisson Distribution}
\usage{
ddoublepois(y, m, s, log=FALSE)
pdoublepois(q, m, s)
qdoublepois(p, m, s)
rdoublepois(n, m, s)
}
\alias{ddoublepois}
\alias{pdoublepois}
\alias{qdoublepois}
\alias{rdoublepois}
\description{
These functions provide information about the double Poisson
distribution with parameters \code{m} and \code{s}: density,
cumulative distribution, quantiles, and random generation.

The double Poisson distribution with \code{mu} \eqn{= m} has density
\deqn{p(y) = c({\mu}, {\lambda}) {\lambda}^({y}/{\mu}) ({\mu}/{y})^(y\log({\lambda})) {y}^{(y-1)} / {y!}%
}{p(y) = c(m,s) s^(y/m) (m/y)^(y log(s)) y^(y-1) / y!}
for \eqn{y = 0, \ldots}, where c(.) is a normalizing constant.
}
\arguments{
\item{y}{vector of counts}
\item{q}{vector of quantiles}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of means}
\item{s}{vector of overdispersion parameters}
\item{log}{if TRUE, log probabilities are supplied.}
}
\seealso{
\code{\link{dpois}} for the Poisson, \code{\link[rmutil]{dconsul}} for
the Consul generalized Poisson, \code{\link[rmutil]{dgammacount}} for
the gamma count, \code{\link[rmutil]{dmultpois}} for the
multiplicative Poisson, \code{\link[rmutil]{dpvfpois}} for the power
variance function Poisson, and \code{\link{dnbinom}} for the negative
binomial distribution.
}

\examples{
ddoublepois(5,10,0.9)
pdoublepois(5,10,0.9)
qdoublepois(0.08,10,0.9)
rdoublepois(10,10,0.9)
}
\keyword{distribution}

\eof
\name{FormulaMethods}
\title{Methods for formulafn Functions}
\usage{
covariates(z)
formula(z)
model(z)
parameters(z)
print(z)
}
\alias{covariates.formulafn}
\alias{formula.formulafn}
\alias{model}
\alias{model.formulafn}
\alias{parameters}
\alias{parameters.formulafn}
\description{
Methods for accessing the contents of a function created from formula
produced by \code{\link[rmutil]{finterp}} or a function modified by
\code{\link[rmutil]{fnenvir}}.

\code{covariates}: extract the names of the covariates.

\code{formula}: extract the formula used to produce the function
(\code{\link[rmutil]{finterp}} only).

\code{model}: extract the model function or model matrix if W&R
notation was used.

\code{parameters}: extract the names of the parameters.
}
\arguments{
\item{z}{A function of class, \code{formulafn}.}
}
\value{
These methods extract information about functions of class, \code{formulafn},
created by \code{\link[rmutil]{finterp}} or \code{\link[rmutil]{fnenvir}}.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{finterp}}, \code{\link[rmutil]{fnenvir}}.
}
\examples{
x1 <- rpois(20,2)
x2 <- rnorm(20)
#
# Wilkinson and Rogers formula with three parameters
fn1 <- finterp(~x1+x2)
fn1
covariates(fn1)
formula(fn1)
model(fn1)
parameters(fn1)
#
# nonlinear formula with unknowns
fn2 <- finterp(~exp(b0+b1*x1+b2*x2))
fn2
covariates(fn2)
formula(fn2)
model(fn2)
parameters(fn2)
#
# function transformed by fnenvir
fn3 <- fnenvir(function(p) p[1]+p[2]*x1)
covariates(fn3)
formula(fn3)
model(fn3)
parameters(fn3)
}
\keyword{manip}

\eof
\name{Generalized Extreme Value}
\title{Generalized Extreme Value Distribution}
\usage{
dgextval(y, s, m, f, log=FALSE)
pgextval(q, s, m, f)
qgextval(p, s, m, f)
hgextval(y, s, m, f)
rgextval(n, s, m, f)
}
\alias{dgextval}
\alias{pgextval}
\alias{qgextval}
\alias{hgextval}
\alias{rgextval}
\description{
These functions provide information about the generalized extreme
value distribution with location parameter equal to \code{m}, dispersion
equal to \code{s}, and family parameter equal to \code{f}: density,
cumulative distribution, quantiles, log hazard, and random generation.

The generalized extreme value distribution has density
\deqn{
  f(y) =
  y^{\nu-1} \exp(y^\nu/\nu) \frac{\sigma}{\mu}
  \frac{\exp(y^\nu/\nu)}{\mu^{\sigma-1}/(1-I(\nu>0)+sign(\nu)
  exp(-\mu^-\sigma))}\exp(-(\exp(y^\nu\nu)/\mu)^\sigma)}{
  f(y) = y^(f-1) exp(y^f/f) (s/m) (exp(y^f/f)/m)^(s-1)
exp(-(exp(y^f/f)/m)^s)/(1-I(f>0)+sign(f) exp(-m^-s))}
	
where \eqn{\mu}{m} is the location parameter of the distribution,
\eqn{\sigma}{s} is the dispersion, \eqn{\nu}{f} is the family
parameter, \eqn{I()} is the indicator function, and \eqn{y>0}.

\eqn{\nu=1}{f=1} a truncated extreme value distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of family parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}

\seealso{
\code{\link{dweibull}} for the Weibull distribution.
}
\examples{
dgextval(1, 2, 1, 2)
pgextval(1, 2, 1, 2)
qgextval(0.82, 2, 1, 2)
rgextval(10, 2, 1, 2)
}
\keyword{distribution}

\eof
\name{Generalized Gamma}
\title{Generalized Gamma Distribution}
\usage{
dggamma(y, s, m, f, log=FALSE)
pggamma(q, s, m, f)
qggamma(p, s, m, f)
hggamma(y, s, m, f)
rggamma(n, s, m, f)
}
\alias{dggamma}
\alias{pggamma}
\alias{qggamma}
\alias{hggamma}
\alias{rggamma}
\description{
These functions provide information about the generalized gamma
distribution with scale parameter equal to \code{m}, shape equal
to \code{s}, and family parameter equal to \code{f}: density,
cumulative distribution, quantiles, log hazard, and random generation.

The generalized gamma distribution has density
\deqn{
  f(y) = \frac{\nu y^{\nu-1}}
  {(\mu/\sigma)^{\nu\sigma} Gamma(\sigma)} y^{\nu(\sigma-1)}
  \exp(-(y \sigma/\mu)^\nu)}{
  f(y) = fy^(f-1)/((m/s)^(fs) Gamma(s)) y^(f(s-1)) exp(-(y s/m)^f)}
	
where \eqn{\mu}{m} is the scale parameter of the distribution,
\eqn{\sigma}{s} is the shape, and \eqn{\nu}{f} is the family
parameter.

\eqn{\nu=1}{f=1} yields a gamma distribution, \eqn{\sigma=1}{s=1} a
Weibull distribution, and \eqn{\sigma=\infty}{s=infinity} a
log normal distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of family parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dgamma}} for the gamma distribution,
\code{\link{dweibull}} for the Weibull distribution, \code{\link{dlnorm}}
for the log normal distribution.
}
\examples{
dggamma(2, 5, 4, 2)
pggamma(2, 5, 4, 2)
qggamma(0.75, 5, 4, 2)
rggamma(10, 5, 4, 2)
}
\keyword{distribution}

\eof
\name{Generalized Inverse Gaussian}
\title{Generalized Inverse Gaussian Distribution}
\usage{
dginvgauss(y, m, s, f, log=FALSE)
pginvgauss(q, m, s, f)
qginvgauss(p, m, s, f)
hginvgauss(y, m, s, f)
rginvgauss(n, m, s, f)
}
\alias{dginvgauss}
\alias{pginvgauss}
\alias{qginvgauss}
\alias{hginvgauss}
\alias{rginvgauss}
\description{
These functions provide information about the generalized inverse
Gaussian distribution with mean equal to \code{m}, dispersion equal to
\code{s}, and family parameter equal to \code{f}: density,
cumulative distribution, quantiles, log hazard, and random generation.

The generalized inverse Gaussian distribution has density
\deqn{
f(y) =
\frac{y^{\nu-1}}{2 \mu^\nu K(1/(\sigma \mu),abs(\nu))}
	\exp(-(1/y+y/\mu^2)/(2*\sigma))}{
f(y) = y^(f-1)/(2 m^f K(1/(s m),abs(f)))
	 exp(-(1/y+y/m^2)/(2*s))}
where \eqn{\mu}{m} is the mean of the distribution,
\eqn{\sigma}{s} the dispersion, \eqn{\nu}{f} is the family
parameter, and \eqn{K()}{K()} is the fractional Bessel function of
the third kind.

\eqn{\nu=-1/2}{f=-1/2} yields an inverse Gaussian distribution,
\eqn{\sigma=\infty}{s=infinity}, \eqn{\nu>0}{f>0} a gamma
distribution, and \eqn{\nu=0}{f=0} a hyperbola distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of means.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of family parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{dinvgauss}} for the inverse Gaussian distribution.
}
\examples{
dginvgauss(10, 3, 1, 1)
pginvgauss(10, 3, 1, 1)
qginvgauss(0.4, 3, 1, 1)
rginvgauss(10, 3, 1, 1)
}
\keyword{distribution}

\eof
\name{Generalized Logistic}
\title{Generalized Logistic Distribution}
\usage{
dglogis(y, m=0, s=1, f=1, log=FALSE)
pglogis(q, m=0, s=1, f=1)
qglogis(p, m=0, s=1, f=1)
hglogis(y, m=0, s=1, f=1)
rglogis(n, m=0, s=1, f=1)
}
\alias{dglogis}
\alias{pglogis}
\alias{qglogis}
\alias{hglogis}
\alias{rglogis}
\description{
These functions provide information about the generalized logistic
distribution with location parameter equal to \code{m}, dispersion equal
to \code{s}, and family parameter equal to \code{f}: density,
cumulative distribution, quantiles, log hazard, and random generation.

The generalized logistic distribution has density
\deqn{
f(y) =
\frac{\nu \sqrt{3} \exp(-\sqrt{3} (y-\mu)/(\sigma \pi))}{
\sigma \pi (1+\exp(-\sqrt{3} (y-\mu)/(\sigma \pi)))^{\nu+1}}}{
f(y) = f sqrt(3) exp(-sqrt(3) (y-m)/(s pi))/
(s pi (1+exp(-sqrt(3) (y-m)/(s pi)))^(f+1))}
	
where \eqn{\mu}{m} is the location parameter of the distribution,
\eqn{\sigma}{s} is the dispersion, and \eqn{\nu}{f} is the family
parameter.

\eqn{\nu=1}{f=1} gives a logistic distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of family parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dlogis}} for the logistic distribution.
}
\examples{
dglogis(5, 5, 1, 2)
pglogis(5, 5, 1, 2)
qglogis(0.25, 5, 1, 2)
rglogis(10, 5, 1, 2)
}
\keyword{distribution}

\eof
\name{Generalized Weibull}
\title{Generalized Weibull Distribution}
\usage{
dgweibull(y, s, m, f, log=FALSE)
pgweibull(q, s, m, f)
qgweibull(p, s, m, f)
hgweibull(y, s, m, f)
rgweibull(n, s, m, f)
}
\alias{dgweibull}
\alias{pgweibull}
\alias{qgweibull}
\alias{hgweibull}
\alias{rgweibull}
\description{
These functions provide information about the generalized Weibull
distribution, also called the exponentiated Weibull, with scale
parameter equal to \code{m}, shape equal to \code{s}, and family
parameter equal to \code{f}: density, cumulative distribution,
quantiles, log hazard, and random generation.

The generalized Weibull distribution has density
\deqn{
f(y) = \frac{\sigma \nu y^{\sigma-1} (1-\exp(-(y/\mu)^\sigma))^{\nu-1}
\exp(-(y/\mu)^\sigma)}{\mu^\sigma}}{
f(y) = s f y^(s-1) (1-exp(-(y/m)^s))^(f-1) exp(-(y/m)^s)/m^s}
	
where \eqn{\mu}{m} is the scale parameter of the distribution,
\eqn{\sigma}{s} is the shape, and \eqn{\nu}{f} is the family
parameter.

\eqn{\nu=1}{f=1} gives a Weibull distribution, for
\eqn{\sigma=1}{s=1}, \eqn{\nu<0}{f<0} a generalized F distribution,
and for \eqn{\sigma>0}{s>0}, \eqn{\nu\leq0}{f<=0} a Burr type XII distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of family parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dweibull}} for the Weibull distribution,
\code{\link{df}} for the F distribution,
\code{\link[rmutil]{dburr}} for the Burr distribution.
}
\examples{
dgweibull(5, 1, 3, 2)
pgweibull(5, 1, 3, 2)
qgweibull(0.65, 1, 3, 2)
rgweibull(10, 1, 3, 2)
}
\keyword{distribution}

\eof
\name{Gamma Count}
\title{Gamma Count Distribution}
\usage{
dgammacount(y, m, s, log=FALSE)
pgammacount(q, m, s)
qgammacount(p, m, s)
rgammacount(n, m, s)
}
\alias{dgammacount}
\alias{pgammacount}
\alias{qgammacount}
\alias{rgammacount}
\description{
These functions provide information about the gamma count
distribution with parameters \code{m} and \code{s}: density,
cumulative distribution, quantiles, and random generation.

The gamma count distribution with \code{prob} \eqn{= m} has density
\deqn{p(y) = pgamma(\mu \sigma,y \sigma,1)-pgamma(\mu \sigma,(y+1) \sigma,1)
}{p(y) = pgamma(m s, y s, 1)-pgamma(m s, (y+1) s, 1)}
for \eqn{y = 0, \ldots, n} where
\eqn{pgamma(\mu \sigma,0,1)=1}{pgamma(m s, 0, 1)=1}.
}
\arguments{
\item{y}{vector of frequencies}
\item{q}{vector of quantiles}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of probabilities}
\item{s}{vector of overdispersion parameters}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dpois}} for the Poisson, \code{\link[rmutil]{dconsul}} for
the Consul generalized Poisson, \code{\link[rmutil]{ddoublepois}} for
the double Poisson, \code{\link[rmutil]{dmultpois}}
for the multiplicative Poisson distributions, and \code{\link{dnbinom}}
for the negative binomial distribution.
}
\examples{
dgammacount(5,10,0.9)
pgammacount(5,10,0.9)
qgammacount(0.08,10,0.9)
rgammacount(10,10,0.9)
}
\keyword{distribution}

\eof
\name{Hjorth}
\title{Hjorth Distribution}
\usage{
dhjorth(y, m, s, f, log=FALSE)
phjorth(q, m, s, f)
qhjorth(p, m, s, f)
hhjorth(y, m, s, f)
rhjorth(n, m, s, f)
}
\alias{dhjorth}
\alias{phjorth}
\alias{qhjorth}
\alias{hhjorth}
\alias{rhjorth}
\description{
These functions provide information about the Hjorth
distribution with location parameter equal to \code{m}, dispersion equal
to \code{s}, and family parameter equal to \code{f}: density,
cumulative distribution, quantiles, log hazard, and random generation.

The Hjorth distribution has density
\deqn{
f(y) = (1+\sigma y)^{-\nu/\sigma} \exp(-(y/\mu)^2/2)
(\frac{y}{\mu^2}+\frac{\nu}{1+\sigma y})}{
f(y) = (1+s y)^(-f/s) exp(-(y/m)^2/2) (y/m^2+f/(1+s y))}
	
where \eqn{\mu}{m} is the location parameter of the distribution,
\eqn{\sigma}{s} is the dispersion, and \eqn{\nu}{f} is the family
parameter.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of family parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\examples{
dhjorth(5, 5, 5, 2)
phjorth(5, 5, 5, 2)
qhjorth(0.8, 5, 5, 2)
rhjorth(10, 5, 5, 2)
}
\keyword{distribution}

\eof
\name{Inverse Gaussian}
\title{Inverse Gaussian Distribution}
\usage{
dinvgauss(y, m, s, log=FALSE)
pinvgauss(q, m, s)
qinvgauss(p, m, s)
hinvgauss(y, m, s)
rinvgauss(n, m, s)
}
\alias{dinvgauss}
\alias{pinvgauss}
\alias{qinvgauss}
\alias{hinvgauss}
\alias{rinvgauss}
\description{
These functions provide information about the inverse Gaussian
distribution with mean equal to \code{m} and dispersion equal to
\code{s}: density, cumulative distribution, quantiles, log hazard, and
random generation.

The inverse Gaussian distribution has density
\deqn{
f(y) =
\frac{1}{\sqrt{2\pi\sigma y^3}} e^{-(y-\mu)^2/(2 y \sigma m^2)}}{
f(y) = 1/sqrt(2 pi s y^3) e^-((y - m)^2/(2 y s m^2))}
where \eqn{\mu}{m} is the mean of the distribution and
\eqn{\sigma}{s} is the dispersion.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of means.}
\item{s}{vector of dispersion parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dnorm}} for the normal distribution and
\code{\link{dlnorm}} for the \emph{Log}normal distribution.
}
\examples{
dinvgauss(5, 5, 1)
pinvgauss(5, 5, 1)
qinvgauss(0.8, 5, 1)
rinvgauss(10, 5, 1)
}
\keyword{distribution}

\eof
\name{Laplace}
\title{Laplace Distribution}
\usage{
dlaplace(y, m=0, s=1, log=FALSE)
plaplace(q, m=0, s=1)
qlaplace(p, m=0, s=1)
hlaplace(y, m=0, s=1)
rlaplace(n, m=0, s=1)
}
\alias{dlaplace}
\alias{plaplace}
\alias{qlaplace}
\alias{hlaplace}
\alias{rlaplace}
\description{
These functions provide information about the Laplace distribution
with location parameter equal to \code{m} and dispersion equal to
\code{s}: density, cumulative distribution, quantiles, log hazard, and
random generation.

The Laplace distribution has density
\deqn{
f(y) = \frac{\exp(-abs(y-\mu)/\sigma)}{(2\sigma)}}{
f(y) = exp(-abs(y-m)/s)/(2*s)}
where \eqn{\mu}{m} is the location parameter of the distribution and
\eqn{\sigma}{s} is the dispersion.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dexp}} for the exponential distribution and
\code{\link{dcauchy}} for the Cauchy distribution.
}
\examples{
dlaplace(5, 2, 1)
plaplace(5, 2, 1)
qlaplace(0.95, 2, 1)
rlaplace(10, 2, 1)
}
\keyword{distribution}

\eof
\name{Levy}
\title{Levy Distribution}
\usage{
dlevy(y, m=0, s=1, log=FALSE)
plevy(q, m=0, s=1)
qlevy(p, m=0, s=1)
rlevy(n, m=0, s=1)
}
\alias{dlevy}
\alias{plevy}
\alias{qlevy}
\alias{rlevy}
\description{
These functions provide information about the Levy distribution
with location parameter equal to \code{m} and dispersion equal to
\code{s}: density, cumulative distribution, quantiles, and
random generation.

The Levy distribution has density
\deqn{
f(y) = \sqrt{\frac{\sigma}{2 \pi (y-\mu)^3}} \exp(-\sigma/(2 (y-\mu)))}{
f(y) = sqrt(s/(2 pi (y-m)^3)) exp(-s/(2 (y-m)))}
where \eqn{\mu}{m} is the location parameter of the distribution and
\eqn{\sigma}{s} is the dispersion, and \eqn{y>\mu}{y>m}.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dnorm}} for the normal distribution and
\code{\link{dcauchy}} for the Cauchy distribution, two other stable
distributions.
}
\examples{
dlevy(5, 2, 1)
plevy(5, 2, 1)
qlevy(0.6, 2, 1)
rlevy(10, 2, 1)
}
\keyword{distribution}

\eof
\name{Multiplicative Binomial}
\title{Multiplicative Binomial Distribution}
\usage{
dmultbinom(y, size, m, s, log=FALSE)
pmultbinom(q, size, m, s)
qmultbinom(p, size, m, s)
rmultbinom(n, size, m, s)
}
\alias{dmultbinom}
\alias{pmultbinom}
\alias{qmultbinom}
\alias{rmultbinom}
\description{
These functions provide information about the multiplicative binomial
distribution with parameters \code{m} and \code{s}: density,
cumulative distribution, quantiles, and random generation.

The multiplicative binomial distribution with total \eqn{= n} and
\code{prob} \eqn{= m} has density
\deqn{p(y) = c({n}, {m}, {s}){n \choose y} {m}^{y} {(1-m)}^{n-y} {s}^{(y(n-y))}
}{p(y) = c(n,m,s) Choose(n,y) m^y (1-m)^(n-y) s^(y(n-y))}
for \eqn{y = 0, \ldots, n}, where c(.) is a normalizing constant.
}
\arguments{
\item{y}{vector of frequencies}
\item{q}{vector of quantiles}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{size}{vector of totals}
\item{m}{vector of probabilities of success}
\item{s}{vector of overdispersion parameters}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dbinom}} for the binomial, \code{\link[rmutil]{ddoublebinom}} for
the double binomial, and \code{\link[rmutil]{dbetabinom}}
for the beta binomial distribution.
}
\examples{
# compute P(45 < y < 55) for y multiplicative binomial(100,0.5,1.1)
sum(dmultbinom(46:54, 100, 0.5, 1.1))
pmultbinom(54, 100, 0.5, 1.1)-pmultbinom(45, 100, 0.5, 1.1)
pmultbinom(2,10,0.5,1.1)
qmultbinom(0.025,10,0.5,1.1)
rmultbinom(10,10,0.5,1.1)
}
\keyword{distribution}

\eof
\name{MultPoisson}
\title{Multiplicative Poisson Distribution}
\usage{
dmultpois(y, m, s, log=FALSE)
pmultpois(q, m, s)
qmultpois(p, m, s)
rmultpois(n, m, s)
}
\alias{dmultpois}
\alias{pmultpois}
\alias{qmultpois}
\alias{rmultpois}
\description{
These functions provide information about the multiplicative Poisson
distribution with parameters \code{m} and \code{s}: density,
cumulative distribution, quantiles, and random generation.

The multiplicative Poisson distribution with \code{mu} \eqn{= m} has density
\deqn{p(y) = c({\mu}, {\lambda})\exp({-\mu}) {\mu}^{y} {\lambda}^({y}^2) / {y!}%
}{p(y) = c(m,s) exp(-m) m^y s^(y^2) / y!}
with \eqn{s <= 1} for \eqn{y = 0, \ldots}, where c(.) is a normalizing
constant.

Note that it only allows for underdispersion, not being defined for
\eqn{s > 1}.
}
\arguments{
\item{y}{vector of counts}
\item{q}{vector of quantiles}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{scalar or vector of means}
\item{s}{scalar or vector of overdispersion parameters, all of which
must lie in (0,1). }
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dpois}} for the Poisson, \code{\link[rmutil]{ddoublepois}} for
the double Poisson, \code{\link[rmutil]{dpvfpois}} for the power variance
function Poisson, \code{\link[rmutil]{dconsul}} for the Consul
generalized Poisson, \code{\link[rmutil]{dgammacount}} for the gamma count, and
\code{\link{dnbinom}} for the negative binomial distribution.
}
\examples{
dmultpois(5,10,0.9)
pmultpois(5,10,0.9)
qmultpois(0.85,10,0.9)
rmultpois(10,10,0.9)
}
\keyword{distribution}

\eof
\name{Pareto}
\title{Pareto Distribution}
\usage{
dpareto(y, m, s, log=FALSE)
ppareto(q, m, s)
qpareto(p, m, s)
hpareto(y, m, s)
rpareto(n, m, s)
}
\alias{dpareto}
\alias{ppareto}
\alias{qpareto}
\alias{hpareto}
\alias{rpareto}
\description{
These functions provide information about the Pareto distribution
with location parameter equal to \code{m} and dispersion equal to
\code{s}: density, cumulative distribution, quantiles, log hazard, and
random generation.

The Pareto distribution has density
\deqn{
f(y) = \frac{\sigma }{\mu (\sigma-1)(1 + y/(\mu (\sigma-1)))^{\sigma+1}}}{
f(y) = s (1 + y/(m (s-1)))^(-s-1)/(m (s-1))}
where \eqn{\mu}{m} is the mean parameter of the distribution and
\eqn{\sigma}{s} is the dispersion.

This distribution can be obtained as a mixture distribution from the
exponential distribution using a gamma mixing distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dexp}} for the exponential distribution.
}
\examples{
dpareto(5, 2, 2)
ppareto(5, 2, 2)
qpareto(0.9, 2, 2)
rpareto(10, 2, 2)
}
\keyword{distribution}

\eof
\name{PowerExponential}
\title{Power Exponential Distribution}
\usage{
dpowexp(y, m=0, s=1, f=1, log=FALSE)
ppowexp(q, m=0, s=1, f=1)
qpowexp(p, m=0, s=1, f=1)
rpowexp(n, m=0, s=1, f=1)
}
\alias{dpowexp}
\alias{ppowexp}
\alias{qpowexp}
\alias{rpowexp}
\description{
These functions provide information about the power exponential
distribution with mean parameter equal to \code{m}, dispersion equal
to \code{s}, and family parameter equal to \code{f}: density,
cumulative distribution, quantiles, log hazard, and random generation.

The power exponential distribution has density
\deqn{
f(y) = \frac{\exp(-(abs{y-\mu}/\sqrt{\sigma})^{2 \nu}/2)}{
\sqrt{\sigma} Gamma(1+1/(2 \nu)) 2^{1+1/(2 \nu)}}}{
f(y) = exp(-(abs(y-m)/sqrt(s))^(2 f)/2)/
(sqrt(s) Gamma(1+1/(2 f)) 2^(1+1/(2 f)))}
	
where \eqn{\mu}{m} is the mean of the distribution,
\eqn{\sigma}{s} is the dispersion, and \eqn{\nu}{f} is the family
parameter. \eqn{\nu=1}{f=1} yields a normal distribution,
\eqn{\nu=0.5}{f=0.5} a Laplace distribution, and
\eqn{\nu=\infty}{f=Inf}  a uniform distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of means.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of family parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\examples{
dpowexp(5, 5, 1, 2)
ppowexp(5, 5, 1, 2)
qpowexp(0.5, 5, 1, 2)
rpowexp(10, 5, 1, 2)
}
\keyword{distribution}

\eof
\name{PvfPoisson}
\title{Power Variance Function Poisson Distribution}
\usage{
dpvfpois(y, m, s, f, log=FALSE)
ppvfpois(q, m, s, f)
qpvfpois(p, m, s, f)
rpvfpois(n, m, s, f)
}
\alias{dpvfpois}
\alias{ppvfpois}
\alias{qpvfpois}
\alias{rpvfpois}
\description{
These functions provide information about the overdispersed power
variance function Poisson distribution with parameters \code{m},
\code{s}, and \code{f}: density, cumulative distribution, quantiles,
and random generation. This function is obtained from a Poisson
distribution as a mixture with a power variance distribution. In the
limit, for \code{f=0}, the mixing distribution is gamma so that it is
a negative binomial distribution.  For \code{f=0.5}, the mixing
distribution is inverse Gaussian. For \code{f<0}, the mixing
distribution is a compound distribution of the sum of a Poisson number
of gamma distributions. For \code{f=1}, it is undefined.

The power variance function Poisson distribution with \code{m} \eqn{=
\mu}, the mean, \code{s} \eqn{= \theta}, and \code{f} \eqn{= \alpha}
has density
\deqn{p(y) =
{\exp(-\mu((\theta+1)^\alpha/\theta^\alpha-\theta)/\alpha)\over y!}
\sum_{i=1}^y c_{yi}(\alpha)\mu^i(\theta+1)^{i\alpha-y}/\theta^{i(\alpha-1)}
}{p(y) = (exp(-m((s+1)^f/s^f-s)/f) / y!)
sum_{i=1}^y c_{yi}(f) m^i (s+1)^{if-y} / s^{i(f-1)}}
for \eqn{y = 0, \ldots}, where \code{c_{yi}(f)} are coefficients
obtained by recursion.
}
\arguments{
\item{y}{vector of counts}
\item{q}{vector of quantiles}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{scalar or vector of means}
\item{s}{scalar or vector of overdispersion parameters}
\item{f}{scalar or vector of family parameters, all < 1}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dpois}} for the Poisson, \code{\link[rmutil]{ddoublepois}} for
the double Poisson, \code{\link[rmutil]{dmultpois}} for
the multiplicative Poisson, \code{\link[rmutil]{dconsul}} for the Consul
generalized Poisson, \code{\link[rmutil]{dgammacount}} for the gamma count, and
\code{\link{dnbinom}} for the negative binomial distribution.
}
\examples{
dpvfpois(5,10,0.9,0.5)
ppvfpois(5,10,0.9,0.5)
qpvfpois(0.85,10,0.9,0.5)
rpvfpois(10,10,0.9,0.5)
}
\keyword{distribution}

\eof
\name{Simplex}
\title{Simplex Distribution}
\usage{
dsimplex(y, m, s, log=FALSE)
psimplex(q, m, s)
qsimplex(p, m, s)
rsimplex(n, m, s)
}
\alias{dsimplex}
\alias{psimplex}
\alias{qsimplex}
\alias{rsimplex}
\description{
These functions provide information about the simplex distribution
with location parameter equal to \code{m} and shape equal to
\code{s}: density, cumulative distribution, quantiles, and
random generation.

The simplex distribution has density
\deqn{
f(y) = \frac{1}{\sqrt(2\pi\sigma(y(1-y))^3)}
     \exp(-((y-\mu)/(\mu(1-\mu)))^2/(2y(1-y)\sigma))}{
f(y) = exp(-((y-m)/(m(1-m)))^2/(2y(1-y)s))/sqrt(2 pi s(y(1-y))^3)}
where \eqn{\mu}{m} is the location parameter of the distribution and
\eqn{\sigma}{s} is the shape, and \eqn{0<y<1}{0<y<1}.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of shape parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dbeta}} for the beta distribution and
\code{\link{dtwosidedpower}} for the two-sided power distribution,
other distributions for proportions between zero and one.
}
\examples{
dsimplex(0.3, 0.5, 1)
psimplex(0.3, 0.5, 1)
qsimplex(0.1, 0.5, 1)
rsimplex(10, 0.5, 1)
}
\keyword{distribution}

\eof
\name{SkewLaplace}
\title{Skew Laplace Distribution}
\usage{
dskewlaplace(y, m=0, s=1, f=1, log=FALSE)
pskewlaplace(q, m=0, s=1, f=1)
qskewlaplace(p, m=0, s=1, f=1)
hskewlaplace(y, m=0, s=1, f=1)
rskewlaplace(n, m=0, s=1, f=1)
}
\alias{dskewlaplace}
\alias{pskewlaplace}
\alias{qskewlaplace}
\alias{hskewlaplace}
\alias{rskewlaplace}
\description{
These functions provide information about the skew Laplace distribution
with location parameter equal to \code{m}, dispersion equal to
\code{s}, and skew equal to \code{f}: density, cumulative
distribution, quantiles, log hazard, and random generation.
For \code{f=1}, this is an ordinary (symmetric) Laplace distribution.

The skew Laplace distribution has density
\deqn{
f(y) = \frac{\nu\exp(-\nu(y-\mu)/\sigma)}{(1+\nu^2)\sigma}}{
f(y) = f*exp(-f*(y-m)/s)/((1+f^2)*s)}
if  \eqn{y\ge\mu}{y>=m} and else
\deqn{
f(y) = \frac{\nu\exp((y-\mu)/(\nu\sigma))}{(1+\nu^2)\sigma}}{
f(y) = f*exp((y-m)/(f*s))/((1+f^2)*s)}
where \eqn{\mu}{m} is the location parameter of the distribution,
\eqn{\sigma}{s} is the dispersion, and \eqn{\nu}{f} is the skew.

The mean is given by \eqn{\mu+\frac{\sigma(1-\nu^2)}{\sqrt{2}\nu}}{m
+ (s * (1 - f^2)) / (sqrt(2) * f)}
and the variance by  \eqn{\frac{\sigma^2(1+\nu^4)}{2\nu^2}}{(s^2
* (1 + f^4)) / (2 * f^2)}.

Note that this parametrization of the skew (family) parameter is
different than that used for the multivariate skew Laplace
distribution in \code{\link[growth]{elliptic}}.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of dispersion parameters.}
\item{f}{vector of skew parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link{dexp}} for the exponential distribution,
\code{\link{dcauchy}} for the Cauchy distribution, and
\code{\link[rmutil]{dlaplace}} for the Laplace distribution.
}
\examples{
dskewlaplace(5, 2, 1, 0.5)
pskewlaplace(5, 2, 1, 0.5)
qskewlaplace(0.95, 2, 1, 0.5)
rskewlaplace(10, 2, 1, 0.5)
}
\keyword{distribution}

\eof
\name{Two-Sided Power}
\title{Two-Sided Power Distribution}
\usage{
dtwosidedpower(y, m, s=2, log=FALSE)
ptwosidedpower(q, m, s=2)
qtwosidedpower(p, m, s=2)
rtwosidedpower(n, m, s=2)
}
\alias{dtwosidedpower}
\alias{ptwosidedpower}
\alias{qtwosidedpower}
\alias{rtwosidedpower}
\description{
These functions provide information about the two-sided power distribution
with location parameter equal to \code{m} and shape equal to
\code{s}: density, cumulative distribution, quantiles, and
random generation.

The two-sided power distribution has density
\deqn{
f(y) = s(\frac{y}{m})^{s-1}, y<=m}{
f(y) = s(y/m)^(s-1), y<=m}
\deqn{
f(y) =s(\frac{1-y}{1-m})^{s-1}, y>=m}{
f(y) = s((1-y)/(1-m))^(s-1), y>=m}
where \eqn{\mu}{m} is the location parameter of the distribution and
\eqn{\sigma}{s} is the shape, and \eqn{0<y<1}{0<y<1}.

For \eqn{\sigma=1}{s=1}, this is the uniform distribution and for
\eqn{\sigma=2}{s=2}, it is the triangular distribution.
}
\arguments{
\item{y}{vector of responses.}
\item{q}{vector of quantiles.}
\item{p}{vector of probabilities}
\item{n}{number of values to generate}
\item{m}{vector of location parameters.}
\item{s}{vector of shape parameters.}
\item{log}{if TRUE, log probabilities are supplied.}
}
\author{J.K. Lindsey}
\references{
van Dorp, J.R. and Kotz, S. (2002) A novel extension of the triangular
distribution and its parameter estimation. The Statistician 51, 63-79.
}
\seealso{
\code{\link{dbeta}} for the beta distribution and
\code{\link{dsimplex}} for the simplex distribution, other
distributions for proportions between zero and one.
}
\examples{
dtwosidedpower(0.3, 0.5, 3)
ptwosidedpower(0.3, 0.5, 3)
qtwosidedpower(0.1, 0.5, 3)
rtwosidedpower(10, 0.5, 3)
}
\keyword{distribution}

\eof
\name{contrast}
\alias{contr.mean}
\title{Contrast Matrix for Constraints about the Mean}
\description{
Return a matrix of contrasts for constraints about the mean.
}
\usage{
contr.mean(n, contrasts = TRUE)
}
\arguments{
\item{n}{A vector of levels for a factor or the number of levels.}
\item{contrasts}{A logical value indicating whether or not contrasts
should be computed.}
}
\details{
This function corrects \code{\link{contr.sum}} to display labels properly.
}
\value{
A matrix of computed contrasts with \code{n} rows and \code{k}
columns, with \code{k=n-1} if \code{contrasts} is \code{TRUE} and
\code{k=n} if \code{contrasts} is \code{FALSE}. The columns of the
resulting matrices contain contrasts which can be used for coding a
factor with \code{n} levels.
}
\seealso{
\code{\link{contrasts}}, \code{\link{C}},
and \code{\link{contr.sum}}.
}
\examples{
oldop <- options(contrasts=c("contr.sum","contra.poly"))
y <- rnorm(30)
x <- gl(3,10,labels=c("First","Second","Third"))
glm(y~x)
options(contrasts=c("contr.mean","contra.poly"))
x <- gl(3,10,labels=c("First","Second","Third"))
glm(y~x)
options(oldop)
}
\keyword{design}
\keyword{regression}
\keyword{array}

\eof
\name{dftorep}
\title{Transform a Dataframe to a repeated Object}
\alias{dftorep}
\usage{
dftorep(dataframe, response, id=NULL, times=NULL, censor=NULL,
	totals=NULL, weights=NULL, nest=NULL, delta=NULL,
	coordinates=NULL, type=NULL, ccov=NULL, tvcov=NULL, na.rm=T)
}
\description{
\code{dftorep} forms an object of class, \code{repeated}, from a
dataframe with the option of removing any observations where response
and covariate values have NAs. For repeated measurements, observations
on the same individual must be together in the table. A number of
validity checks are performed on the data.

Such objects can be printed and plotted. Methods are available for
extracting the response, the numbers of observations per individual,
the times, the weights, the units of measurement/Jacobian, the nesting
variable, the covariates, and their names: \code{\link[rmutil]{response}},
\code{\link[rmutil]{nobs}}, \code{\link[rmutil]{times}},
\code{\link[rmutil]{weights}}, \code{\link[rmutil]{delta}},
\code{\link[rmutil]{nesting}}, \code{\link[rmutil]{covariates}}, and
\code{\link[rmutil]{names}}.
}
\arguments{
\item{dataframe}{A dataframe.}

\item{response}{A character vector giving the column name(s) of the
dataframe for the response variable(s).}

\item{id}{A character vector giving the column name of the
dataframe for the identification numbers of the individuals. If the
numbers are not consecutive integers, a warning is given.

If NULL, one observation per individual is assumed if \code{times} is
also NULL, other time series is assumed.}

\item{times}{An optional character vector giving the column name of the
dataframe for the times vector.}

\item{censor}{An optional character vector giving the column name(s)
of the dataframe for the censor indicator(s). This must be the same
length as \code{response}. Responses without censor indicator can have
a column either of all NAs or all 1s.}

\item{totals}{An optional character vector giving the column name(s)
of the dataframe for the totals for binomial data. This must be the same
length as \code{response}. Responses without censor indicator can have
a column all NAs.}

\item{weights}{An optional character vector giving the column name of
the dataframe for the weights vector.}

\item{nest}{An optional character vector giving the column name of
the dataframe for the nesting vector within individuals.

This is the second level of nesting for repeated measurements, with
the individual being the first level. Values for an individual must be
consecutive increasing integers.}

\item{delta}{An optional character vector giving the column name(s)
of the dataframe for the units of measurement/Jacobian(s) of the
response(s). This must be the same length as \code{response}.
Responses without units of measurement/Jacobian can have a column all
NAs.

If all response variables have the same unit of measurement, this can
be that one number. If each response variable has the same unit of
measurement for all its values, this can be a numeric vector of length
the number of response variables.}

\item{coordinates}{An optional character vector giving the two or
three column name(s) of the dataframe for the spatial coordinates.}

\item{type}{An optional character vector giving the types of response
variables: nominal, ordinal, discrete, duration, continuous,
multivariate, or unknown.}

\item{ccov}{An optional character vector giving the column names of
the dataframe for the time-constant or inter-individual covariates.
For repeated measurements, if the value is not constant for all
observations on an individual, an error is produced.}

\item{tvcov}{An optional character vector giving the column names of
the dataframe for the time-varying or intra-individual covariates.}

\item{na.rm}{If TRUE, observations with NAs in any variables selected
are removed in the object returned. Otherwise, the corresponding
indicator variable is returned in a slot in the object.}
}
\value{
Returns an object of class, \code{repeated}, containing a list of the
response object (\code{z$response}, so that, for example, the response vector
is \code{z$response$y}; see \code{\link[rmutil]{restovec}}), and
possibly the two classes of covariate objects (\code{z$ccov} and
\code{z$tvcov}; see \code{\link[rmutil]{tcctomat}} and
\code{\link[rmutil]{tvctomat}}).
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{lvna}}, \code{\link[rmutil]{read.list}},
\code{\link[rmutil]{read.rep}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}
}
\examples{
y <- data.frame(y1=rpois(20,5),y2=rpois(20,5))
y[2,2] <- NA
idd <- c(rep(1,5),rep(2,10),rep(3,5))
tt <- c(1:5,1:10,1:5)
totals <- data.frame(tot1=rep(12,20),tot2=rep(12,20))
x2 <- c(rep(1,5),rep(2,10),rep(3,5))
df <- data.frame(y,id=idd,tt=tt,totals,x1=rnorm(20),x2=x2)
df
dftorep(df,resp=c("y1","y2"),times="tt",id="id",totals=c("tot1","tot2"),
	tvcov="x1",ccov="x2")
dftorep(df,resp=c("y1","y2"),times="tt",id="id",totals=c("tot1","tot2"),
	tvcov="x1",ccov="x2",na.rm=FALSE)
# x1 is not a time-constant covariate
#dftorep(df,resp=c("y1","y2"),times="tt",id="id",ccov="x1",na.rm=FALSE)
}
\keyword{manip}

\eof
\name{finterp}
\title{Formula Interpreter}
\alias{finterp}
\usage{
finterp(.z, .envir=parent.frame(), .formula=FALSE, .vector=TRUE,
	.args=NULL, .start=1, .name=NULL, .expand=TRUE, .intercept=TRUE,
	.old=NULL, .response=FALSE)
}
\description{
\code{finterp} translates a model formula into a function of the
unknown parameters or of a vector of them. Such language formulae can
either be in Wilkinson and Rogers notation or be expressions
containing both known (existing) covariates and unknown (not existing)
parameters. In the latter, factor variables cannot be used and
parameters must be scalars.

The covariates in the formula are sought in the environment or in the
data object provided. If the data object has class, \code{repeated} or
\code{response}, then the key words, \code{times} will use the
response times from the data object as a covariate, \code{individuals}
will use the index for individuals as a factor covariate, and
\code{nesting} the index for nesting as a factor covariate. The latter
two only work for W&R notation.

Note that, in parameter displays, formulae in Wilkinson and Rogers
notation use variable names whereas those with unknowns use the names
of these parameters, as given in the formulae, and that the meaning of
operators (*, /, :, etc.) is different in the two cases.
}
\arguments{
\item{.z}{A model formula beginning with ~, either in Wilkinson and
Rogers notation or containing unknown parameters. If it contains
unknown parameters, it can have several lines so that, for example,
local variables can be assigned temporary values. In this case,
enclose the formula in curly brackets.}
\item{.envir}{The environment in which the formula is to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}.}
\item{.formula}{If TRUE and the formula is in Wilkinson and Rogers
notation, just returns the formula.}
\item{.vector}{If FALSE and the formula contains unknown parameters,
the function returned has them as separate arguments. If TRUE, it has
one argument, the unknowns as a vector, unless certain parameter names
are specified in \code{.args}. Always TRUE if \code{.envir} is
a data object.}
\item{.args}{If \code{.vector} is TRUE, names of parameters that are to
be function arguments and not included in the vector.}
\item{.start}{The starting index value of the parameter vector in the
function returned when \code{.vector} is TRUE.}
\item{.name}{Character string giving the name of the data object
specified by \code{.envir}. Ignored unless the latter is such an
object and only necessary when \code{finterp} is called within other
functions.}
\item{.expand}{If TRUE, expand functions with only time-constant
covariates to return one value per observation instead of one value
per individual. Ignored unless \code{.envir} is an object of class,
\code{repeated}.}
\item{.intercept}{If W&R notation is supplied and \code{.intercept=F},
a model function without intercept is returned.}
\item{.old}{The name of an existing object of class \code{formulafn}
which has common parameters with the one being created, or a list of
such objects. Only used if \code{.vector}=TRUE. The value of
\code{.start} should ensure that there is no conflict in indexing the
vector.}
\item{.response}{If TRUE, any response variable can be used in the
function. If FALSE, checks are made that the response is not also used
as a covariate.}
}
\value{
A function, of class \code{formulafn}, of the unknown parameters or of a
vector of them is returned. Its attributes give the formula supplied,
the model function produced, the covariate names, the parameter names,
and the range of values of the index of the parameter vector. If
\code{formula} is TRUE and a Wilkinson and Rogers formula was
supplied, it is simply returned instead of creating a function.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{FormulaMethods}}, \code{\link[rmutil]{covariates}},
\code{\link[rmutil]{fnenvir}}, \code{\link[rmutil]{formula}},
\code{\link[rmutil]{model}}, \code{\link[rmutil]{parameters}}
}
\examples{
x1 <- rpois(20,2)
x2 <- rnorm(20)
#
# Wilkinson and Rogers formula with three parameters
fn1 <- finterp(~x1+x2)
fn1
fn1(rep(2,3))
# the same formula with unknowns
fn2 <- finterp(~b0+b1*x1+b2*x2)
fn2
fn2(rep(2,3))
#
# nonlinear formulae with unknowns
# log link
fn2a <- finterp(~exp(b0+b1*x1+b2*x2))
fn2a
fn2a(rep(0.2,3))
# parameters common to two functions
fn2b <- finterp(~c0+c1*exp(b0+b1*x1+b2*x2), .old=fn2a, .start=4)
fn2b
# function returned also depends on values of another function
fn2c <- finterp(~fn2+c1*exp(b0+b1*x1+b2*x2), .old=fn2a,
	.start=4, .args="fn2")
fn2c
args(fn2c)
fn2c(rep(0.2,4),fn2(rep(2,3)))
#
# compartment model
times <- 1:20
# exp() parameters to ensure that they are positive
fn3 <- finterp(~exp(absorption-volume)/(exp(absorption)-
	exp(elimination))*(exp(-exp(elimination)*times)-
	exp(-exp(absorption)*times)))
fn3
fn3(log(c(0.3,3,0.2)))
# a more efficient way
# (note that parameters do not appear in the same order)
form <- ~{
	ka <- exp(absorption)
	ke <- exp(elimination)
	ka*exp(-volume)/(ka-ke)*(exp(-ke*times)-exp(-ka*times))}
fn3a <- finterp(form)
fn3a(log(c(0.3,0.2,3)))
#
# Poisson density
y <- rpois(20,5)
fn4 <- finterp(~mu^y*exp(-mu)/gamma(y+1))
fn4
fn4(5)
dpois(y,5)
#
# Poisson likelihood
# mean parameter
fn5 <- finterp(~-y*log(mu)+mu+lgamma(y+1),.vector=FALSE)
fn5
likefn1 <- function(p) sum(fn5(mu=p))
nlm(likefn1,p=1)
mean(y)
# canonical parameter
fn5a <- finterp(~-y*theta+exp(theta)+lgamma(y+1),.vector=FALSE)
fn5a
likefn1a <- function(p) sum(fn5a(theta=p))
nlm(likefn1a,p=1)
#
# likelihood for Poisson log linear regression
y <- rpois(20,fn2a(c(0.2,1,0.4)))
nlm(likefn1,p=1)
mean(y)
likefn2 <- function(p) sum(fn5(mu=fn2a(p)))
nlm(likefn2,p=c(1,0,0))
# or
likefn2a <- function(p) sum(fn5a(theta=fn2(p)))
nlm(likefn2a,p=c(1,0,0))
#
# likelihood for Poisson nonlinear regression
y <- rpois(20,fn3(log(c(3,0.3,0.2))))
nlm(likefn1,p=1)
mean(y)
likefn3 <- function(p) sum(fn5(mu=fn3(p)))
nlm(likefn3,p=log(c(1,0.4,0.1)))
#
# envir as data objects
y <- matrix(rnorm(20),ncol=5)
y[3,3] <- y[2,2] <- NA
x1 <- 1:4
x2 <- c("a","b","c","d")
resp <- restovec(y)
xx <- tcctomat(x1)
xx2 <- tcctomat(data.frame(x1,x2))
z1 <- matrix(rnorm(20),ncol=5)
z2 <- matrix(rnorm(20),ncol=5)
z3 <- matrix(rnorm(20),ncol=5)
zz <- tvctomat(z1)
zz <- tvctomat(z2,old=zz)
reps <- rmna(resp, ccov=xx, tvcov=zz)
reps2 <- rmna(resp, ccov=xx2, tvcov=zz)
rm(y, x1, x2 , z1, z2)
#
# repeated objects
#
# time-constant covariates
# Wilkinson and Rogers notation
form1 <- ~x1
print(fn1 <- finterp(form1, .envir=reps))
fn1(2:3)
print(fn1a <- finterp(form1, .envir=xx))
fn1a(2:3)
form1b <- ~x1+x2
print(fn1b <- finterp(form1b, .envir=reps2))
fn1b(2:6)
print(fn1c <- finterp(form1b, .envir=xx2))
fn1c(2:6)
# with unknown parameters
form2 <- ~a+b*x1
print(fn2 <- finterp(form2, .envir=reps))
fn2(2:3)
print(fn2a <- finterp(form2, .envir=xx))
fn2a(2:3)
#
# time-varying covariates
# Wilkinson and Rogers notation
form3 <- ~z1+z2
print(fn3 <- finterp(form3, .envir=reps))
fn3(2:4)
print(fn3a <- finterp(form3, .envir=zz))
fn3a(2:4)
# with unknown parameters
form4 <- ~a+b*z1+c*z2
print(fn4 <- finterp(form4, .envir=reps))
fn4(2:4)
print(fn4a <- finterp(form4, .envir=zz))
fn4a(2:4)
#
# note: lengths of x1 and z2 differ
# Wilkinson and Rogers notation
form5 <- ~x1+z2
print(fn5 <- finterp(form5, .envir=reps))
fn5(2:4)
# with unknown parameters
form6 <- ~a+b*x1+c*z2
print(fn6 <- finterp(form6, .envir=reps))
fn6(2:4)
#
# with times
# Wilkinson and Rogers notation
form7 <- ~x1+z2+times
print(fn7 <- finterp(form7, .envir=reps))
fn7(2:5)
form7a <- ~x1+x2+z2+times
print(fn7a <- finterp(form7a, .envir=reps2))
fn7a(2:8)
# with unknown parameters
form8 <- ~a+b*x1+c*z2+e*times
print(fn8 <- finterp(form8, .envir=reps))
fn8(2:5)
#
# with a variable not in the data object
form9 <- ~a+b*z1+c*z2+e*z3
print(fn9 <- finterp(form9, .envir=reps))
fn9(2:5)
# z3 assumed to be an unknown parameter:
fn9(2:6)
#
# multiline formula
form10 <- ~{
	tmp <- exp(b)
	a+tmp*z1+c*z2+d*times}
print(fn10 <- finterp(form10, .envir=reps))
fn10(2:5)
}
\keyword{programming}

\eof
\name{fmobj}
\title{Object Finder}
\alias{fmobj}
\usage{
fmobj(z, envir=parent.frame())
}
\description{
\code{fmobj} inspects a formula and returns a list containing the
objects referred to, with indicators as to which are unknown parameters,
covariates, factor variables, and functions.
}
\arguments{
\item{z}{A model formula beginning with ~, either in Wilkinson and
Rogers notation or containing unknown parameters.}
\item{envir}{The environment in which the formula is to be
interpreted.}
}
\value{
A list, of class \code{fmobj}, containing a character vector
(\code{objects}) with the names of the objects used in a formula, and
logical vectors indicating which are unknown parameters
(\code{parameters}), covariates (\code{covariates}), factor variables
(\code{factors}), and functions (\code{functions}).
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{finterp}}
}
\examples{
x1 <- rpois(20,2)
x2 <- rnorm(20)
x3 <- gl(2,10)
#
# W&R formula
fmobj(~x1+x2+x3)
#
# formula with unknowns
fmobj(~b0+b1*x1+b2*x2)
#
# nonlinear formulae with unknowns
# log link
fmobj(~exp(b0+b1*x1+b2*x2))
}
\keyword{programming}

\eof
\name{fnenvir}
\title{Check Covariates and Parameters of a Function}
\alias{fnenvir}
\usage{
fnenvir(.z, .envir=sys.frame(sys.parent()), .name=NULL, .expand=TRUE,
	.response=FALSE)
}
\description{
\code{fnenvir} finds the covariates and parameters in a function and
can modify it so that the covariates used in it are found in the data
object specified by \code{.envir}.

If the data object has class, \code{repeated}, the key word
\code{times} in a function will use the response times from the data
object as a covariate.
}
\arguments{
\item{.z}{A function.}
\item{.envir}{The environment or data object of class,
\code{repeated}, \code{tccov}, or \code{tvcov}, in which the function
is to be interpreted.}
\item{.name}{Character string giving the name of the data object
specified by \code{.envir}. Ignored unless the latter is such an
object and only necessary when \code{fnenvir} is called within other
functions.}
\item{.expand}{If TRUE, expand functions with only time-constant
covariates to return one value per observation instead of one value
per individual. Ignored unless \code{.envir} is an object of class,
\code{repeated}.}
\item{.response}{If TRUE, any response variable can be used in the
function. If FALSE, checks are made that the response is not also used
as a covariate.}
}
\value{
The (modified) function, of class \code{formulafn}, is returned with its
attributes giving the (new) model function, the covariate names, and
the parameter names.}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{FormulaMethods}},\code{\link[rmutil]{covariates}},
\code{\link[rmutil]{finterp}}, \code{\link[rmutil]{model}},
\code{\link[rmutil]{parameters}}
}
\examples{
fn <- function(p) a+b*x
fnenvir(fn)
fn <- function(p) a+p*x
fnenvir(fn)
x <- 1:4
fnenvir(fn)
fn <- function(p) p[1]+exp(p[2]*x)
fnenvir(fn)
#
y <- matrix(rnorm(20),ncol=5)
y[3,3] <- y[2,2] <- NA
resp <- restovec(y)
xx <- tcctomat(x)
z1 <- matrix(rnorm(20),ncol=5)
z2 <- matrix(rnorm(20),ncol=5)
z3 <- matrix(rnorm(20),ncol=5)
zz <- tvctomat(z1)
zz <- tvctomat(z2,old=zz)
reps <- rmna(resp, ccov=xx, tvcov=zz)
rm(y, x, z1, z2)
#
# repeated objects
func1 <- function(p) p[1]+p[2]*x+p[3]*z2
print(fn1 <- fnenvir(func1, .envir=reps))
fn1(2:4)
#
# time-constant covariates
func2 <- function(p) p[1]+p[2]*x
print(fn2 <- fnenvir(func2, .envir=reps))
fn2(2:3)
print(fn2a <- fnenvir(func2, .envir=xx))
fn2a(2:3)
#
# time-varying covariates
func3 <- function(p) p[1]+p[2]*z1+p[3]*z2
print(fn3 <- fnenvir(func3, .envir=reps))
fn3(2:4)
print(fn3a <- fnenvir(func3, .envir=zz))
fn3a(2:4)
# including times
func3b <- function(p) p[1]+p[2]*z1+p[3]*z2+p[4]*times
print(fn3b <- fnenvir(func3b, .envir=reps))
fn3b(2:5)
#
# with typing error and a variable not in the data object
func4 <- function(p) p[1]+p2[2]*z1+p[3]*z2+p[4]*z3
print(fn4 <- fnenvir(func4, .envir=reps))
#
# first-order one-compartment model
# data objects for formulae
dose <- c(2,5)
dd <- tcctomat(dose)
times <- matrix(rep(1:20,2), nrow=2, byrow=TRUE)
tt <- tvctomat(times)
# vector covariates for functions
dose <- c(rep(2,20),rep(5,20))
times <- rep(1:20,2)
# functions
mu <- function(p) {
	absorption <- exp(p[1])
	elimination <- exp(p[2])
	absorption*exp(-p[3])*dose/(absorption-elimination)*
		(exp(-elimination*times)-exp(-absorption*times))}
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
# response
conc <- matrix(rgamma(40,shape(log(c(0.1,0.4))),
	scale=mu(log(c(1,0.3,0.2))))/shape(log(c(0.1,0.4))),ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- restovec(ifelse(conc>0,conc,0.01))
reps <- rmna(conc, ccov=dd, tvcov=tt)
#
print(fn5 <- fnenvir(mu,.envir=reps))
fn5(c(0,-1.2,-1.6))
}
\keyword{programming}

\eof
\name{gauss.hermite}
\title{Calculate Gauss-Hermite Quadrature Points}
\alias{gauss.hermite}
\usage{
gauss.hermite(points, iterlim=10)
}
\description{
\code{gauss.hermite} calculates the Gauss-Hermite quadrature values
for a specified number of points.
}
\arguments{
\item{points}{The number of points.}
\item{iterlim}{Maximum number of iterations in Newton-Raphson.}
}
\value{
\code{gauss.hermite} returns a two-column matrix containing the points
and their corresponding weights.
}
\author{J.K. Lindsey}
\examples{
gauss.hermite(10)
}
\keyword{math}

\eof
\name{gettvc}
\title{Find the Most Recent Value of a Time-varying Covariate
Before Each Observed Response}
\alias{gettvc}
\usage{
gettvc(response, times=NULL, tvcov=NULL, tvctimes=NULL,
	oldtvcov=NULL, ties=TRUE)
}
\description{
\code{gettvc} finds the most recent value of a time-varying covariate
before each observed response and possibly adds them to a list of other
time-varying covariates.
It compares the times of response observations with those of
time-varying covariates to find the most recent observed time-varying
covariate for each response. These are either placed in a new object of
class, \code{tvcov}, added to an already existing list of matrices containing
other time-varying covariates and a new object of class, \code{tvcov},
created, or added to an existing object of class, \code{tvcov}.

If there are response observation times before the first covariate
time, the covariate for these times is set to zero.
}
\arguments{
\item{response}{A list of two column matrices with response values and
times for each individual, one matrix or dataframe of response
values, or an object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}).}
\item{times}{When \code{response} is a matrix, a vector of possibly
unequally spaced times for the response, when they are the same for
all individuals or a matrix of times. Not necessary if equally spaced.}
\item{tvcov}{A list of two column matrices with time-varying covariate
values and corresponding times for each individual or one matrix or
dataframe of such covariate values. Times need not be the same as for
responses.}
\item{tvctimes}{When the time-varying covariate is a matrix, a vector
of possibly unequally spaced times for the covariate, when they are
the same for all individuals or a matrix of times. Not necessary if
equally spaced.}
\item{oldtvcov}{A list of matrices with time-varying covariate values,
observed at the event times in \code{response}, for each individual,
or an object of class, \code{tvcov}. If not provided, a new object is
created.}
\item{ties}{If TRUE, when the response and covariate times are
identical, the response depends on that new value (as in observational
studies); if FALSE, only the next response depends on that value (for
example, if the covariate is a new treatment just applied at that time).}
}
\value{
An object of class, \code{tvcov}, is returned containing the new time-varying
covariate and, possibly, those in \code{oldtvcov}.
}
\author{J.K. Lindsey and D.F. Heitjan}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}},
\code{\link[repeated]{gar}}, \code{\link[repeated]{kalcount}},
\code{\link[repeated]{kalseries}}, \code{\link[event]{kalsurv}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{tvctomat}}.
}
\examples{
y <- matrix(rnorm(20), ncol=5)
resp <- restovec(y, times=c(1,3,6,10,15))
z <- matrix(rpois(20,5),ncol=5)
z
# create a new time-varying covariate object for the response
newtvc <- gettvc(resp, tvcov=z, tvctimes=c(1,2,5,12,14))
covariates(newtvc)
# add another time-varying covariate to the object
z2 <- matrix(rpois(20,5),ncol=5)
z2
newtvc2 <- gettvc(resp, tvcov=z2, tvctimes=c(0,4,5,12,16), oldtvc=newtvc)
covariates(newtvc2)
}
\keyword{manip}

\eof
\name{int}
\title{Vectorized Numerical Integration}
\alias{int}
\usage{
int(f, a=-Inf, b=Inf, type="Romberg", eps=0.0001, max=NULL, d=NULL, p=0)
}
\description{
\code{int} performs numerical integration of a given function using
either Romberg integration or algorithm 614 of the collected
algorithms from ACM. Only the former is vectorized. The latter uses
formulae optimal in certain Hardy spaces h(p,d).

Functions may have singularities at one or both end-points of the
interval (a,b).
}
\arguments{
\item{f}{The function (of one variable) to integrate, returning either
a scalar or a vector.}
\item{a}{A scalar or vector (only Romberg) giving the lower bound(s).
A vector cannot contain both -Inf and finite values.}
\item{b}{A scalar or vector (only Romberg) giving the upper bound(s).
A vector cannot contain both Inf and finite values.}
\item{type}{The algorithm to be used, by default Romberg integration.
Otherwise, it uses the TOMS614 algorithm.}
\item{eps}{Precision.}
\item{max}{For Romberg, the maximum number of steps, by default set
to 16. For TOMS614, the maximum number of function evaluations, by
default set to 100.}
\item{d}{For Romberg, the number of extrapolation points so that
2d is the order of integration, by default set to 5; d=2 is Simpson's
rule. For TOMS614, heuristic termination = any real number;
deterministic termination = a number in the range 0 < d < pi/2
by default, set to 1.}
\item{p}{For TOMS614, p = 0: heuristic termination, p = 1:
deterministic termination with the infinity norm, p > 1: deterministic
termination with the p-th norm.}
}
\value{
The vector of values of the integrals of the function supplied.
}
\author{J.K. Lindsey}
\references{
ACM algorithm 614 appeared in

ACM-Trans. Math. Software, Vol.10, No. 2, Jun., 1984, p. 152-160.

See also

Sikorski,K., Optimal quadrature algorithms in HP spaces, Num. Math.,
39, 405-410 (1982).
}
\examples{
f <- function(x) sin(x)+cos(x)-x^2
int(f, a=0, b=2)
int(f, a=0, b=2, type="TOMS614")
#
f <- function(x) exp(-(x-2)^2/2)/sqrt(2*pi)
int(f, a=0:3)
int(f, a=0:3, d=2)
1-pnorm(0:3, 2)
}
\keyword{math}

\eof
\name{int2}
\title{Vectorized Two-dimensional Numerical Integration}
\alias{int2}
\usage{
int2(f, a=c(-Inf,-Inf), b=c(Inf,Inf), eps=1.0e-6, max=16, d=5)
}
\description{
\code{int} performs vectorized numerical integration of a given
two-dimensional function.
}
\arguments{
\item{f}{The function (of two variables) to integrate, returning either
a scalar or a vector.}
\item{a}{A two-element vector or a two-column matrix giving the lower
bounds. It cannot contain both -Inf and finite values.}
\item{b}{A two-element vector or a two-column matrix giving the upper
bounds. It cannot contain both Inf and finite values.}
\item{eps}{Precision.}
\item{max}{The maximum number of steps, by default set to 16.}
\item{d}{The number of extrapolation points so that 2k is the order of
integration, by default set to 5; d=2 is Simpson's rule.}
}
\value{
The vector of values of the integrals of the function supplied.
}
\author{J.K. Lindsey}
\examples{
f <- function(x,y) sin(x)+cos(y)-x^2
int2(f, a=c(0,1), b=c(2,4))
#
fn1 <- function(x, y) x^2+y^2
fn2 <- function(x, y) (1:4)*x^2+(2:5)*y^2
int2(fn1, c(1,2), c(2,4))
int2(fn2, c(1,2), c(2,4))
int2(fn1, matrix(c(1:4,1:4),ncol=2), matrix(c(2:5,2:5),ncol=2))
int2(fn2, matrix(c(1:4,1:4),ncol=2), matrix(c(2:5,2:5),ncol=2))
}
\keyword{math}

\eof
\name{iprofile}
\title{Produce Individual Time Profiles for Plotting}
\usage{
zz <- iprofile(z, plotsd=FALSE)
plot(zz, nind=1, observed=TRUE, intensity=F,
	add=FALSE, lty=NULL, pch=NULL, ylab=NULL, xlab=NULL,
	main=NULL, ylim=NULL, xlim=NULL, ...)
}
\alias{iprofile}
\alias{plot.iprofile}
\description{
\code{iprofile} is used for plotting individual profiles over time
for objects obtained from dynamic models. It produces output for
plotting recursive fitted values for individual time profiles from
such models.

See \code{\link[rmutil]{mprofile}} for plotting marginal profiles.
}
\arguments{
\item{z}{An object of class \code{recursive}, from
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}},
\code{\link[repeated]{gar}}, \code{\link[repeated]{kalcount}},
\code{\link[repeated]{kalseries}}, \code{\link[event]{kalsurv}}, or
\code{\link[repeated]{nbkal}}.}
\item{zz}{An object of class \code{iprofile}.}
\item{plotsd}{If TRUE, plots standard deviations around profile
(\code{\link[growth]{carma}} and \code{\link[growth]{elliptic}} only).}
\item{nind}{Observation number(s) of individual(s) to be plotted.}
\item{observed}{If TRUE, plots observed responses.}
\item{intensity}{If z has class, \code{kalsurv}, and this is TRUE, the
intensity is plotted instead of the time between events.}
\item{add}{If TRUE, the graph is added to an existing plot.}
\item{others}{Plotting control options.}
}
\value{
\code{iprofile} returns information ready for plotting by
\code{plot.iprofile}.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}},
\code{\link[repeated]{gar}}, \code{\link[repeated]{kalcount}},
\code{\link[repeated]{kalseries}}, \code{\link[event]{kalsurv}},
\code{\link[repeated]{nbkal}} \code{\link[rmutil]{mprofile}}
\code{\link[rmutil]{plot.residuals}}.
}
\examples{
library(repeated)
times <- rep(1:20,2)
dose <- c(rep(2,20),rep(5,20))
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
conc <- matrix(rgamma(40,1,scale=mu(log(c(1,0.3,0.2)))),ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- ifelse(conc>0,conc,0.01)
z <- gar(conc, dist="gamma", times=1:20, mu=mu, shape=shape,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=log(c(1,0.2)))
# plot individual profiles and the average profile
plot(iprofile(z), nind=1:2, pch=c(1,20), lty=3:4)
plot(mprofile(z), nind=1:2, lty=1:2, add=TRUE)
}
\keyword{hplot}

\eof
\name{lin.diff.eqn}
\title{Solution of Autonomous Linear Differential Equations}
\alias{lin.diff.eqn}
\usage{
lin.diff.eqn(A, initial, t=1)
}
\description{
\code{lin.diff.eqn} numerically solves a system of autonomous linear
differential equations with given initial conditions by matrix
exponentiation.
}
\arguments{
\item{A}{A square matrix giving the coefficients of the equations.}
\item{initial}{The vector of initial values of the system.}
\item{t}{A scalar or vector of values of the independent variable for
which solutions are sought.}
}
\value{
A matrix of solutions with one row for each value of \code{t}.
}
\author{J.K. Lindsey}
\examples{
a <- matrix(c(1,0,1,0,0,0,0,0,-1),ncol=3,byrow=TRUE)
x <- c(5,7,6)
lin.diff.eqn(a,x,1)
# function giving the exact solution
exact <- function(t) c(8*exp(t)-3*exp(-t),7,6*exp(-t))
exact(1)
}
\keyword{math}

\eof
\name{lvna}
\title{Create a repeated Object, Leaving NAs}
\alias{lvna}
\usage{
lvna(response, ccov=NULL, tvcov=NULL)
}
\description{
\code{lvna} forms an object of class, \code{repeated}, from a response
object and possibly time-varying or intra-individual covariate
(\code{tvcov}), and time-constant or inter-individual covariate
(\code{tccov}) objects. If there are NAs in any variables, it also
creates a logical vector indicating which observations have NAs either
in the response or the covariate values. Subjects
must be in the same order in all (three) objects to be combined.

Such objects can be printed and plotted. Methods are available for
extracting the response, the numbers of observations per individual,
the times, the weights, the units of measurement/Jacobian, the nesting
variable, the covariates, and their names: \code{\link[rmutil]{response}},
\code{\link[rmutil]{nobs}}, \code{\link[rmutil]{times}},
\code{\link[rmutil]{weights}}, \code{\link[rmutil]{delta}},
\code{\link[rmutil]{nesting}}, \code{\link[rmutil]{covariates}}, and
\code{\link[rmutil]{names}}.
}
\arguments{
\item{response}{An object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}), containing the response variable information.}
\item{ccov}{An object of class, \code{tccov} (created by
\code{\link[rmutil]{tcctomat}}), containing the time-constant or
inter-individual covariate information.}
\item{tvcov}{An object of class, \code{tvcov} (created by
\code{\link[rmutil]{tvctomat}}), containing the time-varying or
intra-individual covariate information.}
}
\value{
Returns an object of class, \code{repeated}, containing a list of the
response object (\code{z$response}, so that, for example, the response vector
is \code{z$response$y}; see \code{\link[rmutil]{restovec}}), possibly the two
classes of covariate objects (\code{z$ccov} and \code{z$tvcov}; see
\code{\link[rmutil]{tcctomat}} and \code{\link[rmutil]{tvctomat}}),
and a logical vector (\code{z$NAs}) indicating which observations have
an NA in the response or some covariate.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{DataMethods}}, \code{\link[rmutil]{covariates}},
\code{\link[rmutil]{covind}}, \code{\link[rmutil]{delta}},
\code{\link[rmutil]{dftorep}}, \code{\link[rmutil]{names}},
\code{\link[rmutil]{nesting}}, \code{\link[rmutil]{nobs}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{read.surv}},
\code{\link[rmutil]{response}}, \code{\link[rmutil]{resptype}},
\code{\link[rmutil]{restovec}}, \code{\link[rmutil]{rmna}},
\code{\link[rmutil]{tcctomat}}, \code{\link[rmutil]{times}},
\code{\link[rmutil]{transform}}, \code{\link[rmutil]{tvctomat}},
\code{\link[rmutil]{units}}, \code{\link[rmutil]{weights}}
}
\examples{
y <- matrix(rnorm(20),ncol=5)
y[2,3] <- NA
tt <- c(1,3,6,10,15)
print(resp <- restovec(y,times=tt))
x <- c(0,0,1,1)
tcc <- tcctomat(x)
z <- matrix(rpois(20,5),ncol=5)
tvc <- tvctomat(z)
print(reps <- lvna(resp, tvcov=tvc, ccov=tcc))
response(reps)
response(reps, nind=2:3)
times(reps)
nobs(reps)
weights(reps)
covariates(reps)
covariates(reps,names="x")
covariates(reps,names="z")
names(reps)
nesting(reps)
# because individuals are the only nesting, this is the same as
covind(reps)
# binomial
y <- matrix(rpois(20,5),ncol=5)
y[2,3] <- NA
print(respb <- restovec(y,totals=y+matrix(rpois(20,5),ncol=5),times=tt))
print(repsb <- lvna(respb, tvcov=tvc, ccov=tcc))
response(repsb)
# censored data
y <- matrix(rweibull(20,2,5),ncol=5)
print(respc <- restovec(y,censor=matrix(rbinom(20,1,0.9),ncol=5),times=tt))
print(repsc <- lvna(respc, tvcov=tvc, ccov=tcc))
# if there is no censoring, censor indicator is not printed
response(repsc)
# nesting clustered within individuals
nest <- c(1,1,2,2,2)
print(respn <- restovec(y,censor=matrix(rbinom(20,1,0.9),ncol=5),
	times=tt,nest=nest))
print(repsn <- lvna(respn, tvcov=tvc, ccov=tcc))
response(respn)
times(respn)
nesting(respn)
}
\keyword{manip}

\eof
\name{mexp}
\title{Matrix Exponentiation}
\alias{mexp}
\usage{
mexp(x, t=1, type="spectral decomposition", n=20, k=3)
}
\description{
\code{mexp} calculates \code{exp(t*x)} for the square matrix, \code{x}, by
spectral decomposition or series expansion.
}
\arguments{
\item{x}{A square matrix.}
\item{t}{Constant multiplying the matrix.}
\item{type}{Algorithm used: spectral decomposition or series approximation.}
\item{n}{Number of terms in the series expansion.}
\item{k}{Constant divisor to avoid over- or underflow (series
approximation only).}
}
\value{
\code{mexp} returns the exponential of a matrix.
}
\author{J.K. Lindsey}
\examples{
x <- matrix(c(1,2,3,4),nrow=2)
mexp(x)
}
\keyword{array}

\eof
\name{mpower}
\title{Power of a Matrix}
\alias{%^%}
\usage{
x\%^\%p
}
\description{
\code{\%^\%} calculates \code{x^p} for the square matrix, \code{x}, by
spectral decomposition.
}
\arguments{
\item{x}{A square matrix.}
\item{p}{The power to which the matrix is to be raised.}
}
\value{
\code{\%^\%} returns the power of a matrix.
}
\author{J.K. Lindsey}
\examples{
x <- matrix(c(0.4,0.6,0.6,0.4),nrow=2)
x\%^\%2
x\%^\%10
x\%^\%20
}
\keyword{array}

\eof
\name{mprofile}
\title{Produce Marginal Time Profiles for Plotting}
\usage{
zz <- mprofile(z, times=NULL, mu=NULL, ccov, plotse=TRUE)
plot(zz, nind=1, intensity=FALSE, add=FALSE, ylim=c(min(z$pred),max(z$pred)),
	lty=NULL, ylab="Fitted value", xlab="Time", ...)
}
\alias{mprofile}
\alias{plot.mprofile}
\description{
\code{mprofile} is used for plotting marginal profiles over time
for models obtained from dynamic models, for given fixed values of
covariates. These are either obtained from those supplied by the
model, if available, or from a function supplied by the user.

See \code{\link[rmutil]{iprofile}} for plotting individual profiles from
recursive fitted values.
}
\arguments{
\item{z}{An object of class \code{recursive}, from \code{\link[growth]{carma}},
\code{\link[growth]{elliptic}}, \code{\link[repeated]{gar}},
\code{\link[repeated]{kalcount}}, \code{\link[repeated]{kalseries}},
\code{\link[event]{kalsurv}}, or \code{\link[repeated]{nbkal}}.}
\item{zz}{An object of class \code{mprofile}/}
\item{times}{Vector of time points at which profiles are to be plotted.}
\item{mu}{The location regression as a function of the parameters and
the times for the desired covariate values.}
\item{ccov}{Covariate values for the profiles (\code{\link[growth]{carma}}
only).}
\item{plotse}{If TRUE, plot standard errors
(\code{\link[growth]{carma}} only).}
\item{nind}{Observation number(s) of individual(s) to be plotted. (Not
used if \code{mu} is supplied.)}
\item{intensity}{If TRUE, the intensity is plotted instead of the time
between events. Only for models produced by \code{\link[event]{kalsurv}}.}
\item{add}{If TRUE, add contour to previous plot instead of creating a
new one.}
\item{others}{Plotting control options.}
}
\value{
\code{mprofile}  returns information ready for plotting by
\code{plot.mprofile}.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}},
\code{\link[repeated]{gar}}, \code{\link[repeated]{kalcount}},
\code{\link[repeated]{kalseries}}, \code{\link[event]{kalsurv}},
\code{\link[repeated]{nbkal}} \code{\link[rmutil]{iprofile}},
\code{\link[rmutil]{plot.residuals}}.
}
\examples{
library(repeated)
times <- rep(1:20,2)
dose <- c(rep(2,20),rep(5,20))
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
conc <- matrix(rgamma(40,1,scale=mu(log(c(1,0.3,0.2)))),ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- ifelse(conc>0,conc,0.01)
z <- gar(conc, dist="gamma", times=1:20, mu=mu, shape=shape,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=log(c(1,0.2)))
# plot individual profiles and the average profile
plot(iprofile(z), nind=1:2, pch=c(1,20), lty=3:4)
plot(mprofile(z), nind=1:2, lty=1:2, add=TRUE)
}
\keyword{hplot}

\eof
\name{pkpd}
\title{Pharmacokinetic Compartment Models}
\usage{
mu1.0o1c(p, times, dose=1, end=0.5)
mu1.1o1c(p, times, dose=1)
mu1.1o2c(p, times, dose=1)
mu1.1o2cl(p, times, dose=1)
mu1.1o2cc(p, times, dose=1)
mu2.0o1c(p, times, dose=1, ind, end=0.5)
mu2.0o2c1(p, times, dose=1, ind, end=0.5)
mu2.0o2c2(p, times, dose=1, ind, end=0.5)
mu2.1o1c(p, times, dose=1, ind)
mu2.0o1cfp(p, times, dose=1, ind, end=0.5)
mu2.0o2c1fp(p, times, dose=1, ind, end=0.5)
mu2.0o2c2fp(p, times, dose=1, ind, end=0.5)
mu2.1o1cfp(p, times, dose=1, ind)
}
\alias{pkpd}
\alias{mu1.0o1c}
\alias{mu1.1o1c}
\alias{mu1.1o2c}
\alias{mu1.1o2cl}
\alias{mu1.1o2cc}
\alias{mu2.0o1c}
\alias{mu2.0o2c1}
\alias{mu2.0o2c2}
\alias{mu2.1o1c}
\alias{mu2.0o1cfp}
\alias{mu2.0o2c1fp}
\alias{mu2.0o2c2fp}
\alias{mu2.1o1cfp}
\description{
Mean functions for use in fitting pharmacokineticcompartment models models.

\code{mu1.0o1c}: open zero-order one-compartment model

\code{mu1.1o1c}: open first-order one-compartment model

\code{mu1.1o2c}: open first-order two-compartment model (ordered)

\code{mu1.1o2cl}: open first-order two-compartment model (ordered,
	absorption and transfer equal)

\code{mu1.1o2cc}: open first-order two-compartment model (circular)

Simultaneous models for parent drug and metabolite:

\code{mu2.0o1c}: zero-order one-compartment model

\code{mu2.0o2c1}: zero-order two-compartment for parent,
one-compartment for metabolite, model

\code{mu2.0o2c2}: zero-order two-compartment model for both parent and
metabolite

\code{mu2.1o1c}: first-order one-compartment model

\code{mu2.0o1cfp}: zero-order one-compartment first-pass model

\code{mu2.0o2c1fp}: zero-order two-compartment for parent,
one-compartment for metabolite, model with first-pass

\code{mu2.0o2c2fp}: zero-order two-compartment model for both parent and
metabolite with first-pass

\code{mu2.1o1cfp}: first-order one-compartment first-pass model
}
\arguments{
\item{p}{Vector of parameters. See the source file for details.}
\item{times}{Vector of times.}
\item{dose}{Vector of dose levels.}
\item{ind}{Indicator whether parent drug or metabolite.}
\item{end}{Time infusion ends.}
}
\value{
The profile of mean concentrations for the given times and doses is
returned.
}
\author{J.K. Lindsey}
\examples{
library(repeated)
times <- rep(1:20,2)
dose <- c(rep(2,20),rep(5,20))
# set up a mean function for gar based on mu1.1o1c:
mu <- function(p) {
	ka <- exp(p[2])
	ke <- exp(p[3])
	exp(p[2]-p[1])/(ka-ke)*(exp(-ke*times)-exp(-ka*times))}
conc <- matrix(rgamma(40,2,scale=mu(log(c(1,0.3,0.2)))/2),ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- ifelse(conc>0,conc,0.01)
gar(conc, dist="gamma", times=1:20, mu=mu, preg=log(c(1,0.4,0.1)),
	pdepend=0.1, pshape=1)
# changing variance
shape <- mu
gar(conc, dist="gamma", times=1:20, mu=mu, preg=log(c(0.5,0.4,0.1)),
	pdep=0.1, shape=shape, pshape=log(c(0.5,0.4,0.1)))
}
\keyword{models}

\eof
\name{plot.residuals}
\title{Plot Residuals}
\alias{plot.residuals}
\usage{
plot.residuals(z, x=NULL, subset=NULL, ccov=NULL, nind=NULL,
	recursive=TRUE, pch=20, ylab="Residual", xlab=NULL,
	main=NULL, ...)
}
\description{
\code{plot.residuals} is used for plotting residuals from models
obtained from dynamic models for given subsets of the data.
}
\arguments{
\item{z}{An object of class recursive, from \code{\link[growth]{carma}},
\code{\link[repeated]{gar}}, \code{\link[repeated]{kalcount}},
\code{\link[repeated]{kalseries}}, \code{\link[event]{kalsurv}}, or
\code{\link[repeated]{nbkal}}.}
\item{x}{Vector of of values for the x-axis. If missing, time is
used. It can also be specified by the strings "response" or "fitted".}
\item{subset}{A logical vector defining which observations are to be
used.}
\item{ccov}{If the name of a time-constant covariate is
supplied, separate plots are made for each distinct value of that
covariate.}
\item{nind}{Observation number(s) of individual(s) to be plotted.}
\item{recursive}{If TRUE, plot recursive residuals, otherwise ordinary
residuals.}
\item{others}{Plotting control options.}
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[repeated]{gar}},
\code{\link[repeated]{kalcount}}, \code{\link[repeated]{kalseries}},
\code{\link[event]{kalsurv}}, \code{\link[repeated]{nbkal}}
\code{\link[rmutil]{plot.iprofile}}, \code{\link[rmutil]{plot.mprofile}}.}
\examples{
library(repeated)
times <- rep(1:20,2)
dose <- c(rep(2,20),rep(5,20))
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
conc <- matrix(rgamma(40,2,scale=mu(log(c(1,0.3,0.2)))/2),ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- ifelse(conc>0,conc,0.01)
z <- gar(conc, dist="gamma", times=1:20, mu=mu, shape=shape,
	preg=log(c(1,0.4,0.1)), pdepend=0.1, pshape=log(c(1,0.2)))
plot.residuals(z, subset=1:20, main="Dose 1")
plot.residuals(z, x="fitted", subset=1:20, main="Dose 1")
plot.residuals(z, x="response", subset=1:20, main="Dose 1")
}
\keyword{hplot}

\eof
\name{read.list}
\title{Read a List of Matrices from a File for Unbalanced Repeated
Measurements}
\alias{read.list}
\usage{
read.list(file="", skip=0, nlines=2, order=NULL)
}
\description{
\code{read.list} reads sets of lines of data from a file and creates a
list of matrices. Different sets of lines may be have different lengths.
}
\arguments{
\item{file}{Name of the file to read}
\item{skip}{Number of lines to skip at the beginning of the file}
\item{nlines}{Number of lines per matrix}
\item{order}{Order in which the lines are to be used as columns of the
matrix. If NULL, they are placed in the order read.}
}
\value{
The list of matrices, each with \code{nlines} columns, is returned.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{lvna}}, \code{\link[rmutil]{read.rep}},
\code{\link[rmutil]{read.surv}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tvctomat}}
}
\examples{
\dontrun{y <- read.list("test.dat")}
}
\keyword{file}


\eof
\name{read.rep}
\title{Read a Rectangular Data Set from a File to Create a repeated Object}
\alias{read.rep}
\usage{
read.rep(file, header=TRUE, skip=0, sep = "", na.strings="NA",
	response, id=NULL, times=NULL, censor=NULL, totals=NULL,
	weights=NULL, nest=NULL, delta=NULL, coordinates=NULL,
	type=NULL, ccov=NULL, tvcov=NULL, na.rm=T)
}
\description{
\code{dftorep} forms an object of class, \code{repeated}, from data
read from a file with the option of removing any observations where
response and covariate values have NAs. For repeated measurements,
observations on the same individual must be together in the file. A
number of validity checks are performed on the data.

Such objects can be printed and plotted. Methods are available for
extracting the response, the numbers of observations per individual,
the times, the weights, the units of measurement/Jacobian, the nesting
variable, the covariates, and their names: \code{\link[rmutil]{response}},
\code{\link[rmutil]{nobs}}, \code{\link[rmutil]{times}},
\code{\link[rmutil]{weights}}, \code{\link[rmutil]{delta}},
\code{\link[rmutil]{nesting}}, \code{\link[rmutil]{covariates}}, and
\code{\link[rmutil]{names}}.
}
\arguments{
\item{file}{A file name from which to read the data with variables as
columns and observations as rows.}

\item{header}{A logical value indicating whether the file contains the
names of the variables as the line before the first row of data.}

\item{skip}{The number of lines of the file to skip before beginning
to read data.}

\item{sep}{The field separator character. Values on each line of the
file are separated by this character.}

\item{na.strings}{A vector of strings defining what values are to be
assigned NA.}

\item{response}{A character vector giving the column name(s) of the
dataframe for the response variable(s).}

\item{id}{A character vector giving the column name of the
dataframe for the identification numbers of the individuals. If the
numbers are not consecutive integers, a warning is given.

If NULL, one observation per individual is assumed if \code{times} is
also NULL, other time series is assumed.}

\item{times}{An optional character vector giving the column name of the
dataframe for the times vector.}

\item{censor}{An optional character vector giving the column name(s)
of the dataframe for the censor indicator(s). This must be the same
length as \code{response}. Responses without censor indicator can have
a column either of all NAs or all 1s.}

\item{totals}{An optional character vector giving the column name(s)
of the dataframe for the totals for binomial data. This must be the same
length as \code{response}. Responses without censor indicator can have
a column all NAs.}

\item{weights}{An optional character vector giving the column name of
the dataframe for the weights vector.}

\item{nest}{An optional character vector giving the column name of
the dataframe for the nesting vector within individuals.

This is the second level of nesting for repeated measurements, with
the individual being the first level. Values for an individual must be
consecutive increasing integers.}

\item{delta}{An optional character vector giving the column name(s)
of the dataframe for the units of measurement/Jacobian(s) of the
response(s). This must be the same length as \code{response}.
Responses without units of measurement/Jacobian can have a column all
NAs.

If all response variables have the same unit of measurement, this can
be that one number. If each response variable has the same unit of
measurement for all its values, this can be a numeric vector of length
the number of response variables.}

\item{coordinates}{An optional character vector giving the two or
three column name(s) of the dataframe for the spatial coordinates.}

\item{type}{An optional character vector giving the types of response
variables: nominal, ordinal, discrete, duration, continuous,
multivariate, or unknown.}

\item{ccov}{An optional character vector giving the column names of
the dataframe for the time-constant or inter-individual covariates.
For repeated measurements, if the value is not constant for all
observations on an individual, an error is produced.}

\item{tvcov}{An optional character vector giving the column names of
the dataframe for the time-varying or intra-individual covariates.}

\item{na.rm}{If TRUE, observations with NAs in any variables selected
are removed in the object returned. Otherwise, the corresponding
indicator variable is returned in a slot in the object.}
}
\value{
Returns an object of class, \code{repeated}, containing a list of the
response object (\code{z$response}, so that, for example, the response vector
is \code{z$response$y}; see \code{\link[rmutil]{restovec}}), and
possibly the two classes of covariate objects (\code{z$ccov} and
\code{z$tvcov}; see \code{\link[rmutil]{tcctomat}} and
\code{\link[rmutil]{tvctomat}}).
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{dftorep}}, \code{\link[rmutil]{lvna}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}
}
\examples{
\dontrun{read.rep("test.dat", resp=c("y1","y2"), times="tt", id="id",}
\dontrun{	totals=c("tot1","tot2"), tvcov="x",ccov="x2")}
}
\keyword{file}

\eof
\name{read.surv}
\title{Read a List of Matrices from a File for Repeated Times to Events}
\alias{read.surv}
\usage{
read.surv(file="", skip=0, nlines=1, cumulative=T, all=T)
}
\description{
\code{read.surv} reads sets of lines of data from a file. Each set may
contain a series of duration times followed by a censor indicator for
the last value (\code{all=FALSE}) or a series of pairs of times followed by
their censor indicators (\code{all=TRUE}).
}
\arguments{
\item{file}{Name of the file to read}
\item{skip}{Number of lines to skip at the beginning of the file}
\item{nlines}{Number of lines in each series of duration times}
\item{cumulative}{If TRUE, the times are cumulative and differences
are taken to obtain times between events. Otherwise, the times are
used unchanged.}
\item{all}{If TRUE, all times have accompanying censor indicators;
otherwise, only the last one does.}
}
\value{
A list containing a list of vectors with the series of times and a
vector of censor indicators for the last time of each series is returned.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{lvna}}, \code{\link[rmutil]{read.list}},
\code{\link[rmutil]{read.rep}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}
}
\examples{
\dontrun{y <- read.surv("test.dat")}
}
\keyword{file}


\eof
\name{restovec}
\title{Create a response Object}
\alias{restovec}
\usage{
restovec(response=NULL, times=NULL, nest=NULL, coordinates=NULL,
	censor=NULL, totals=NULL, weights=NULL, delta=NULL,
	type=NULL, names=NULL, units=NULL, oldresponse=NULL,
	description=NULL)
}
\description{
\code{restovec} can produce an object of class, \code{response}, from
a vector of (1) independent univariate responses or (2) a single time
series.

It can produce such an object from repeated measurements in the form
of (1) a list of vectors of event histories, (2) a list of two or more
column matrices with times, response values, and and other information
or (3) a matrix or dataframe of response values. The first two are for
unbalanced data and the third for balanced data.

Multivariate responses can be supplied as (1) a three-dimensional
array of balanced repeated measurements, (2) lists of matrices for
unbalanced repeated measurements, or (3) a matrix with either (a)
several time series or (b) single observations per individual on
several variables.

In formula and functions, the key words, \code{times} can be used to
refer to the response times from the data object as a covariate,
\code{individuals} to the index for individuals as a factor covariate,
and \code{nesting} the index for nesting as a factor covariate. The
latter two only work for W&R notation.

NAs can be detected with \code{\link[rmutil]{lvna}} or removed with
\code{\link[rmutil]{rmna}} (where necessary, in coordination with the
appropriate covariates) to create a \code{repeated} object.

\code{response} objects can be printed and plotted. Methods are
available for extracting the response, the numbers of observations per
individual, the times, the weights, the units of measurement/Jacobian,
and the nesting variable: \code{\link[rmutil]{response}},
\code{\link[rmutil]{nobs}}, \code{\link[rmutil]{times}},
\code{\link[rmutil]{weights}}, \code{\link[rmutil]{delta}}, and
\code{\link[rmutil]{nesting}}.

The response and or the times may be \link[rmutil]{transform}ed using
\code{transform(z, newy=fcn1(y), times=fcn2(times))} where
\code{fcn1} and \code{fcn2} are transformations and \code{y} is the
name of a response variable. When the response is
transformed, the Jacobian is automatically calculated. Note that, if
the unit of precision/Jacobian (\code{\link[rmutil]{delta}}) is available in
the \code{response} object, this is automatically included in the
calculation of the likelihood function in all library model functions.
}
\arguments{
\item{response}{For (1) independent univariate responses with one
observation per individual or (2) a single time series, one vector may
be supplied (in the latter case, the times must be given even if
equally spaced).

Univariate repeated measurements responses can be given (1) if
balanced, as a matrix or dataframe of response values with dimensions:
number of individuals by number of responses/individual, (2) a list of
vectors of event histories, or (3) a list of one or more column
matrices, for each individual, with response values in the first
column and times in the second (if there are no times, set
\code{times} to FALSE), possibly followed by columns with nesting
categories, binomial totals, censoring indicators, and/or units of
measurement.

Multivariate responses can be supplied as (1) a three-dimensional
array of balanced repeated measurements with dimensions: number of
individuals by number of responses/individual by number of variables,
(2) a list of matrices for unbalanced repeated measurements each with
dimensions: number of responses on that individual by number of
variables, plus a column for times if available (otherwise set
\code{times} to FALSE), or (3) a matrix with either (a) several time
series, having dimensions: length of time series by by number of times
series, or (b) single observations per individual on several variables
with dimensions: number of individuals by number of variables. In all
but case (1), \code{type} must be a character vector with length equal
to the number of responses. In case (2), where applicable, \code{censor},
\code{totals}, and \code{delta} must be supplied as lists of matrices
of the same size as for \code{response}, and \code{nest} and
\code{weights} as lists of vectors of lengths equal to the number of
observations on each individual.}

\item{times}{When \code{response} is a matrix or multivariate array,
these can be (1) a vector when the times are the same for all
individuals, possibly unequally-spaced, or (2) a matrix with
dimensions: number of individuals by number of responses/individual.
Not necessary if times are equally spaced, except if a vector
containing a single time series is supplied (if not given in this
case, it takes the responses to be independent, not a time
series). For clustered data with no time ordering, set to FALSE.}

\item{nest}{This is the second level of nesting, with the individual
being the first level. Values for an individual must be consecutive
increasing integers with all responses in the same cluster grouped
together. For example, with three clusters of four observations each,
the code would be 1,1,1,1,2,2,2,2,3,3,3,3.

When \code{response} is a matrix or multivariate array, this can be a
vector of length equal to the number of responses/individual
indicating which responses belong to which nesting category.

If \code{response} is a multivariate list, this must also be a list.

When \code{response} is a univariate list of unbalanced repeated
measurements, the nesting indicator may instead be included in that
list but must respect the same ordering as described above.}

\item{coordinates}{When \code{response} is a vector, a two-column
matrix giving the coordinates for spatial data.}

\item{censor}{When \code{response} is a matrix, this can be (1) a vector
of the same length as the number of individuals, containing a binary
indicator, with a one indicating that the last time period in the
series terminated with an event and zero that it was censored, or
(2) a matrix of the same size as \code{response}.

When \code{response} is a multivariate array, this can be (1) a matrix
with dimensions: number of individuals by number of responses, or (2)
an array of the same size as \code{response}. In the first case, for
each column corresponding to a duration response, it should contain a
binary indicator, with a one indicating that the last time period in
the series terminated with an event and zero that it was censored, and
NAs in columns not containing durations. In the second case, layers
not corresponding to duration responses should contain NAs.

If \code{response} is a multivariate list, this must also be a list.

For event history data, even with no censoring, an appropriate vector
of ones must be supplied.

When \code{response} is a univariate list of unbalanced repeated
measurements, the censoring indicator may instead be included in that
list.}

\item{totals}{If the response is a matrix of binomial counts, this can
be (1) a corresponding vector (one total per individual) or (2) a
matrix of totals.

When \code{response} is a multivariate array, this can be (1) a matrix
with dimensions: number of individuals by number of responses if all
binomial responses for an individual have the same total, or (2) an
array of the same size as \code{response}. In the first case, for each
column corresponding to a binomial response, it should contain the
corresponding totals, with NAs in columns not containing binomial. In
the second case, layers not corresponding to binomial responses should
contain NAs.

If \code{response} is a multivariate list, this must also be a list.

When \code{response} is a univariate list of unbalanced repeated
measurements, the totals may instead be included in that list.}

\item{weights}{A vector, matrix, array, or list of vectors of
frequencies or weights, with one value per \code{response}. In other
words, a multivariate response has only one corresponding weight value.}

\item{delta}{For continuous measurements, the unit of precision (if
not equal to unity) for each response: a scalar, vector, matrix,
array, or list of the same dimensions as \code{response}. For example,
if responses have two decimal places (\code{12.34}), \code{delta=0.01}.
If the response has been transformed, this should be multiplied by the
numerical values of the Jacobian. When the \code{transform} method is
applied to the \code{response} object, this is automatically updated.}

\item{type}{The type(s) of observations: nominal, ordinal, discrete,
duration, continuous, or unknown. If not specified otherwise, those
responses with \code{delta} and no \code{censor} are assumed to be
\code{continuous}, those with \code{censor} indicator are assumed to
be \code{duration}, those with \code{totals} are assumed to be
\code{nominal}, and all others \code{unknown}.}

\item{names}{Optional name(s) of the response variable(s).}
\item{units}{Optional character vector giving units of measurement of
response(s).}
\item{oldresponse}{An existing \code{response} object to which the new
data are to be added.}
\item{description}{An optional named list of character vectors with
names of some or all response variables containing their descriptions.}
}
\value{
Returns an object of class, \code{response}, containing a vector with the
responses (\code{z$y}), a corresponding vector of times (\code{z$times}) if
applicable, a vector giving the number of observations per individual
(\code{z$nobs}, set to a scalar 1 if observations are independent),
type  (\code{z$delta}), and possibly binomial totals (\code{z$n}),
nesting (clustering, \code{z$nest}), censoring (\code{z$censor}),
weights (\code{z$wt}),  unit of precision/Jacobian (\code{z$delta}),
units of measurement (\code{z$units}), and description
(\code{z$description}) information.
}
\seealso{
\code{\link[rmutil]{DataMethods}}, \code{\link[rmutil]{covind}},
\code{\link[rmutil]{delta}}, \code{\link[rmutil]{description}},
\code{\link[rmutil]{lvna}}, \code{\link[rmutil]{names}},
\code{\link[rmutil]{nesting}}, \code{\link[rmutil]{nobs}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{read.surv}},
\code{\link[rmutil]{response}}, \code{\link[rmutil]{resptype}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{times}}, \code{\link[rmutil]{transform}},
\code{\link[rmutil]{tvctomat}}, \code{\link[rmutil]{units}},
\code{\link[rmutil]{weights}}
}
\author{J.K. Lindsey}
\examples{
#
#continuous response
y <- matrix(rnorm(20),ncol=5)
# times assumed to be 1:5
restovec(y, units="m")
#unequally-spaced times
tt <- c(1,3,6,10,15)
print(resp <- restovec(y, times=tt, units="m",
	description=list(y="Response measured in metres")))
response(resp)
response(resp, nind=2:3)
response(transform(resp, y=1/y))
transform(resp, y=1/y, units="1/m")
units(resp)
description(resp)
times(resp)
times(transform(resp, times=times-6))
nobs(resp)
weights(resp)
nesting(resp)
# because individuals are the only nesting, this is the same as
covind(resp)
#
# binomial response
y <- matrix(rpois(20,5),ncol=5)
# responses summarized as relative frequencies
print(respb <- restovec(y, totals=y+matrix(rpois(20,5),ncol=5), times=tt))
response(respb)
#
# censored data
y <- matrix(rweibull(20,2,5),ncol=5)
print(respc <- restovec(y, censor=matrix(rbinom(20,1,0.9),ncol=5), times=tt))
# if there is no censoring, censor indicator is not printed
response(respc)
# nesting clustered within individuals
nest <- c(1,1,2,2,2)
print(respn <- restovec(y, censor=matrix(rbinom(20,1,0.9),ncol=5),
	times=tt,nest=nest))
response(respn)
times(respn)
nesting(respn)
#
# multivariate response
restovec(y, censor=matrix(rbinom(20,1,0.9),ncol=5),
	units=c("m","days","l","cm","mon"),
	type=c("continuous","duration","continuous","continuous","duration"),
	description=list(y1="First continuous variable",
		y2="First duration variable",y3="Second continuous variable",
		y4="Third continuous variable",y5="Second duration variable"))
restovec(y, censor=matrix(rbinom(20,1,0.9),ncol=5), 
	names=c("a","b","c","d","e"), units=c("m","days","l","cm","mon"),
	type=c("continuous","duration","continuous","continuous","duration"),
	description=list(a="First continuous variable",
		b="First duration variable",c="Second continuous variable",
		d="Third continuous variable",e="Second duration variable"))
}
\keyword{manip}

\eof
\name{rmna}
\title{Create a repeated Object, Removing NAs}
\alias{rmna}
\usage{
rmna(response, ccov=NULL, tvcov=NULL)}
\description{
\code{rmna} forms an object of class, \code{repeated}, from a
\code{response} object and possibly time-varying or
intra-individual covariate (\code{tvcov}), and time-constant or
inter-individual covariate (\code{tccov}) objects, removing any
observations where response and covariate values have NAs. Subjects
must be in the same order in all (three) objects to be combined.

Such objects can be printed and plotted. Methods are available for
extracting the response, the numbers of observations per individual,
the times, the weights, the units of measurement/Jacobian, the nesting
variable, the covariates, and their names: \code{\link[rmutil]{response}},
\code{\link[rmutil]{nobs}}, \code{\link[rmutil]{times}},
\code{\link[rmutil]{weights}}, \code{\link[rmutil]{delta}},
\code{\link[rmutil]{nesting}}, \code{\link[rmutil]{covariates}}, and
\code{\link[rmutil]{names}}.
}
\arguments{
\item{response}{An object of class, \code{response} (created by
\code{\link[rmutil]{restovec}}), containing the response variable information.}
\item{ccov}{An object of class, \code{tccov} (created by
\code{\link[rmutil]{tcctomat}}), containing the time-constant or
inter-individual covariate information.}
\item{tvcov}{An object of class, \code{tvcov} (created by
\code{\link[rmutil]{tvctomat}}), containing the time-varying or
intra-individual covariate information.}
}
\value{
Returns an object of class, \code{repeated}, containing a list of the
response object (\code{z$response}, so that, for example, the response vector
is \code{z$response$y}; see \code{\link[rmutil]{restovec}}), and
possibly the two classes of covariate objects (\code{z$ccov} and
\code{z$tvcov}; see \code{\link[rmutil]{tcctomat}} and
\code{\link[rmutil]{tvctomat}}).
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{DataMethods}}, \code{\link[rmutil]{covariates}},
\code{\link[rmutil]{covind}}, \code{\link[rmutil]{delta}},
\code{\link[rmutil]{dftorep}}, \code{\link[rmutil]{lvna}},
\code{\link[rmutil]{names}}, \code{\link[rmutil]{nesting}},
\code{\link[rmutil]{nobs}}, \code{\link[rmutil]{read.list}},
\code{\link[rmutil]{read.surv}}, \code{\link[rmutil]{response}},
\code{\link[rmutil]{resptype}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{tcctomat}}, \code{\link[rmutil]{times}},
\code{\link[rmutil]{transform}}, \code{\link[rmutil]{tvctomat}},
\code{\link[rmutil]{units}}, \code{\link[rmutil]{weights}}
}
\examples{
y <- matrix(rnorm(20),ncol=5)
tt <- c(1,3,6,10,15)
print(resp <- restovec(y,times=tt))
x <- c(0,0,1,1)
tcc <- tcctomat(x)
z <- matrix(rpois(20,5),ncol=5)
tvc <- tvctomat(z)
print(reps <- rmna(resp, tvcov=tvc, ccov=tcc))
response(reps)
response(reps, nind=2:3)
times(reps)
nobs(reps)
weights(reps)
covariates(reps)
covariates(reps,names="x")
covariates(reps,names="z")
names(reps)
nesting(reps)
# because individuals are the only nesting, this is the same as
covind(reps)
#
# use in glm
rm(y,x,z)
glm(y~x+z,data=as.data.frame(reps))
#
# binomial
y <- matrix(rpois(20,5),ncol=5)
print(respb <- restovec(y,totals=y+matrix(rpois(20,5),ncol=5),times=tt))
print(repsb <- rmna(respb, tvcov=tvc, ccov=tcc))
response(repsb)
#
# censored data
y <- matrix(rweibull(20,2,5),ncol=5)
print(respc <- restovec(y,censor=matrix(rbinom(20,1,0.9),ncol=5),times=tt))
print(repsc <- rmna(respc, tvcov=tvc, ccov=tcc))
# if there is no censoring, censor indicator is not printed
response(repsc)
#
# nesting clustered within individuals
nest <- c(1,1,2,2,2)
print(respn <- restovec(y,censor=matrix(rbinom(20,1,0.9),ncol=5),
	times=tt,nest=nest))
print(repsn <- rmna(respn, tvcov=tvc, ccov=tcc))
response(respn)
times(respn)
nesting(respn)
}
\keyword{manip}

\eof
\name{rmutil}
\title{Utilities for Repeated Measurements Library}
\alias{rmutil}
\description{
\code{\link[rmutil]{\%^\%}}			  Power of a Matrix

\code{\link[rmutil]{covariates}}		Extract Covariate Matrices from a Data Object

\code{\link[rmutil]{covind}}			Nesting Indicator for Observations within Individuals in a Data Object

\code{\link[rmutil]{dbetabinom}}		Density of Beta Binomial Distribution

\code{\link[rmutil]{dboxcox}}			Density of Box-Cox Distribution

\code{\link[rmutil]{dburr}}			Density of Burr Distribution

\code{\link[rmutil]{ddoublebinom}}		Density of Double Binomial Distribution

\code{\link[rmutil]{ddoublepois}}		Density of Double Poisson Distribution

\code{\link[rmutil]{delta}}			Extract Units of Measurement Vector from a Data Object

\code{\link[rmutil]{dftorep}}			Transform a Dataframe to a repeated Object

\code{\link[rmutil]{dgammacount}}		Density of Gamma Count Distribution

\code{\link[rmutil]{dgextval}}			Density of Generalized Extreme Value Distribution

\code{\link[rmutil]{dggamma}}			Density of Generalized Gamma Distribution

\code{\link[rmutil]{dginvgauss}}		Density of Generalized Inverse Gaussian Distribution

\code{\link[rmutil]{dglogis}}			Density of Generalized Logistic Distribution

\code{\link[rmutil]{dgweibull}}			Density of Generalized Weibull Distribution

\code{\link[rmutil]{dhjorth}}			Density of Hjorth Distribution

\code{\link[rmutil]{dinvgauss}}			Density of Inverse Gaussian Distribution

\code{\link[rmutil]{dlaplace}}			Density of Laplace Distribution

\code{\link[rmutil]{dlevy}}			Density of Levy Distribution

\code{\link[rmutil]{dmultbinom}}		Density of Multiplicative Binomial Distribution

\code{\link[rmutil]{dmultpois}}			Density of Multiplicative Poisson Distribution

\code{\link[rmutil]{dpareto}}			Density of Pareto Distribution

\code{\link[rmutil]{dpowexp}}			Density of Power Exponential Distribution

\code{\link[rmutil]{dpvfpois}}			Density of Power Variance Function Poisson Distribution

\code{\link[rmutil]{dsimplex}}			Density of Simplex Distribution

\code{\link[rmutil]{dskewlaplace}}		Density of Skew Laplace Distribution

\code{\link[rmutil]{finterp}}			Formula Interpreter

\code{\link[rmutil]{fmobj}}			Object Finder in Formulae

\code{\link[rmutil]{fnenvir}}			Check Covariates and Parameters of a Function

\code{\link[rmutil]{formula}}			Extract Formula Used to Create Time-constant Covariate Matrix in a Data Object

\code{\link[rmutil]{gauss.hermite}}		Calculate Gauss-Hermite Quadrature Points

\code{\link[rmutil]{gettvc}}			Create Time-varying Covariates

\code{\link[rmutil]{int}}			Vectorized One-dimensional Numerical Integration

\code{\link[rmutil]{int2}}			Vectorized Two-dimensional Numerical Integration

\code{\link[rmutil]{iprofile}}			Produce Individual Time Profiles for Plotting

\code{\link[rmutil]{lin.diff.eqn}}		Solution of Autonomous Linear Differential Equations

\code{\link[rmutil]{lvna}}			Create a Repeated Object Leaving NAs

\code{\link[rmutil]{mexp}}			Matrix Exponentiation

\code{\link[rmutil]{mprofile}}			Produce Marginal Time Profiles for Plotting

\code{\link[rmutil]{names}}			Extract Names of Covariates from a Data Object

\code{\link[rmutil]{nesting}}			Extract Nesting Indicators from a Data Object

\code{\link[rmutil]{nobs}}			Extract Number of Observations per Individual from a Data Object

\code{\link[rmutil]{pbetabinom}}		Distribution Function of Beta Binomial Distribution

\code{\link[rmutil]{pboxcox}}			Distribution Function of Box-Cox Distribution

\code{\link[rmutil]{pburr}}			Distribution Function of Burr Distribution

\code{\link[rmutil]{pdoublebinom}}		Distribution Function of Double Binomial Distribution

\code{\link[rmutil]{pdoublepois}}		Distribution Function of Double Poisson Distribution

\code{\link[rmutil]{pgammacount}}		Distribution Function of Gamma Count Distribution

\code{\link[rmutil]{pgextval}}			Distribution Function of Generalized Extreme Value Distribution

\code{\link[rmutil]{pggamma}}			Distribution Function of Generalized Gamma Distribution

\code{\link[rmutil]{pginvgauss}}		Distribution Function of Generalized Inverse Gaussian Distribution

\code{\link[rmutil]{pglogis}}			Distribution Function of Generalized Logistic Distribution

\code{\link[rmutil]{pgweibull}}			Distribution Function of Generalized Weibull Distribution

\code{\link[rmutil]{phjorth}}			Distribution Function of Hjorth Distribution

\code{\link[rmutil]{pinvgauss}}			Distribution Function of Inverse Gaussian Distribution

\code{\link[rmutil]{pkpd}}			Pharmacokinetic Model Functions

\code{\link[rmutil]{plaplace}}			Distribution Function of Laplace Distribution

\code{\link[rmutil]{plevy}}			Distribution Function of Levy Distribution

\code{\link[rmutil]{plot.residuals}}		Plot Residuals for Carma

\code{\link[rmutil]{pmultbinom}}		Distribution Function of Multiplicative Binomial Distribution

\code{\link[rmutil]{pmultpois}}			Distribution Function of Multiplicative Poisson Distribution

\code{\link[rmutil]{ppareto}}			Distribution Function of Pareto Distribution

\code{\link[rmutil]{ppowexp}}			Distribution Function of Power Exponential Distribution

\code{\link[rmutil]{ppvfpois}}			Distribution Function of Power Variance Function Poisson Distribution

\code{\link[rmutil]{psimplex}}			Distribution Function of Simplex Distribution

\code{\link[rmutil]{pskewlaplace}}		Distribution Function of Skew Laplace Distribution

\code{\link[rmutil]{qbetabinom}}		Quantiles of Beta Binomial Distribution

\code{\link[rmutil]{qboxcox}}			Quantiles of Box-Cox Distribution

\code{\link[rmutil]{qburr}}			Quantiles of Burr Distribution

\code{\link[rmutil]{qdoublebinom}}		Quantiles of Double Binomial Distribution

\code{\link[rmutil]{qdoublepois}}		Quantiles of Double Poisson Distribution

\code{\link[rmutil]{qgammacount}}		Quantiles of Gamma Count Distribution

\code{\link[rmutil]{qgextval}}			Quantiles of Generalized Extreme Value Distribution

\code{\link[rmutil]{qggamma}}			Quantiles of Generalized Gamma Distribution

\code{\link[rmutil]{qginvgauss}}		Quantiles of Generalized Inverse Gaussian Distribution

\code{\link[rmutil]{qglogis}}			Quantiles of Generalized Logistic Distribution

\code{\link[rmutil]{qgweibull}}			Quantiles of Generalized Weibull Distribution

\code{\link[rmutil]{qhjorth}}			Quantiles of Hjorth Distribution

\code{\link[rmutil]{qinvgauss}}			Quantiles of Inverse Gaussian Distribution

\code{\link[rmutil]{qlaplace}}			Quantiles of Laplace Distribution

\code{\link[rmutil]{qlevy}}			Quantiles of Levy Distribution

\code{\link[rmutil]{qmultbinom}}		Quantiles of Multiplicative Binomial Distribution

\code{\link[rmutil]{qmultpois}}			Quantiles of Multiplicative Poisson Distribution

\code{\link[rmutil]{qpareto}}			Quantiles of Pareto Distribution

\code{\link[rmutil]{qpowexp}}			Quantiles of Power Exponential Distribution

\code{\link[rmutil]{qpvfpois}}			Quantiles of Power Variance Function Poisson Distribution

\code{\link[rmutil]{qsimplex}}			Quantiles of Simplex Distribution

\code{\link[rmutil]{qskewlaplace}}		Quantiles of Skew Laplace Distribution

\code{\link[rmutil]{rbetabinom}}		Random Number Generation for Beta Binomial Distribution

\code{\link[rmutil]{rboxcox}}			Random Number Generation for Box-Cox Distribution

\code{\link[rmutil]{rburr}}			Random Number Generation for Burr Distribution

\code{\link[rmutil]{rdoublebinom}}		Random Number Generation for Double Binomial Distribution

\code{\link[rmutil]{rdoublepois}}		Random Number Generation for Double Poisson Distribution

\code{\link[rmutil]{read.list}}			Read a List of Matrices of Unbalanced Repeated Measurements from a File

\code{\link[rmutil]{read.rep}}			Read a Rectangular Data Set from a File to Create a repeated Object

\code{\link[rmutil]{read.surv}}			Read a List of Vectors of Event Histories from a File

\code{\link[rmutil]{response}}			Extract Response Vector from a Data Object

\code{\link[rmutil]{restovec}}			Create a Response Object

\code{\link[rmutil]{rgammacount}}		Random Number Generation for Gamma Count Distribution

\code{\link[rmutil]{rgextval}}			Random Number Generation for Generalized Extreme Value Distribution

\code{\link[rmutil]{rggamma}}			Random Number Generation for Generalized Gamma Distribution

\code{\link[rmutil]{rginvgauss}}		Random Number Generation for Generalized Inverse Gaussian Distribution

\code{\link[rmutil]{rglogis}}			Random Number Generation for Generalized Logistic Distribution

\code{\link[rmutil]{rgweibull}}			Random Number Generation for Generalized Weibull Distribution

\code{\link[rmutil]{rhjorth}}			Random Number Generation for Hjorth Distribution

\code{\link[rmutil]{rinvgauss}}			Random Number Generation for Inverse Gaussian Distribution

\code{\link[rmutil]{rlaplace}}			Random Number Generation for Laplace Distribution

\code{\link[rmutil]{rlevy}}			Random Number Generation for Levy Distribution

\code{\link[rmutil]{rmna}}			Create a Repeated Object

\code{\link[rmutil]{rmultbinom}}		Random Number Generation for Multiplicative Binomial Distribution

\code{\link[rmutil]{rmultpois}}			Random Number Generation for Multiplicative Poisson Distribution

\code{\link[rmutil]{rpareto}}			Random Number Generation for Pareto Distribution

\code{\link[rmutil]{rpowexp}}			Random Number Generation for Power Exponential Distribution

\code{\link[rmutil]{rpvfpois}}			Random Number Generation for Power Variance Function Poisson Distribution

\code{\link[rmutil]{rsimplex}}			Random Number Generation for Simplex Distribution

\code{\link[rmutil]{rskewlaplace}}		Random Number Generation for Skew Laplace Distribution

\code{\link[rmutil]{runge.kutta}}		Runge-Kutta Method for Solving Differential Equations

\code{\link[rmutil]{tcctomat}}			Create a Time-constant Covariate (tccov) Object

\code{\link[rmutil]{times}}			Extract Times Vector from a Data Object

\code{\link[rmutil]{transform}}			Transform Variables in a Data Object

\code{\link[rmutil]{tvctomat}}			Create a Time-varying Covariate (tvcov) Object

\code{\link[rmutil]{wr}}			Find the Response Vector and Design Matrix for a Model Formula
}
\keyword{documentation}

\eof
\name{runge.kutta}
\title{Runge-Kutta Method for Solving Differential Equations}
\alias{runge.kutta}
\usage{
runge.kutta(f, initial, x)
}
\description{
\code{runge.kutta} numerically solves a differential equation by the
fourth-order Runge-Kutta method.
}
\arguments{
\item{f}{A function \code{dy/dx=func(y,x)}.}
\item{initial}{The initial value of \code{y}.}
\item{x}{A vector of values of \code{x} for which the values or
\code{y} are required.}
}
\value{
A vector of values of \code{y} as solution of the function \code{f}
corresponding to the values in \code{x}.
}
\author{J.K. Lindsey}
\examples{
fn <- function(y,x) (x*y-y^2)/x^2
soln <- runge.kutta(fn,2,seq(1,3,by=1/128))
## exact solution
exact <- seq(1,3,by=1/128)/(0.5+log(seq(1,3,by=1/128)))
rbind(soln, exact)
}
\keyword{math}

\eof
\name{tcctomat}
\title{Create a Time-constant, Inter-individual Covariate (tccov) Object}
\alias{tcctomat}
\usage{
tcctomat(ccov, names=NULL, units=NULL, oldccov=NULL, dataframe=TRUE,
	description=NULL)
}
\description{
\code{tcctomat} creates an object of class, \code{tccov}, from a
vector or matrix containing time-constant or inter-individual baseline
covariates or a model formula. It can also combine two such objects.

Such objects can be printed. Methods are available for extracting the
covariates, their names, and the formula: \code{\link[rmutil]{covariates}},
\code{\link[rmutil]{names}}, and \code{\link[rmutil]{formula}}. The method,
\code{\link[rmutil]{transform}}, can transform variables in place or by adding
new variables to the object.

To obtain the indexing to expand time-constant or inter-individual
covariates to the size of a repeated measurements response, use
\code{\link[rmutil]{covind}}.
}
\arguments{
\item{ccov}{A vector, matrix, or dataframe containing time-constant or
inter-individual baseline covariates with one row per individual, a
model formula using vectors of the same size, or an object of class,
\code{tccov}. In the first two cases, the variables may be factors; if
\code{dataframe=FALSE}, these are transformed to indicator variables.}
\item{units}{Optional character vector specifying units of
measurements of covariates.}
\item{names}{The names of the covariates (if the matrix does not have
column names).}
\item{oldccov}{An object of class, \code{tccov}, to which \code{ccov}
is to be added.}
\item{dataframe}{If TRUE and factor variables are present, the
covariates are stored as a dataframe; if FALSE, they are expanded to
indicator variables. If no factor variables are present, covariates
are always stored as a matrix.}
\item{description}{An optional named list of character vectors with
names of some or all covariates containing their descriptions.}
}
\value{
Returns an object of class, \code{tccov}, containing one matrix or
dataframe for the covariates (\code{z$ccov}) with one row per
individual and possibly the model formula (\code{z$linear}).
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{DataMethods}}, \code{\link[rmutil]{covariates}},
\code{\link[rmutil]{description}}, \code{\link[rmutil]{formula}},
\code{\link[rmutil]{lvna}}, \code{\link[rmutil]{names}},
\code{\link[rmutil]{restovec}}, \code{\link[rmutil]{rmna}},
\code{\link[rmutil]{transform}}, \code{\link[rmutil]{tvctomat}},
\code{\link[rmutil]{units}}
}
\examples{
x1 <- gl(4,1)
print(tcc1 <- tcctomat(~x1))
covariates(tcc1)
covariates(tcc1, name="x12")
tcctomat(x1)
tcctomat(x1, dataframe=FALSE)
x2 <- c(0,0,1,1)
print(tcc2 <- tcctomat(~x2, units="days"))
covariates(tcc2)
print(tcc3 <- tcctomat(~x1+x2))
covariates(tcc3)
covariates(tcc3, names=c("x12","x2"))
formula(tcc3)
names(tcc3)
print(tcc4 <- tcctomat(data.frame(x1,x2), units=c(NA,"days")))
covariates(tcc4)
print(tcc5 <- tcctomat(data.frame(x1,x2), dataframe=FALSE, units=c(NA,"days")))
covariates(tcc5)
}
\keyword{manip}

\eof
\name{tvctomat}
\title{Create a Time-varying, Intra-individual Covariate (tvcov) Object}
\alias{tvctomat}
\usage{
tvctomat(tvcov, names=NULL, units=NULL, interaction=NULL, ccov=NULL,
	oldtvcov=NULL, dataframe=TRUE, description=NULL)
}
\description{
\code{tvctovmat} creates an object of class, \code{tvcov}, from a list of
matrices with time-varying or intra-individual covariates for each
individual or one matrix or dataframe of such covariate values. It can
also combine two such objects or add interactions among covariates.

Such objects can be printed. Methods are available for extracting the
covariates and their names: \code{\link[rmutil]{covariates}} and
\code{\link[rmutil]{names}}. The method,
\code{\link[rmutil]{transform}}, can transform variables in place or
by adding new variables to the object.
}
\arguments{
\item{tvcov}{Either (1) if unbalanced, a list of matrices or
dataframes with time-varying or intra-individual covariate values for
each individual (one column per variable), (2) if balanced, one matrix
or dataframe of such covariate values (when there is only one such
covariate) with dimensions: number of individuals by number of
observations/individual, or (3) an object of class, \code{tvcov}.
In the first two cases, the variables may be factors; if
\code{dataframe=FALSE}, these are transformed to indicator variables.}
\item{names}{The names of the time-varying or intra-individual
covariates in \code{tvcov} (if the matrices do not have column names)
or the names of the time-constant covariates for which interactions
are to be created.}
\item{units}{Optional character vector specifying units of
measurements of covariates.}
\item{interaction}{A pair of index numbers or names of variables in
\code{tvcov}, with that class, for which an interaction is to be added
or, if \code{ccov} is provided, a set of such names of time-varying or
intra-individual covariates for creating interactions with the
time-constant covariates.}
\item{ccov}{Time-constant or inter-individual covariates for which an
interaction is to be introduced with time-varying or intra-individual
covariates in \code{tvcov}.}
\item{oldtvcov}{An object of class, \code{tvcov}, to which
\code{tvcov} is to be added.}
\item{dataframe}{If TRUE and factor variables are present, the
covariates are stored as a dataframe; if FALSE, they are expanded to
indicator variables. If no factor variables are present, covariates
are always stored as a matrix.}
\item{description}{An optional named list of character vectors with
names of some or all covariates containing their descriptions.}
}
\value{
Returns an object of class, \code{tvcov}, containing a matrix or
dataframe for the covariates (\code{z$tvcov}) with one row per
response per individual and a vector giving the number of observations
per individual (\code{z$nobs}).
}
\author{J.K. Lindsey}
\seealso{
\code{\link[rmutil]{DataMethods}}, \code{\link[rmutil]{covariates}},
\code{\link[rmutil]{description}}, \code{\link[rmutil]{formula}},
\code{\link[rmutil]{gettvc}}, \code{\link[rmutil]{lvna}},
\code{\link[rmutil]{names}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{transform}}, \code{\link[rmutil]{units}}
}
\examples{
z <- matrix(rpois(20,5),ncol=5)
print(tvc <- tvctomat(z, units="days"))
covariates(tvc)
names(tvc)
v <- data.frame(matrix(rep(c("a","b","c","d","e"),4),ncol=5))
print(tvc2 <- tvctomat(v, oldtvc=tvc, units=NA))
covariates(tvc2)
print(tvc3 <- tvctomat(v, oldtvc=tvc, dataframe=FALSE, units=NA))
covariates(tvc3)
print(tvc4 <- tvctomat(tvc2, interaction=c("z","v")))
covariates(tvc4)
x1 <- 1:4
x2 <- gl(4,1)
xx <- tcctomat(data.frame(x1,x2), dataframe=FALSE)
tvctomat(tvc3, interaction="z", ccov=xx)
tvctomat(tvc3, interaction="z", ccov=xx, names="x1")
tvctomat(tvc3, interaction="z", ccov=xx, names=c("x22","x23","x24"))
xx <- tcctomat(data.frame(x1,x2), dataframe=TRUE)
tvctomat(tvc2, interaction="z", ccov=xx)
tvctomat(tvc2, interaction="z", ccov=xx, names="x1")
tvctomat(tvc2, interaction="z", ccov=xx, names="x2")
}
\keyword{manip}

\eof
\name{wr}
\title{Find the Response Vector and Design Matrix for a W\&R Model Formula}
\alias{wr}
\usage{
wr(formula, data=NULL, expand=T)
}
\description{
\code{wr} gives the response vector and design matrix for a formula in
Wilkinson and Rogers notation.
}
\arguments{
\item{formula}{A model formula.}
\item{data}{A data object or environment.}
\item{expand}{If FALSE, the covariates are read from the \code{tccov}
object without expanding to the length of the response variable.}
}
\value{
\code{wr} returns a list containing the response vector
(\code{z$response}), if included in the formula, and the design matrix
(\code{z$design}) from the data object or environment supplied or from
the global environment for the formula supplied.
}
\author{J.K. Lindsey}
\examples{
y <- rnorm(20)
x <- gl(4,5)
z <- rpois(20,2)
wr(y~x+z)
}
\keyword{programming}

\eof
